(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     55322,       1063]
NotebookOptionsPosition[     53715,       1010]
NotebookOutlinePosition[     54121,       1027]
CellTagsIndexPosition[     54078,       1024]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Nonlinear Magnetostatic Problem", "Section"],

Cell["\<\
David Meeker
dmeeker@ieee.org\
\>", "Text",
 FontSize->14],

Cell["May 30, 2004 ", "Text"],

Cell["\<\
The objective of this worksheet is to compare calculations of Force versus \
Position for a solenoid plunger with
experimental results from Roter's \"Electromagnetic Devices.\" In particular, \
we will consider the device pictured
in Chapter IX, Figure 7.\
\>", "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\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\
\>"], "Graphics",
 ImageSize->{542, 270.25},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["First, load up the MathFEMM package:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "c:\\femm42\\mathfemm\\mathfemm.m"}]], "Input",
 CellChangeTimes->{{3.5261648728221235`*^9, 3.5261648747097263`*^9}}],

Cell[BoxData["\<\"MathFEMM loaded at Sun 15 Nov 2015 21:06:00\"\>"], "Print",
 CellChangeTimes->{{3.656628306661291*^9, 3.6566283254437623`*^9}, 
   3.6566283602932353`*^9}]
}, Open  ]],

Cell["and then start up a FEMM process with which to interact:", "Text"],

Cell[BoxData[
 RowBox[{"OpenFEMM", "[", "]"}]], "Input"],

Cell["\<\
The actuator geometry was previously drawn in FEMM in the usual interactive \
mode. All components of the moving plunger were defined to be members of \
Group Number 1 so that the plunger can be selected with a single command and \
then moved with a second command.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"OpenDocument", "[", 
  RowBox[{
   RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<roters1b.fem\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.656628259884557*^9, 3.6566282677889147`*^9}, 
   3.656628319396803*^9}],

Cell["\<\
We can set the coil current to investigate the 1.5A curve from Roters\
\>", "Text"],

Cell[BoxData[
 RowBox[{"MISetCurrent", "[", 
  RowBox[{"\"\<Coil Current\>\"", ",", "1.5"}], "]"}]], "Input"],

Cell["\<\
Then geometry can be saved to a temporary file name so that we don't \
overwrite our original geometry during the following analysis\
\>", "Text"],

Cell[BoxData[
 RowBox[{"MISaveAs", "[", 
  RowBox[{
   RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<temp.fem\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.656628276664468*^9, 3.6566282882010927`*^9}, {
  3.6566283463368897`*^9, 3.656628348698943*^9}}],

Cell["\<\
The finished input geometry can be programmatically grabbed from FEMM for \
display in the Notebook. The FEMM model used to analyze this problem looks \
like:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"MIGetView", "[", "]"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3ctx87qaBVDd6kg6DYdxQ7gDTzuCE0DPHI0T6aGDUVtvPvDJIgxBALxW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    "], {{0, 393}, {979, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{979, 393},
  PlotRange->{{0, 979}, {0, 393}}]], "Output",
 CellChangeTimes->{{3.656628308192614*^9, 3.6566283279126263`*^9}, 
   3.6566283624808397`*^9}]
}, Open  ]],

Cell["\<\
This loop repeatedly analyzes the problem, computes force on the plunger via \
the \"Weighted Stress Tensor\", then moves the plunger 1/10 of an inch.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{"For", "[", 
  RowBox[{
   RowBox[{"i", "=", "0"}], ",", 
   RowBox[{"i", "\[LessEqual]", "15"}], ",", 
   RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MIAnalyze", "[", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"i", "\[Equal]", "0"}], ",", 
      RowBox[{"MILoadSolution", "[", "]"}], ",", 
      RowBox[{"MOReload", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"MOGroupSelectBlock", "[", "1", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"data", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"data", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"i", "/", "10."}], ",", 
         RowBox[{"MOBlockIntegral", "[", "19", "]"}]}], "}"}]}], "]"}]}], ";",
     "\[IndentingNewLine]", 
    RowBox[{"MISelectGroup", "[", "1", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"MIMoveTranslate", "[", 
     RowBox[{"0", ",", 
      RowBox[{"-", "0.1"}]}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"MIClearSelected", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell["\<\
The following data points were stripped from the figure in Roters using \
WinDig, a free and very useful tool for recovering numerical data from \
graphs.  See http://www.unige.ch/sciences/chifi/cpb/windig.html
A similar program that will run on 64-bit machines is ScanIt -- see \
http://www.amsterchem.com/scanit.html\
\>", "Text",
 CellChangeTimes->{{3.6566286159767523`*^9, 3.6566286420400753`*^9}}],

Cell["\<\
rotersdata= {{0., 10.468}, {0.10552, 11.788},{0.203,12.584}, {0.30032, \
13.144}, {0.40584, 13.698}, {0.50325, 14.759}, {0.60065, 16.075}, {0.698050, \
17.647}, {0.79545, 19.985}, {0.90909, 21.563}, {1.0146, 23.138}, {1.1039, \
23.94}, {1.2094, 23.728}, {1.3068, 23.002}, {1.4042, 21.254}, {1.5016, \
18.486}};\
\>", "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotersplot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{"rotersdata", ",", 
     RowBox[{"PlotStyle", "->", 
      RowBox[{"{", 
       RowBox[{"PointSize", "[", "0.015", "]"}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.656628760185952*^9, 3.656628761498762*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"feaplot", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"data", ".", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", 
          FractionBox["1", "4.4482`"]}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.656628765512436*^9, 3.6566287657622633`*^9}}],

Cell["\<\
A combined plot compares the data from Roters to that produced from the \
finite element analysis. The solid line is the FEA results and the dots are \
the forces from Roters. There is a reasonable agreement between the two \
results.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"rotersplot", ",", "feaplot", ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "25"}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Displacement, Inches\>\"", ",", 
      "\"\<Force on Plunger, Pounds\>\""}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "->", 
    "\"\<Comparison of FEMM and Experimental Data from Roters\>\""}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "500"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Tahoma\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "14"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.65662868014083*^9, 3.6566287094701333`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], PointSize[0.015], 
    PointBox[{{0., 10.468}, {0.10552, 11.788}, {0.203, 12.584}, {0.30032, 
     13.144}, {0.40584, 13.698}, {0.50325, 14.759}, {0.60065, 16.075}, {
     0.69805, 17.647}, {0.79545, 19.985}, {0.90909, 21.563}, {1.0146, 
     23.138}, {1.1039, 23.94}, {1.2094, 23.728}, {1.3068, 23.002}, {1.4042, 
     21.254}, {1.5016, 18.486}}]}, 
   {Hue[0.67, 0.6, 0.6], 
    LineBox[{{0., 12.263748957896139`}, {0.1, 12.463679009674284`}, {0.2, 
     12.936952436152085`}, {0.30000000000000004`, 13.574669134052128`}, {0.4, 
     14.405564834079184`}, {0.5, 15.32881649447656}, {0.6000000000000001, 
     16.389707731198417`}, {0.7000000000000001, 17.512717319985455`}, {0.8, 
     18.75621550699406}, {0.9, 20.077877175458088`}, {1., 
     21.41328242539233}, {1.1, 22.556602274933436`}, {1.2000000000000002`, 
     22.894410670950904`}, {1.3, 21.695566479548535`}, {1.4000000000000001`, 
     19.435021425380402`}, {1.5, 16.99807571848051}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  BaseStyle->{FontFamily -> "Tahoma", FontSize -> 14},
  Frame->True,
  FrameLabel->{
    FormBox["\"Displacement, Inches\"", TraditionalForm], 
    FormBox["\"Force on Plunger, Pounds\"", TraditionalForm]},
  ImageSize->500,
  PlotLabel->FormBox[
   "\"Comparison of FEMM and Experimental Data from Roters\"", 
    TraditionalForm],
  PlotRange->{0, 25},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{{3.656628308755139*^9, 3.6566283285845323`*^9}, 
   3.656628572759819*^9, {3.6566286823595304`*^9, 3.6566287098449497`*^9}, 
   3.656628769074911*^9}]
}, Open  ]],

Cell["\<\
Now that we are done with the computation, we can shut down FEMM.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"CloseFEMM", "[", "]"}]], "Input"]
}, Open  ]]
},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 50, 0, 71, "Section"],
Cell[620, 24, 68, 4, 49, "Text"],
Cell[691, 30, 29, 0, 29, "Text"],
Cell[723, 32, 279, 6, 65, "Text"],
Cell[1005, 40, 36343, 598, 279, "Graphics"],
Cell[37351, 640, 52, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[37428, 644, 146, 2, 31, "Input"],
Cell[37577, 648, 173, 2, 23, "Print"]
}, Open  ]],
Cell[37765, 653, 72, 0, 29, "Text"],
Cell[37840, 655, 56, 1, 31, "Input"],
Cell[37899, 658, 289, 5, 47, "Text"],
Cell[38191, 665, 245, 6, 31, "Input"],
Cell[38439, 673, 93, 2, 29, "Text"],
Cell[38535, 677, 109, 2, 31, "Input"],
Cell[38647, 681, 156, 3, 29, "Text"],
Cell[38806, 686, 262, 6, 31, "Input"],
Cell[39071, 694, 182, 4, 29, "Text"],
Cell[CellGroupData[{
Cell[39278, 702, 88, 2, 31, "Input"],
Cell[39369, 706, 8438, 143, 338, "Output"]
}, Open  ]],
Cell[47822, 852, 174, 3, 29, "Text"],
Cell[47999, 857, 89, 3, 31, "Input"],
Cell[48091, 862, 1113, 27, 192, "Input"],
Cell[49207, 891, 412, 7, 65, "Text"],
Cell[49622, 900, 335, 6, 31, "Input"],
Cell[49960, 908, 322, 9, 31, "Input"],
Cell[50285, 919, 479, 14, 47, "Input"],
Cell[50767, 935, 258, 5, 47, "Text"],
Cell[CellGroupData[{
Cell[51050, 944, 836, 21, 72, "Input"],
Cell[51889, 967, 1646, 32, 371, "Output"]
}, Open  ]],
Cell[53550, 1002, 89, 2, 29, "Text"],
Cell[53642, 1006, 57, 1, 31, "Input"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
