(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    280125,       6695]
NotebookOptionsPosition[    159766,       3473]
NotebookOutlinePosition[    236486,       5468]
CellTagsIndexPosition[    215286,       4972]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "MathFEMM 1.20\n\n",
 StyleBox["The Mathematica interface to FEMM 4.2", "Subsubtitle"],
 "\n",
 StyleBox["David Meeker\ndmeeker@ieee.org\n\nJanuary 26, 2006", "Subsubtitle"]
}], "Subtitle"],

Cell[CellGroupData[{

Cell["Installation and Setup", "Section"],

Cell["\<\
The MathFEMM package is automatically installed with FEMM 4.2. If you have \
accepted the default install for FEMM (to c:\\Program Files\\femm42) no \
further initialization is required. If you have installed FEMM to a different \
directory, you will need to perform an additional initialization step so that \
MathFEMM can find the FEMM executable:
1) Start up Mathematica.
2) Load the MathFEMM package from the installation directory with the command:
<<c:\\progra~1\\femm42\\mathfemm\\mathfemm.m
3) Run the SetPathToFEMM command to specify the path to the FEMM executable:
SetPathToFEMM[\"c:\\\\progra~1\\\\femm42\\\\bin\\\\femm.exe\"]
where you'd replace the above path withe the one to femm.exe in your \
installation.Be sure to use double backslashes in the path specification

USE:To start an MathFEMM session,first load up the MathFEMM package using the \
command:
<<c:\\progra~1\\femm42\\mathfemm\\mathfemm.m
You may need to change the path to mathfemm.m in the above call if you chose \
to install in a directory other than the default one.Then,use the OpenFEMM[] \
to automatically FEMM process and connect to it. Subsequent MathFEMM commands \
are sent to that instance of FEMM.When you are finished sending commands to \
FEMM,you can close down FEMM with the CloseFEMM[] function.There are a number \
of example notebooks of various MathFEMM analyses in the examples \
subdirectory. To run them,simply open up the notebooks and select \
Kernel|Evaluation|Evaluate Notebook off of the Mathematica main menu. The \
included notebook Usage.nb describes all MathFEMM commands in detail.\
\>", "Text",
 FontFamily->"Courier New"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Common Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"OpenFEMM[] starts an external instance of FEMM and \
establishes an associated MathLink connection.\"\>"], "Print",
 CellTags->"Info3347223940-6631621"],

Cell[BoxData["\<\"CloseFEMM[] shuts down the external instance of FEMM and \
closes the associated MathLink connection.\"\>"], "Print",
 CellTags->"Info3347223940-4294206"],

Cell[BoxData["\<\"NewDocument[doctype] creates a new preprocessor document \
and opens up a new preprocessor window in FEMM. Specify doctype to be 0 for a \
magnetics problem, 1 for an electrostatics problem, 2 for a heat flow \
problem, or 3 for a current flow problem. Alternate form is Create[doctype]\"\
\>"], "Print",
 CellTags->"Info3347223940-6810511"],

Cell[BoxData["\<\"OpenDocument[\\\"filename\\\"] opens a document specified \
by \\\"filename\\\".\"\>"], "Print",
 CellTags->"Info3347223940-7389295"],

Cell[BoxData["\<\"ShowPointProps[] displays the Point Properties \
dialog\"\>"], "Print",
 CellTags->"Info3347223940-2382490"],

Cell[BoxData["\<\"HidePointProps[] hides the Point Properties dialog from \
view\"\>"], "Print",
 CellTags->"Info3347223940-6023529"],

Cell[BoxData["\<\"ShowConsole[] displays the FEMM Lua console\"\>"], "Print",
 CellTags->"Info3347223940-6503571"],

Cell[BoxData["\<\"HideConsole[] hides the FEMM Lua console from view\"\>"], \
"Print",
 CellTags->"Info3347223940-5379615"],

Cell[BoxData["\<\"MessageBox[\\\"string\\\"] displays a pop-up messagebox \
with the message \\\"string\\\"\"\>"], "Print",
 CellTags->"Info3347223940-1834069"],

Cell[BoxData["\<\"Prompt[\\\"string\\\"] displays a pop-up dialog with the \
message \\\"string\\\" displayed on it with an edit box.  The return value of \
the funciton is the contents of the edit box.\"\>"], "Print",
 CellTags->"Info3347223940-7924268"],

Cell[BoxData["\<\"MLPut[\\\"string\\\"] sends \\\"string\\\" to FEMM's Lua \
interpreter via MathLink\"\>"], "Print",
 CellTags->"Info3347223940-7939632"],

Cell[BoxData["\<\"MLGet[] receives data from FEMM via MathLink.  The data is \
always in the form of a list, but the number of elements in the list is \
variable.  The items in the list could be either numbers or strings\"\>"], \
"Print",
 CellTags->"Info3347223940-6833855"],

Cell[BoxData["\<\"AWG[awg] returns the wire diameter in mm for the specified \
AWG gauge\"\>"], "Print",
 CellTags->"Info3347223940-1189387"],

Cell["MathFEMM`IEC", "Print",
 CellTags->"Info3347223940-1293541"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {GridBox[{
       {
        RowBox[{
         RowBox[{"IEC", "[", "MathFEMM`Private`iec_", "]"}], ":=", 
         RowBox[{"7.959159641581004`", " ", "MathFEMM`Private`exp", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "0.11519673572274754`"}], " ", 
            "MathFEMM`Private`iec"}], ")"}]}]}]}
      },
      BaselinePosition->{Baseline, {1, 1}},
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{"Columns" -> {{
           Scaled[0.999]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}}],
  Definition["IEC"],
  Editable->False]], "Print",
 CellTags->"Info3347223940-1293541"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrostatics Input Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EIAddBoundProp[\\\"boundpropname\\\", \
Vs,qs,c0,c1,BdryFormat] adds a new boundary property with name \
\\\"boundpropname\\\"\\n For a \\\"Fixed Temperature\\\" type boundary \
condition, set the Vs parameter to the desired voltage and all other \
parameters to zero.\\n To obtain a \\\"Mixed\\\" type boundary condition, set \
C1 and C0 as required and BdryFormat to 1. Set all other parameters to \
zero.\\n To obtain a prescribes surface charge density, set qs to the desired \
charge density in C/m2 and set BdryFormat to 2.\\n For a \\\"Periodic\\\" \
boundary condition, set BdryFormat to 3 and set all other parameters to zero.\
\\n For an \\\"Anti-Perodic\\\" boundary condition, set BdryFormat to 4 set \
all other parameters to zero.\"\>"], "Print",
 CellTags->"Info3347223940-8692552"],

Cell[BoxData["\<\"EIAddConductorProp[\\\"conductorname\\\",Vc,qc,\
conductortype] adds a new conductor property with name \\\"conductorname\\\" \
with either a prescribed voltage or a prescribed total charge. Set the unused \
property to zero. The conductortype parameter is 0 for prescribed charge and \
1 for prescribed voltage.\"\>"], "Print",
 CellTags->"Info3347223940-9972450"],

Cell[BoxData["\"\<EIGetMaterial[\\\"materialname\\\"] fetches the specified \
material from the materials library.\>"], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.496193361170231*^9, 3.4961933882938423`*^9}},
 CellTags->"Info3347223940-9972450"],

Cell[BoxData["\<\"EIAddMaterial[\\\"materialname\\\",ex,ey,qv] adds a new \
material with called \\\"materialname\\\" with the material properties:\\n ex \
Relative permittivity in the x- or r-direction.\\n ey Relative permittivity \
in the y- or z-direction.\\n qv Volume charge density in units of \
C/m^3\"\>"], "Print",
 CellTags->"Info3347223940-4605738"],

Cell[BoxData["\<\"EIAddPointProp[\\\"pointpropname\\\",Vp,qp] adds a new \
point property of name \\\"pointpropname\\\" with either a specified \
potential Vp a point charge density qp in units of C/m.\"\>"], "Print",
 CellTags->"Info3347223940-4732625"],

Cell[BoxData["\<\"EIModifyBoundProp[\\\"BdryName\\\",propnum,value] allows \
for modification of a boundary property. The BC to be modified is specified \
by \\\"BdryName\\\". The next parameter is the number of the property to be \
set. The last number is the value to be applied to the specified property. \
The various properties that can be modified are listed below:\\n 0 - \
\\\"BdryName\\\" - Name of boundary property\\n 1 - Vs - Fixed Voltage\\n 2 - \
qs - Prescribed charge density\\n 3 - c0 - Mixed BC parameter\\n 4 - c1 - \
Mixed BC parameter\\n 5 - BdryFormat -  Type of boundary condition (0 = \
Prescribed V; 1 = Mixed; 2 = Surface charge density; 3 = Periodic; 4 = \
Antiperiodic)\"\>"], "Print",
 CellTags->"Info3347223940-4167237"],

Cell[BoxData["\<\"EIModifyConductorProp[\\\"ConductorName\\\",propnum,value] \
allows for modification of a conductor property. The conductor property to be \
modified is specified by \\\"ConductorName\\\". The next parameter is the \
number of the property to be set. The last number is the value to be applied \
to the specified property. The various properties that can be modified are \
listed below:\\n 0 - \\\"ConductorName\\\" - Name of the conductor \
property\\n 1 - Vc - Conductor voltage\\n 2 - qc - Total conductor charge\\n \
3 - ConductorType - 0 = Prescribed charge, 1 = Prescribed voltage\"\>"], \
"Print",
 CellTags->"Info3347223940-9087758"],

Cell[BoxData["\<\"EIModifyMaterial[\\\"BlockName\\\",propnum,value] allows \
for modification of a material's properties without redefining the entire \
material (e.g. so that current can be modified from run to run). The material \
to be modified is specified by \\\"BlockName\\\". The next parameter is the \
number of the property to be set. The last number is the value to be applied \
to the specified property. The various properties that can be modified are \
listed below:\\n 0 - \\\"BlockName\\\" - Name of the material 1 - ex - x (or \
r) direction relative permittivity 2 - ey - y (or z) direction relative \
permittivity 3 - qs - Volume charge\"\>"], "Print",
 CellTags->"Info3347223940-5926772"],

Cell[BoxData["\<\"EIModifyPointProp[\\\"PointName\\\",propnum,value] allows \
for modification of a point property. The point property to be modified is \
specified by \\\"PointName\\\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\\n 0 - PointName - Name of the point property\\n 1 - Vp - Prescribed \
nodal voltage\\n 2 - qp - Point charge density in C/m\"\>"], "Print",
 CellTags->"Info3347223940-8501482"],

Cell[BoxData["\<\"EIDeleteBoundProp[\\\"boundpropname\\\"] deletes the \
boundary property named \\\"boundpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223940-7144037"],

Cell[BoxData["\<\"EIDeleteConductor[\\\"conductorname\\\"] deletes the \
conductor property named \\\"conductorname\\\".\"\>"], "Print",
 CellTags->"Info3347223940-2011507"],

Cell[BoxData["\<\"EIDeleteMaterial[\\\"materialname\\\"] deletes the material \
property named \\\"materialname\\\".\"\>"], "Print",
 CellTags->"Info3347223940-6339513"],

Cell[BoxData["\<\"EIDeletePointProp[\\\"pointpropname\\\"] deletes the point \
property named \\\"pointpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223940-5174597"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
electrostatics input geometry from the point nearst to {x1,y1} to the point \
nearest to {x2,y2}.  The arc spans a number of degrees specified by angle. \
Since FEMM approximates arcs by many line segments, the parameter maxseg \
specifies the maximum number of degrees that is allowed to be spanned by any \
one segment. Equivalent forms are:\\n \
EIAddArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
EIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223940-1062849"],

Cell[BoxData["\<\"EIAddBlockLabel[x,y] adds a block label at the point {x,y}. \
 An equivalent form is:\\n EIAddBlockLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223940-3542961"],

Cell[BoxData["\<\"EIAddNode[x,y] adds a new node at {x,y}. An equivalent form \
is:\\n EIAddNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223940-1600426"],

Cell[BoxData["\<\"EIAddSegment[x1,y1,x2,y2] add a new line segment from node \
closest to {x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\\n \
EIAddSegment[{x1,y1},{x2,y2}]\\n EIAddSegment[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223940-4337716"],

Cell[BoxData["\<\"EIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
electrostatics input geometry by drawing points at {x1,y1} and {x2,y2} and \
then connecting them with an arc segment. The arc spans a number of degrees \
specified by angle. Since FEMM approximates arcs by many line segments, the \
parameter maxseg specifies the maximum number of degrees that is allowed to \
be spanned by any one segment. Equivalent forms are:\\n \
EIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
EIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223941-1813366"],

Cell[BoxData["\<\"EIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} \
and then adds a segment connecting these two points.  Equivalent forms \
are:\\n EIDrawLine[{x1,y1},{x2,y2}]\\n EIDrawLine[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223941-1118594"],

Cell[BoxData["\<\"EIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points \
at every listed point and then draws a closed figure that connects the points\
\"\>"], "Print",
 CellTags->"Info3347223941-5737972"],

Cell[BoxData["\<\"EIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment \
line by adding each of the points in the list and then adding segments that \
join the listed points.\"\>"], "Print",
 CellTags->"Info3347223941-7410441"],

Cell[BoxData["\<\"EIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, \
{x1,y2}, {x2,y2} and  {x2,y1} and joins them with new segments.  Equivalent \
forms are:\\n EIDrawRectangle[{x1,y1},{x2,y2}]\\n \
EIDrawRectangle[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223941-8640170"],

Cell[BoxData["\<\"EICreateRadius[x,y,z] turns a corner located at {x,y} into \
a curve of radius r.\\n An equivalent form is: EICreateRadius[{x,y},z]\"\>"], \
"Print",
 CellTags->"Info3347223941-1951187"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EISelectArcSegment[x,y] selects the arc segment closest to \
{x,y}.  An equivalent form is:\\n EISelectArcSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-8197922"],

Cell[BoxData["\<\"EISelectGroup[n] selects the nth group of nodes, segments, \
arc segments and block labels. This function will clear all previously \
selected elements and leave the edit mode in 4 (group)\"\>"], "Print",
 CellTags->"Info3347223941-2611265"],

Cell[BoxData["\<\"EISelectLabel[x,y] selects the block label closest to \
{x,y}.  An equivalent form is:\\n EISelectLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-9442840"],

Cell[BoxData["\<\"EISelectNode[x,y] selects the node closest to {x,y}.  An \
equivalent form is:\\n EISelectNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-7245219"],

Cell[BoxData["\<\"EISelectSegment[x,y] selects the segment closest to {x,y}.  \
An equivalent form is:\\n EISelectSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-5798128"],

Cell[BoxData["\<\"EISetArcSegmentProp[maxsegdeg, \\\"propname\\\", hide, \
groupno,\\\"inconductor\\\"] sets the properties associated with the selected \
arc segments\\n maxsegdeg specifies that the arcs must be meshed with \
elements that span at most maxsegdeg degrees per element\\n \\\"propname\\\" \
specifies the boundary property to be associated with the selected arcs\\n \
hide: 0 = not hidden in post-processor, 1 == hidden in post processor\\n \
groupno is an integer specifying the group number of which the selected arcs \
are to be members.\\n \\\"inconductor\\\" specifies the name of the conductor \
property with which the selected arcs are to be associated. If the arcs is \
not to be part of a conductor, this parameter can be specified as \
\\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223941-1459018"],

Cell[BoxData["\<\"EISetBlockProp[\\\"blockname\\\",automesh,meshsize,groupno] \
sets the selected block labels to have the properties:\\n Block property \
\\\"blockname\\\".\\n automesh: 0 = mesher defers to mesh size constraint \
defined in meshsize, 1 = mesher automatically chooses the mesh density.\\n \
meshsize: size constraint on the mesh in the block marked by this label\\n. \
groupno: make selected members of specified group number\"\>"], "Print",
 CellTags->"Info3347223941-1589458"],

Cell[BoxData["\<\"EISetNodeProp[\\\"propname\\\",groupno,\\\"inconductor\\\"] \
sets the selected nodes to have the nodal property \\\"propname\\\" and group \
number groupno. The \\\"inconductor\\\" string specifies which conductor the \
node belongs to. If the node doesn\[CloseCurlyQuote]t belong to a named \
conductor, this parameter can be set to \\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223941-8534708"],

Cell[BoxData["\<\"EISetSegmentProp[\\\"propname\\\",elementsize,automesh,hide,\
groupno,\\\"inconductor\\\"] sets the select segments to have:\\n Boundary \
property \\\"propname\\\"\\n Local element size along segment no greater than \
elementsize\\n automesh: 0 = mesher defers to the element constraint defined \
by elementsize, 1 = mesher automatically chooses mesh size along the selected \
segments\\n hide: 0 = not hidden in post-processor, 1 == hidden in post \
processor\\n A member of group number groupno\\n A member of the conductor \
specified by the string \\\"inconductor\\\". If the segment is not part of a \
conductor, this parameter can be specified as \\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223941-7553760"],

Cell[BoxData["\<\"EIDeleteSelected[] deletes all selected objects.\"\>"], \
"Print",
 CellTags->"Info3347223941-9188284"],

Cell[BoxData["\<\"EIDeleteSelectedArcSegments[] deletes all selected arc \
segments.\"\>"], "Print",
 CellTags->"Info3347223941-7542695"],

Cell[BoxData["\<\"EIDeleteSelectedLabels[] deletes all selected block labels.\
\"\>"], "Print",
 CellTags->"Info3347223941-2715154"],

Cell[BoxData["\<\"EIDeleteSelectedNodes[] deletes all selected nodes.\"\>"], \
"Print",
 CellTags->"Info3347223941-2795720"],

Cell[BoxData["\<\"EIDeleteSelectedSegments[] deletes all selected segments.\"\
\>"], "Print",
 CellTags->"Info3347223941-9823357"],

Cell[BoxData["\<\"EIClearSelected[] clear all selected nodes, blocks, \
segments and arc segments.\"\>"], "Print",
 CellTags->"Info3347223941-8020983"],

Cell[BoxData["\<\"EIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric \
external region to be used in conjuction with the Kelvin Transformation \
method of modeling unbounded problems.  The Zo parameter is the z-location of \
the origin of the outer region, the Ro parameter is the radius of the outer \
region, and the Ri parameter is the radius of the inner region (i.e. the \
region of interest). In the exterior region, the permeability varies as a \
function of distance from the origin of the external region.  These \
parameters are necessary to define the permeability variation in the external \
region.\"\>"], "Print",
 CellTags->"Info3347223941-4999920"],

Cell[BoxData["\<\"EIAttachOuterSpace[] marks all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223941-6637905"],

Cell[BoxData["\<\"EIDetachOuterSpace[] undefines all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223941-9601905"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move, Copy, Scale", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EICopyRotate[bx,by,angle,copies,(editaction)]\\n bx, by \
base point for rotation\\n angle angle by which the selected objects are \
incrementally shifted to make each copy. This angle is measured in \
degrees.\\n copies number of copies to be produced from the selected objects \
\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\\n An \
equivalent form is:\\n EICopyRotate[{bx,by},angle,copies,(editaction)]\"\>"], \
"Print",
 CellTags->"Info3347223941-1464798"],

Cell[BoxData["\<\"EICopyTranslate[dx,dy,copies,(editaction)]\\n {dx,dy} \
represents the distance by which the selected objects are to be incrementally \
shifted.\\n copies specifies the number of copoies to be produced from the \
selected objects\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, \
4-group\\n An equivalent form is:\\n \
EICopyTranslate[{dx,dy},copies,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-1770110"],

Cell[BoxData["\<\"EIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected \
objects about a line passing through the points (x1,y1) and (x2,y2). Valid \
editaction entries are 0 for nodes, 1 for lines (segments), 2 for block \
labels, 3 for arc segments, and 4 for groups. Equivalent forms are:\\n \
EIMirror[{x1,y1},{x2,y2},(editaction)]\\n \
EIMirror[{{x1,y1},{x2,y2}},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-2471642"],

Cell[BoxData["\<\"EIMoveRotate[bx,by,shiftangle,(editaction)]\\n bx, by \
\[Dash] base point for rotation\\n shiftangle \[Dash] angle in degrees by \
which the selected objects are rotated.\\n editaction - 0  \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent form is:\\n \
EIMoveRotate[{bx,by},shiftangle,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-7586356"],

Cell[BoxData["\<\"EIMoveTranslate[dx,dy,(editaction)]\\n dx,dy \[Dash] \
distance by which the selected objects are shifted.\\n editaction - 0 \
\[Dash]nodes, 1 \[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] \
arc segments, 4- group\\n An equivalent form is:\\n \
EIMoveTranslate[{dx,dy},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-4155620"],

Cell[BoxData["\<\"EIScale[bx,by,scalefactor,(editaction)]\\n bx, by \[Dash] \
base point for scaling\\n scalefactor \[Dash] a multiplier that determines \
how much the selected objects are scaled\\n editaction 0 \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent for is: \
EIScale[{bx,by},scalefactor,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-3197855"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EISetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the \
\\\"type\\\" parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\
\"polar\\\" for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223941-8920274"],

Cell[BoxData["\<\"EIShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223941-2580618"],

Cell[BoxData["\<\"EIHideGrid[] hides the electrostatics input grid \
points\"\>"], "Print",
 CellTags->"Info3347223941-5009207"],

Cell[BoxData["\<\"EIShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223941-1486463"],

Cell[BoxData["\<\"EIPurgeMesh[] clears the mesh out of both the screen and \
memory.\"\>"], "Print",
 CellTags->"Info3347223941-2487122"],

Cell[BoxData["\<\"EIShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223941-6450972"],

Cell[BoxData["\<\"EIHideNames[] stops the names of the materials associated \
with each block label from being displayed\"\>"], "Print",
 CellTags->"Info3347223941-4162216"],

Cell[BoxData["\<\"EISnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223941-6354640"],

Cell[BoxData["\<\"EISnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223941-5746827"],

Cell[BoxData["\<\"EIZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n EIZoom[{x1,y1},{x2,y2}]\\n \
EIZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223941-2691935"],

Cell[BoxData["\<\"EIZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223941-7877067"],

Cell[BoxData["\<\"EIZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223941-7749989"],

Cell[BoxData["\<\"EIZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223941-3231106"],

Cell[BoxData["\<\"EIGetView[] grabs the current electrostatics input view and \
returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223941-3377092"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EIAnalyze[(flag)] runs the electrostatics solver. The flag \
parameter controls whether the solver window is visible or minimized. For a \
visible window, either specify no value for flag or specify 0. For a \
minimized window, flag should be set to 1. An equivalent form is:\\n \
EIAnalyse[(flag)]\"\>"], "Print",
 CellTags->"Info3347223941-4876077"],

Cell[BoxData["\<\"EIClose[] closes the preprocessor window and destroys the \
current document.\"\>"], "Print",
 CellTags->"Info3347223941-3439479"],

Cell[BoxData["\<\"EICreateMesh[] runs triangle to create a mesh. Note that \
this is not a necessary precursor of performing an analysis, as EIAnalyze[] \
will make sure the mesh is up to date before running an analysis.\"\>"], \
"Print",
 CellTags->"Info3347223941-7653090"],

Cell[BoxData["\<\"EILoadSolution[] loads and displays the solution \
corresponding to the current geometry.\"\>"], "Print",
 CellTags->"Info3347223941-7874582"],

Cell[BoxData["\<\"EIProbDef[units,type,precision,depth,minangle] changes the \
problem definition. The units parameter specifies the units used for \
measuring length in the problem domain. Valid \\\"units\\\" entries are \
\\\"inches\\\", \\\"millimeters\\\", \\\"centimeters\\\", \\\"mils\\\", \
\\\"meters\\\", and \\\"micrometers\\\". Set problemtype to \\\"planar\\\" \
for a 2-D planar problem, or to \\\"axi\\\" for an axisymmetric problem. The \
precision parameter dictates the precision required by the solver. For \
example, specifying 1.E-8 requires the RMS of the residual to be less than \
10^(-8). The depth parameter, represents the depth of the problem in the \
into-the-page direction for 2-D planar problems. The minangle parameter is a \
constraint for the mesh generator. It specifies the smallest permissible \
angle in triangles that compose the finite element mesh. A good value to \
choose is 30 degrees, but smaller values may be needed for \\\"tough\\\" \
geometries that contain small angles.\"\>"], "Print",
 CellTags->"Info3347223941-5235115"],

Cell[BoxData["\<\"EIReadDXF[\\\"filename\\\"] reads in geometry information a \
DXF file specified by \\\"filename\\\"\"\>"], "Print",
 CellTags->"Info3347223941-7704576"],

Cell[BoxData["\<\"EIRefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223941-4043808"],

Cell[BoxData["\<\"EISaveAs[\\\"filename\\\"] saves the file with name \
\\\"filename\\\". Note if you use a path you must use two backslashes e.g. \\\
\"c:\\\\\\\\temp\\\\\\\\myfemmfile.fem\\\"\"\>"], "Print",
 CellTags->"Info3347223941-3418109"],

Cell[BoxData["\<\"EISaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the EISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223941-6580237"],

Cell[BoxData["\<\"EISaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the EISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223941-6852624"],

Cell[BoxData["\<\"EISetEditMode[\\\"editmode\\\"] sets the current editmode \
to:\\n \\\"nodes\\\" \[Dash] nodes\\n \\\"segments\\\" - line segments\\n \
\\\"arcsegments\\\" - arc segments\\n \\\"blocks\\\" - block labels\\n \
\\\"group\\\" - selected group\\n This command will affect all subsequent \
uses of the other editing commands, if they are used without the editaction \
parameter.\"\>"], "Print",
 CellTags->"Info3347223941-1422078"],

Cell[BoxData["\<\"EISetFocus[\\\"documentname\\\"] switches the \
electrostatics input file upon which scripting commands are to act. If more \
than one electrostatics input file is being edited at a time, this command \
can be used to switch between files so that the mutiple files can be operated \
upon programmatically . \\\"documentname\\\" should contain the name of the \
desired document as it appears on the window\[CloseCurlyQuote]s title \
bar.\"\>"], "Print",
 CellTags->"Info3347223941-2029304"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heat Flow Input Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HIAddBoundProp[\\\"boundpropname\\\", BdryFormat, Tset, qs, \
Tinf, h, beta] adds a new boundary property with name \
\\\"boundpropname\\\"\\n For a \\\"Fixed Temperature\\\" type boundary \
condition, set the Tset parameter to the desired temperature and all other \
parameters to zero.\\n To obtain a \\\"Heat Flux\\\" type boundary condition, \
set qs to be the heat flux density and BdryFormat to 1. Set all other \
parameters to zero.\\n To obtain a convection boundary condition, set h to \
the desired heat transfer coefficient and Tinf to the desired external \
temperature and set BdryFormat to 2.\\n For a Radiation boundary condition, \
set beta equal to the desired emmissivity and Tinf to the  desired external \
temperature and set BdryFormat to 3.\\n For a \\\"Periodic\\\" boundary \
condition, set BdryFormat to 4 and set all other parameters to zero.\\n For \
an \\\"Anti-Perodic\\\" boundary condition, set BdryFormat to 5 set all other \
parameters to zero.\"\>"], "Print",
 CellTags->"Info3347223941-8989917"],

Cell[BoxData["\"\<HIGetMaterial[\\\"materialname\\\"] fetches the specified \
material from the materials library.\>"], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.496193361170231*^9, 3.49619341030834*^9}},
 CellTags->"Info3347223940-9972450"],

Cell[BoxData["\<\"HIAddConductorProp[\\\"conductorname\\\",Tc,qc,\
conductortype] adds a new conductor property with name \\\"conductorname\\\" \
with either a prescribed temperature or a prescribed total heat flux. Set the \
unused property to zero. The conductortype parameter is 0 for prescribed \
charge and 1 for prescribed temperature.\"\>"], "Print",
 CellTags->"Info3347223941-3552733"],

Cell[BoxData["\<\"HIAddMaterial[\\\"materialname\\\",Kx,Ky,qv] adds a new \
material with called \\\"materialname\\\" with the material properties:\\n Kx \
Thermal conductivity in the x- or r-direction.\\n Ky Thermal conductivity in \
the y- or z-direction.\\n qv Volume heat generation density in units of J/m^3\
\"\>"], "Print",
 CellTags->"Info3347223941-6176457"],

Cell[BoxData["\<\"HIAddPointProp[\\\"pointpropname\\\",Tp,qp] adds a new \
point property of name \\\"pointpropname\\\" with either a specified \
temperature Tp or point heat generation qp in units of J/m.\"\>"], "Print",
 CellTags->"Info3347223941-8109493"],

Cell[BoxData["\<\"HIModifyBoundProp[\\\"BdryName\\\",propnum,value] allows \
for modification of a boundary property. The BC to be modified is specified \
by \\\"BdryName\\\". The next parameter is the number of the property to be \
set. The last number is the value to be applied to the specified property. \
The various properties that can be modified are listed below:\\n 0 - \
\\\"BdryName\\\" - Name of boundary property\\n 1 - BdryFormat -  Type of \
boundary condition (0 = Prescribed Temperature; 1 = Heat Flux; 2 = \
Convection; 3 = Radiation; 4 = Periodic; 5 = Antiperiodic) 2 - Tset - Fixed \
Temperature\\n 3 - qs - Prescribed heat flux density\\n 4 - Tinf - External \
temperature\\n 5 - h - heat transfer coefficient\\n 6 - beta - \
emmissivity\"\>"], "Print",
 CellTags->"Info3347223941-6089851"],

Cell[BoxData["\<\"HIModifyConductorProp[\\\"ConductorName\\\",propnum,value] \
allows for modification of a conductor property. The conductor property to be \
modified is specified by \\\"ConductorName\\\". The next parameter is the \
number of the property to be set. The last number is the value to be applied \
to the specified property. The various properties that can be modified are \
listed below:\\n 0 - \\\"ConductorName\\\" - Name of the conductor \
property\\n 1 - Tc - Conductor Temperature\\n 2 - qc - Total conductor heat \
flux\\n 3 - ConductorType - 0 = Prescribed heat flow, 1 = Prescribed \
temperature\"\>"], "Print",
 CellTags->"Info3347223941-7134049"],

Cell[BoxData["\<\"HIModifyMaterial[\\\"BlockName\\\",propnum,value] allows \
for modification of a material's properties without redefining the entire \
material (e.g. so that current can be modified from run to run). The material \
to be modified is specified by \\\"BlockName\\\". The next parameter is the \
number of the property to be set. The last number is the value to be applied \
to the specified property. The various properties that can be modified are \
listed below:\\n 0 - \\\"BlockName\\\" - Name of the material 1 - Kx - x (or \
r) direction thermal conductivity 2 - Ky - y (or z) direction thermal \
conductivity 3 - qv - Volume heat generation\"\>"], "Print",
 CellTags->"Info3347223941-7244468"],

Cell[BoxData["\<\"HIModifyPointProp[\\\"PointName\\\",propnum,value] allows \
for modification of a point property. The point property to be modified is \
specified by \\\"PointName\\\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\\n 0 - PointName - Name of the point property\\n 1 - Tp - Prescribed \
nodal temperature\\n 2 - qp - Point heat generation in C/m\"\>"], "Print",
 CellTags->"Info3347223941-4415755"],

Cell[BoxData["\<\"HIDeleteBoundProp[\\\"boundpropname\\\"] deletes the \
boundary property named \\\"boundpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-9094170"],

Cell[BoxData["\<\"HIDeleteConductor[\\\"conductorname\\\"] deletes the \
conductor property named \\\"conductorname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-3611725"],

Cell[BoxData["\<\"HIDeleteMaterial[\\\"materialname\\\"] deletes the material \
property named \\\"materialname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-9967462"],

Cell[BoxData["\<\"HIDeletePointProp[\\\"pointpropname\\\"] deletes the point \
property named \\\"pointpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-4309295"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
electrostatics input geometry from the point nearst to {x1,y1} to the point \
nearest to {x2,y2}.  The arc spans a number of degrees specified by angle. \
Since FEMM approximates arcs by many line segments, the parameter maxseg \
specifies the maximum number of degrees that is allowed to be spanned by any \
one segment. Equivalent forms are:\\n \
HIAddArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
HIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223941-8260624"],

Cell[BoxData["\<\"HIAddBlockLabel[x,y] adds a block label at the point {x,y}. \
 An equivalent form is:\\n HIAddBlockLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-8492284"],

Cell[BoxData["\<\"HIAddNode[x,y] adds a new node at {x,y}. An equivalent form \
is:\\n HIAddNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-8438704"],

Cell[BoxData["\<\"HIAddSegment[x1,y1,x2,y2] add a new line segment from node \
closest to {x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\\n \
HIAddSegment[{x1,y1},{x2,y2}]\\n HIAddSegment[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223941-3285558"],

Cell[BoxData["\<\"HIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the heat \
flow input geometry by drawing points at {x1,y1} and {x2,y2} and then \
connecting them with an arc segment. The arc spans a number of degrees \
specified by angle. Since FEMM approximates arcs by many line segments, the \
parameter maxseg specifies the maximum number of degrees that is allowed to \
be spanned by any one segment. Equivalent forms are:\\n \
HIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
HIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223941-1354509"],

Cell[BoxData["\<\"HIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} \
and then adds a segment connecting these two points.  Equivalent forms \
are:\\n HIDrawLine[{x1,y1},{x2,y2}]\\n HIDrawLine[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223941-1355904"],

Cell[BoxData["\<\"HIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points \
at every listed point and then draws a closed figure that connects the points\
\"\>"], "Print",
 CellTags->"Info3347223941-8370622"],

Cell[BoxData["\<\"HIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment \
line by adding each of the points in the list and then adding segments that \
join the listed points.\"\>"], "Print",
 CellTags->"Info3347223941-2291614"],

Cell[BoxData["\<\"HIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, \
{x1,y2}, {x2,y2} and  {x2,y1} and joins them with new segments.  Equivalent \
forms are:\\n HIDrawRectangle[{x1,y1},{x2,y2}]\\n \
HIDrawRectangle[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223941-7771765"],

Cell[BoxData["\<\"EICreateRadius[x,y,z] turns a corner located at {x,y} into \
a curve of radius r.\\n An equivalent form is: EICreateRadius[{x,y},z]\"\>"], \
"Print",
 CellTags->"Info3347223941-7568170"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HISelectArcSegment[x,y] selects the arc segment closest to \
{x,y}.  An equivalent form is:\\n HISelectArcSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-5343679"],

Cell[BoxData["\<\"HISelectGroup[n] selects the nth group of nodes, segments, \
arc segments and block labels. This function will clear all previously \
selected elements and leave the edit mode in 4 (group)\"\>"], "Print",
 CellTags->"Info3347223941-5864838"],

Cell[BoxData["\<\"HISelectLabel[x,y] selects the block label closest to \
{x,y}.  An equivalent form is:\\n HISelectLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-7809650"],

Cell[BoxData["\<\"HISelectNode[x,y] selects the node closest to {x,y}.  An \
equivalent form is:\\n HISelectNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-2458221"],

Cell[BoxData["\<\"HISelectSegment[x,y] selects the segment closest to {x,y}.  \
An equivalent form is:\\n HISelectSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-1974298"],

Cell[BoxData["\<\"HISetArcSegmentProp[maxsegdeg, \\\"propname\\\", hide, \
groupno,\\\"inconductor\\\"] sets the properties associated with the selected \
arc segments\\n maxsegdeg specifies that the arcs must be meshed with \
elements that span at most maxsegdeg degrees per element\\n \\\"propname\\\" \
specifies the boundary property to be associated with the selected arcs\\n \
hide: 0 = not hidden in post-processor, 1 == hidden in post processor\\n \
groupno is an integer specifying the group number of which the selected arcs \
are to be members.\\n \\\"inconductor\\\" specifies the name of the conductor \
property with which the selected arcs are to be associated. If the arcs is \
not to be part of a conductor, this parameter can be specified as \
\\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223941-7595909"],

Cell[BoxData["\<\"HISetBlockProp[\\\"blockname\\\",automesh,meshsize,groupno] \
sets the selected block labels to have the properties:\\n Block property \
\\\"blockname\\\".\\n automesh: 0 = mesher defers to mesh size constraint \
defined in meshsize, 1 = mesher automatically chooses the mesh density.\\n \
meshsize: size constraint on the mesh in the block marked by this label\\n. \
groupno: make selected members of specified group number\"\>"], "Print",
 CellTags->"Info3347223941-2077596"],

Cell[BoxData["\<\"HISetNodeProp[\\\"propname\\\",groupno,\\\"inconductor\\\"] \
sets the selected nodes to have the nodal property \\\"propname\\\" and group \
number groupno. The \\\"inconductor\\\" string specifies which conductor the \
node belongs to. If the node doesn\[CloseCurlyQuote]t belong to a named \
conductor, this parameter can be set to \\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223941-6833115"],

Cell[BoxData["\<\"HISetSegmentProp[\\\"propname\\\",elementsize,automesh,hide,\
groupno,\\\"inconductor\\\"] sets the select segments to have:\\n Boundary \
property \\\"propname\\\"\\n Local element size along segment no greater than \
elementsize\\n automesh: 0 = mesher defers to the element constraint defined \
by elementsize, 1 = mesher automatically chooses mesh size along the selected \
segments\\n hide: 0 = not hidden in post-processor, 1 == hidden in post \
processor\\n A member of group number groupno\\n A member of the conductor \
specified by the string \\\"inconductor\\\". If the segment is not part of a \
conductor, this parameter can be specified as \\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223941-8415350"],

Cell[BoxData["\<\"HIDeleteSelected[] deletes all selected objects.\"\>"], \
"Print",
 CellTags->"Info3347223941-7920837"],

Cell[BoxData["\<\"HIDeleteSelectedArcSegments[] deletes all selected arc \
segments.\"\>"], "Print",
 CellTags->"Info3347223941-5070483"],

Cell[BoxData["\<\"HIDeleteSelectedLabels[] deletes all selected block labels.\
\"\>"], "Print",
 CellTags->"Info3347223941-1032206"],

Cell[BoxData["\<\"HIDeleteSelectedNodes[] deletes all selected nodes.\"\>"], \
"Print",
 CellTags->"Info3347223941-1376349"],

Cell[BoxData["\<\"HIDeleteSelectedSegments[] deletes all selected segments.\"\
\>"], "Print",
 CellTags->"Info3347223941-7407861"],

Cell[BoxData["\<\"HIClearSelected[] clear all selected nodes, blocks, \
segments and arc segments.\"\>"], "Print",
 CellTags->"Info3347223941-2948475"],

Cell[BoxData["\<\"HIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric \
external region to be used in conjuction with the Kelvin Transformation \
method of modeling unbounded problems.  The Zo parameter is the z-location of \
the origin of the outer region, the Ro parameter is the radius of the outer \
region, and the Ri parameter is the radius of the inner region (i.e. the \
region of interest). In the exterior region, the permeability varies as a \
function of distance from the origin of the external region.  These \
parameters are necessary to define the permeability variation in the external \
region.\"\>"], "Print",
 CellTags->"Info3347223941-8742318"],

Cell[BoxData["\<\"HIAttachOuterSpace[] marks all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223941-9656730"],

Cell[BoxData["\<\"HIDetachOuterSpace[] undefines all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223941-1145073"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move, Copy, Scale", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HICopyRotate[bx,by,angle,copies,(editaction)]\\n bx, by \
base point for rotation\\n angle angle by which the selected objects are \
incrementally shifted to make each copy. This angle is measured in \
degrees.\\n copies number of copies to be produced from the selected objects \
\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\\n An \
equivalent form is:\\n HICopyRotate[{bx,by},angle,copies,(editaction)]\"\>"], \
"Print",
 CellTags->"Info3347223941-4193583"],

Cell[BoxData["\<\"HICopyTranslate[dx,dy,copies,(editaction)]\\n {dx,dy} \
represents the distance by which the selected objects are to be incrementally \
shifted.\\n copies specifies the number of copoies to be produced from the \
selected objects\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, \
4-group\\n An equivalent form is:\\n \
HICopyTranslate[{dx,dy},copies,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-6993551"],

Cell[BoxData["\<\"HIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected \
objects about a line passing through the points (x1,y1) and (x2,y2). Valid \
editaction entries are 0 for nodes, 1 for lines (segments), 2 for block \
labels, 3 for arc segments, and 4 for groups. Equivalent forms are:\\n \
HIMirror[{x1,y1},{x2,y2},(editaction)]\\n \
HIMirror[{{x1,y1},{x2,y2}},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-6453383"],

Cell[BoxData["\<\"HIMoveRotate[bx,by,shiftangle,(editaction)]\\n bx, by \
\[Dash] base point for rotation\\n shiftangle \[Dash] angle in degrees by \
which the selected objects are rotated.\\n editaction - 0  \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent form is:\\n \
HIMoveRotate[{bx,by},shiftangle,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-7559587"],

Cell[BoxData["\<\"HIMoveTranslate[dx,dy,(editaction)]\\n dx,dy \[Dash] \
distance by which the selected objects are shifted.\\n editaction - 0 \
\[Dash]nodes, 1 \[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] \
arc segments, 4- group\\n An equivalent form is:\\n \
HIMoveTranslate[{dx,dy},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-5358822"],

Cell[BoxData["\<\"HIScale[bx,by,scalefactor,(editaction)]\\n bx, by \[Dash] \
base point for scaling\\n scalefactor \[Dash] a multiplier that determines \
how much the selected objects are scaled\\n editaction 0 \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent for is: \
HIScale[{bx,by},scalefactor,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223941-6682568"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HISetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the \
\\\"type\\\" parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\
\"polar\\\" for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223941-3512651"],

Cell[BoxData["\<\"HIShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223941-8850662"],

Cell[BoxData["\<\"HIHideGrid[] hides the heat flow input grid points\"\>"], \
"Print",
 CellTags->"Info3347223941-7730051"],

Cell[BoxData["\<\"HIShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223941-2942451"],

Cell[BoxData["\<\"HIPurgeMesh[] clears the mesh out of both the screen and \
memory.\"\>"], "Print",
 CellTags->"Info3347223941-3089129"],

Cell[BoxData["\<\"HIShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223941-3186031"],

Cell[BoxData["\<\"HIHideNames[] stops the names of the materials associated \
with each block label from being displayed\"\>"], "Print",
 CellTags->"Info3347223941-4802215"],

Cell[BoxData["\<\"HISnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223941-8163804"],

Cell[BoxData["\<\"HISnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223941-6931229"],

Cell[BoxData["\<\"HIZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n HIZoom[{x1,y1},{x2,y2}]\\n \
HIZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223941-9964984"],

Cell[BoxData["\<\"HIZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223941-4270299"],

Cell[BoxData["\<\"HIZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223941-7308454"],

Cell[BoxData["\<\"HIZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223941-7750860"],

Cell[BoxData["\<\"HIGetView[] grabs the current heat flow input view and \
returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223941-3895549"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HIAnalyze[(flag)] runs the heat flow solver. The flag \
parameter controls whether the solver window is visible or minimized. For a \
visible window, either specify no value for flag or specify 0. For a \
minimized window, flag should be set to 1. An equivalent form is:\\n \
HIAnalyse[(flag)]\"\>"], "Print",
 CellTags->"Info3347223941-4236356"],

Cell[BoxData["\<\"HIClose[] closes the preprocessor window and destroys the \
current document.\"\>"], "Print",
 CellTags->"Info3347223941-2245144"],

Cell[BoxData["\<\"HICreateMesh[] runs triangle to create a mesh. Note that \
this is not a necessary precursor of performing an analysis, as HIAnalyze[] \
will make sure the mesh is up to date before running an analysis.\"\>"], \
"Print",
 CellTags->"Info3347223941-8159017"],

Cell[BoxData["\<\"HILoadSolution[] loads and displays the solution \
corresponding to the current geometry.\"\>"], "Print",
 CellTags->"Info3347223941-8125029"],

Cell[BoxData["\<\"HIProbDef[units,type,precision,depth,minangle] changes the \
problem definition. The units parameter specifies the units used for \
measuring length in the problem domain. Valid \\\"units\\\" entries are \
\\\"inches\\\", \\\"millimeters\\\", \\\"centimeters\\\", \\\"mils\\\", \
\\\"meters\\\", and \\\"micrometers\\\". Set problemtype to \\\"planar\\\" \
for a 2-D planar problem, or to \\\"axi\\\" for an axisymmetric problem. The \
precision parameter dictates the precision required by the solver. For \
example, specifying 1.E-8 requires the RMS of the residual to be less than \
10^(-8). The depth parameter, represents the depth of the problem in the \
into-the-page direction for 2-D planar problems. The minangle parameter is a \
constraint for the mesh generator. It specifies the smallest permissible \
angle in triangles that compose the finite element mesh. A good value to \
choose is 30 degrees, but smaller values may be needed for \\\"tough\\\" \
geometries that contain small angles.\"\>"], "Print",
 CellTags->"Info3347223941-5725470"],

Cell[BoxData["\<\"HIReadDXF[\\\"filename\\\"] reads in geometry information a \
DXF file specified by \\\"filename\\\"\"\>"], "Print",
 CellTags->"Info3347223941-8114379"],

Cell[BoxData["\<\"HIRefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223941-7760450"],

Cell[BoxData["\<\"HISaveAs[\\\"filename\\\"] saves the file with name \
\\\"filename\\\". Note if you use a path you must use two backslashes e.g. \\\
\"c:\\\\\\\\temp\\\\\\\\myfemmfile.fem\\\"\"\>"], "Print",
 CellTags->"Info3347223941-7609199"],

Cell[BoxData["\<\"HISaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the HISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223941-8492301"],

Cell[BoxData["\<\"HISaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the HISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223941-8350572"],

Cell[BoxData["\<\"HISetEditMode[\\\"editmode\\\"] sets the current editmode \
to:\\n \\\"nodes\\\" \[Dash] nodes\\n \\\"segments\\\" - line segments\\n \
\\\"arcsegments\\\" - arc segments\\n \\\"blocks\\\" - block labels\\n \
\\\"group\\\" - selected group\\n This command will affect all subsequent \
uses of the other editing commands, if they are used without the editaction \
parameter.\"\>"], "Print",
 CellTags->"Info3347223941-7702967"],

Cell[BoxData["\<\"HISetFocus[\\\"documentname\\\"] switches the heat flow \
input file upon which scripting commands are to act. If more than one heat \
flow input file is being edited at a time, this command can be used to switch \
between files so that the mutiple files can be operated upon programmatically \
. \\\"documentname\\\" should contain the name of the desired document as it \
appears on the window\[CloseCurlyQuote]s title bar.\"\>"], "Print",
 CellTags->"Info3347223941-7628927"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Current Flow Input Commands", "Section",
 CellChangeTimes->{{3.4961934314166346`*^9, 3.4961934340258756`*^9}}],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"CIAddBoundProp[\\\"boundpropname\\\", Vs, qs, c0, c1, \
bdryformat] adds a new boundary property with name \\\"boundpropname\\\"\\n \
For a \\\"Fixed Voltage\\\" type boundary condition, set the Vs parameter to \
the desired voltage and all other parameters to zero. \\n To obtain a \
\\\"Mixed\\\"  type boundary condition, set \\texttt{C1} and c0 as required \
and bdryformat to 1. Set all other parameters to zero.\\n To obtain a \
prescribes surface current density, set qs to the desired current density in \
A/m^2 and set bdryformat to 2.\\n For a \\\"Periodic\\\" boundary condition, \
set bdryformat to 3 and set all other parameters to zero.\\n For an \
\\\"Anti-Perodic\\\" boundary condition, set bdryformat to 4 set all other \
parameters to zero.\"\>"], "Print",
 CellTags->"Info3347223941-2550021"],

Cell[BoxData["\<\"CIAddConductorProp[\\\"conductorname\\\",vc,qc,\
conductortype] adds a new conductor property with name \\\"conductorname\\\" \
with either a prescribed voltage or a prescribed total current. Set the \
unused property to zero. The conductortype parameter is 0 for prescribed \
charge and 1 for prescribed voltage.\"\>"], "Print",
 CellTags->"Info3347223941-9246453"],

Cell[BoxData["\"\<CIGetMaterial[\\\"materialname\\\"] fetches the specified \
material from the materials library.\>"], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.496193361170231*^9, 3.4961933882938423`*^9}, {
  3.4961934240576363`*^9, 3.496193424198254*^9}},
 CellTags->"Info3347223940-9972450"],

Cell[BoxData["\<\"CIAddMaterial[\\\"materialname\\\",ox,oy,ex,ey,ltx,lty] \
adds a new material with called \\\"materialname\\\" with the material \
properties:\\n ox Electrical conductivity in the x- or r-direction.\\n oy \
Electrical conductivity in the y- or z-direction.\\n ex Relative electrical \
permittivity in the x- or r-direction.\\n ey Relative electrical permittivity \
in the y- or z-direction.\\n ltx Dielectric loss tangent in the x- or \
r-direction.\\n lty Dielectric loss tangent in the y- or z-direction.\"\>"], \
"Print",
 CellTags->"Info3347223941-6719514"],

Cell[BoxData["\<\"CIAddPointProp[\\\"pointpropname\\\",vp,qp] adds a new \
point property of name \\\"pointpropname\\\" with either a specified voltage \
vp or point heat generation qp in units of J/m.\"\>"], "Print",
 CellTags->"Info3347223941-3075263"],

Cell[BoxData["\<\"CIModifyBoundProp[\\\"BdryName\\\",propnum,value] allows \
for modification of a boundary property. The BC to be modified is specified \
by \\\"BdryName\\\". The next parameter is the number of the property to be \
set. The last number is the value to be applied to the specified property. \
The various properties that can be modified are listed below:\\n 0 - \
\\\"BdryName\\\" - Name of boundary property\\n 1 - Vs - Fixed Voltage\\n 2 - \
js - Prescribed current density\\n 3 - c0 - External voltage\\n 4 - c1 - heat \
transfer coefficient\\n 5 - BdryFormat -  Type of boundary condition (0 = \
Prescribed Voltage; 1 = Mixed; 2 = Surface Current Density; 3 = Periodic; 4 = \
Antiperiodic)\"\>"], "Print",
 CellTags->"Info3347223941-1794145"],

Cell[BoxData["\<\"CIModifyConductorProp[\\\"ConductorName\\\",propnum,value] \
allows for modification of a conductor property. The conductor property to be \
modified is specified by \\\"ConductorName\\\". The next parameter is the \
number of the property to be set. The last number is the value to be applied \
to the specified property. The various properties that can be modified are \
listed below:\\n 0 - \\\"ConductorName\\\" - Name of the conductor \
property\\n 1 - Vc - Conductor Voltage\\n 2 - jc - Total conductor current\\n \
3 - ConductorType - 0 = Prescribed current, 1 = Prescribed voltage\"\>"], \
"Print",
 CellTags->"Info3347223941-2809827"],

Cell[BoxData["\<\"CIModifyMaterial[\\\"BlockName\\\",propnum,value] allows \
for modification of a material's properties without redefining the entire \
material (e.g. so that current can be modified from run to run). The material \
to be modified is specified by \\\"BlockName\\\". The next parameter is the \
number of the property to be set. The last number is the value to be applied \
to the specified property. The various properties that can be modified are \
listed below:\\n 0 - \\\"BlockName\\\" - Name of the material\\n 1 - ox - x \
(or r) direction electrical conductivity\\n 2 - oy - y (or z) direction \
electrical conductivity\\n 1 - ox - x (or r) direction relative electrical \
permittivity\\n 2 - oy - y (or z) direction relative electrical \
permittivity\\n 1 - ox - x (or r) direction dielectric loss tangent\\n 2 - oy \
- y (or z) direction dielectric loss tangent\"\>"], "Print",
 CellTags->"Info3347223941-3602638"],

Cell[BoxData["\<\"CIModifyPointProp[\\\"PointName\\\",propnum,value] allows \
for modification of a point property. The point property to be modified is \
specified by \\\"PointName\\\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\\n 0 - PointName - Name of the point property\\n 1 - Vp - Prescribed \
nodal voltage\\n 2 - jp - Point current in A/m\"\>"], "Print",
 CellTags->"Info3347223941-4062804"],

Cell[BoxData["\<\"CIDeleteBoundProp[\\\"boundpropname\\\"] deletes the \
boundary property named \\\"boundpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-8484718"],

Cell[BoxData["\<\"CIDeleteConductor[\\\"conductorname\\\"] deletes the \
conductor property named \\\"conductorname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-8368394"],

Cell[BoxData["\<\"CIDeleteMaterial[\\\"materialname\\\"] deletes the material \
property named \\\"materialname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-5771336"],

Cell[BoxData["\<\"CIDeletePointProp[\\\"pointpropname\\\"] deletes the point \
property named \\\"pointpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223941-5718574"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"CIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
electrostatics input geometry from the point nearst to {x1,y1} to the point \
nearest to {x2,y2}.  The arc spans a number of degrees specified by angle. \
Since FEMM approximates arcs by many line segments, the parameter maxseg \
specifies the maximum number of degrees that is allowed to be spanned by any \
one segment. Equivalent forms are:\\n \
CIAddArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
CIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223941-9029670"],

Cell[BoxData["\<\"CIAddBlockLabel[x,y] adds a block label at the point {x,y}. \
 An equivalent form is:\\n CIAddBlockLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-8579298"],

Cell[BoxData["\<\"CIAddNode[x,y] adds a new node at {x,y}. An equivalent form \
is:\\n CIAddNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223941-4116126"],

Cell[BoxData["\<\"CIAddSegment[x1,y1,x2,y2] add a new line segment from node \
closest to {x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\\n \
CIAddSegment[{x1,y1},{x2,y2}]\\n CIAddSegment[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223942-6124645"],

Cell[BoxData["\<\"CIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
current input geometry by drawing points at {x1,y1} and {x2,y2} and then \
connecting them with an arc segment. The arc spans a number of degrees \
specified by angle. Since FEMM approximates arcs by many line segments, the \
parameter maxseg specifies the maximum number of degrees that is allowed to \
be spanned by any one segment. Equivalent forms are:\\n \
CIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
CIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223942-3619064"],

Cell[BoxData["\<\"CIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} \
and then adds a segment connecting these two points.  Equivalent forms \
are:\\n CIDrawLine[{x1,y1},{x2,y2}]\\n CIDrawLine[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223942-4004828"],

Cell[BoxData["\<\"CIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points \
at every listed point and then draws a closed figure that connects the points\
\"\>"], "Print",
 CellTags->"Info3347223942-3596063"],

Cell[BoxData["\<\"CIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment \
line by adding each of the points in the list and then adding segments that \
join the listed points.\"\>"], "Print",
 CellTags->"Info3347223942-5797197"],

Cell[BoxData["\<\"CIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, \
{x1,y2}, {x2,y2} and  {x2,y1} and joins them with new segments.  Equivalent \
forms are:\\n CIDrawRectangle[{x1,y1},{x2,y2}]\\n \
CIDrawRectangle[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223942-2688418"],

Cell[BoxData["\<\"CICreateRadius[x,y,z] turns a corner located at {x,y} into \
a curve of radius r.\\n An equivalent form is: CICreateRadius[{x,y},z]\"\>"], \
"Print",
 CellTags->"Info3347223942-4889550"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"CISelectArcSegment[x,y] selects the arc segment closest to \
{x,y}.  An equivalent form is:\\n CISelectArcSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-4775645"],

Cell[BoxData["\<\"CISelectGroup[n] selects the nth group of nodes, segments, \
arc segments and block labels. This function will clear all previously \
selected elements and leave the edit mode in 4 (group)\"\>"], "Print",
 CellTags->"Info3347223942-9433219"],

Cell[BoxData["\<\"CISelectLabel[x,y] selects the block label closest to \
{x,y}.  An equivalent form is:\\n CISelectLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-1224636"],

Cell[BoxData["\<\"CISelectNode[x,y] selects the node closest to {x,y}.  An \
equivalent form is:\\n CISelectNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-4362745"],

Cell[BoxData["\<\"CISelectSegment[x,y] selects the segment closest to {x,y}.  \
An equivalent form is:\\n CISelectSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-3956808"],

Cell[BoxData["\<\"CISetArcSegmentProp[maxsegdeg, \\\"propname\\\", hide, \
groupno,\\\"inconductor\\\"] sets the properties associated with the selected \
arc segments\\n maxsegdeg specifies that the arcs must be meshed with \
elements that span at most maxsegdeg degrees per element\\n \\\"propname\\\" \
specifies the boundary property to be associated with the selected arcs\\n \
hide: 0 = not hidden in post-processor, 1 == hidden in post processor\\n \
groupno is an integer specifying the group number of which the selected arcs \
are to be members.\\n \\\"inconductor\\\" specifies the name of the conductor \
property with which the selected arcs are to be associated. If the arcs is \
not to be part of a conductor, this parameter can be specified as \
\\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223942-7340812"],

Cell[BoxData["\<\"CISetBlockProp[\\\"blockname\\\",automesh,meshsize,groupno] \
sets the selected block labels to have the properties:\\n Block property \
\\\"blockname\\\".\\n automesh: 0 = mesher defers to mesh size constraint \
defined in meshsize, 1 = mesher automatically chooses the mesh density.\\n \
meshsize: size constraint on the mesh in the block marked by this label\\n. \
groupno: make selected members of specified group number\"\>"], "Print",
 CellTags->"Info3347223942-7747929"],

Cell[BoxData["\<\"CISetNodeProp[\\\"propname\\\",groupno,\\\"inconductor\\\"] \
sets the selected nodes to have the nodal property \\\"propname\\\" and group \
number groupno. The \\\"inconductor\\\" string specifies which conductor the \
node belongs to. If the node doesn\[CloseCurlyQuote]t belong to a named \
conductor, this parameter can be set to \\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223942-1072148"],

Cell[BoxData["\<\"CISetSegmentProp[\\\"propname\\\",elementsize,automesh,hide,\
groupno,\\\"inconductor\\\"] sets the select segments to have:\\n Boundary \
property \\\"propname\\\"\\n Local element size along segment no greater than \
elementsize\\n automesh: 0 = mesher defers to the element constraint defined \
by elementsize, 1 = mesher automatically chooses mesh size along the selected \
segments\\n hide: 0 = not hidden in post-processor, 1 == hidden in post \
processor\\n A member of group number groupno\\n A member of the conductor \
specified by the string \\\"inconductor\\\". If the segment is not part of a \
conductor, this parameter can be specified as \\\"<None>\\\".\"\>"], "Print",
 CellTags->"Info3347223942-4833943"],

Cell[BoxData["\<\"CIDeleteSelected[] deletes all selected objects.\"\>"], \
"Print",
 CellTags->"Info3347223942-3215298"],

Cell[BoxData["\<\"CIDeleteSelectedArcSegments[] deletes all selected arc \
segments.\"\>"], "Print",
 CellTags->"Info3347223942-3062770"],

Cell[BoxData["\<\"CIDeleteSelectedLabels[] deletes all selected block labels.\
\"\>"], "Print",
 CellTags->"Info3347223942-1478151"],

Cell[BoxData["\<\"CIDeleteSelectedNodes[] deletes all selected nodes.\"\>"], \
"Print",
 CellTags->"Info3347223942-4873634"],

Cell[BoxData["\<\"CIDeleteSelectedSegments[] deletes all selected segments.\"\
\>"], "Print",
 CellTags->"Info3347223942-1405457"],

Cell[BoxData["\<\"CIClearSelected[] clear all selected nodes, blocks, \
segments and arc segments.\"\>"], "Print",
 CellTags->"Info3347223942-3777925"],

Cell[BoxData["\<\"CIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric \
external region to be used in conjuction with the Kelvin Transformation \
method of modeling unbounded problems.  The Zo parameter is the z-location of \
the origin of the outer region, the Ro parameter is the radius of the outer \
region, and the Ri parameter is the radius of the inner region (i.e. the \
region of interest). In the exterior region, the permeability varies as a \
function of distance from the origin of the external region.  These \
parameters are necessary to define the permeability variation in the external \
region.\"\>"], "Print",
 CellTags->"Info3347223942-2152760"],

Cell[BoxData["\<\"CIAttachOuterSpace[] marks all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223942-5073193"],

Cell[BoxData["\<\"CIDetachOuterSpace[] undefines all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223942-3551327"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move, Copy, Scale", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"CICopyRotate[bx,by,angle,copies,(editaction)]\\n bx, by \
base point for rotation\\n angle angle by which the selected objects are \
incrementally shifted to make each copy. This angle is measured in \
degrees.\\n copies number of copies to be produced from the selected objects \
\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\\n An \
equivalent form is:\\n CICopyRotate[{bx,by},angle,copies,(editaction)]\"\>"], \
"Print",
 CellTags->"Info3347223942-9096541"],

Cell[BoxData["\<\"CICopyTranslate[dx,dy,copies,(editaction)]\\n {dx,dy} \
represents the distance by which the selected objects are to be incrementally \
shifted.\\n copies specifies the number of copoies to be produced from the \
selected objects\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, \
4-group\\n An equivalent form is:\\n \
CICopyTranslate[{dx,dy},copies,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-2626858"],

Cell[BoxData["\<\"CIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected \
objects about a line passing through the points (x1,y1) and (x2,y2). Valid \
editaction entries are 0 for nodes, 1 for lines (segments), 2 for block \
labels, 3 for arc segments, and 4 for groups. Equivalent forms are:\\n \
CIMirror[{x1,y1},{x2,y2},(editaction)]\\n \
CIMirror[{{x1,y1},{x2,y2}},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-9568268"],

Cell[BoxData["\<\"CIMoveRotate[bx,by,shiftangle,(editaction)]\\n bx, by \
\[Dash] base point for rotation\\n shiftangle \[Dash] angle in degrees by \
which the selected objects are rotated.\\n editaction - 0  \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent form is:\\n \
CIMoveRotate[{bx,by},shiftangle,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-6949674"],

Cell[BoxData["\<\"CIMoveTranslate[dx,dy,(editaction)]\\n dx,dy \[Dash] \
distance by which the selected objects are shifted.\\n editaction - 0 \
\[Dash]nodes, 1 \[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] \
arc segments, 4- group\\n An equivalent form is:\\n \
CIMoveTranslate[{dx,dy},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-3601001"],

Cell[BoxData["\<\"CIScale[bx,by,scalefactor,(editaction)]\\n bx, by \[Dash] \
base point for scaling\\n scalefactor \[Dash] a multiplier that determines \
how much the selected objects are scaled\\n editaction 0 \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent for is: \
CIScale[{bx,by},scalefactor,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-6609419"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"CISetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the \
\\\"type\\\" parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\
\"polar\\\" for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223942-9958241"],

Cell[BoxData["\<\"CIShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223942-7543440"],

Cell[BoxData["\<\"CIHideGrid[] hides the current input grid points\"\>"], \
"Print",
 CellTags->"Info3347223942-5025554"],

Cell[BoxData["\<\"CIShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223942-6965775"],

Cell[BoxData["\<\"CIPurgeMesh[] clears the mesh out of both the screen and \
memory.\"\>"], "Print",
 CellTags->"Info3347223942-3888279"],

Cell[BoxData["\<\"CIShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223942-5334754"],

Cell[BoxData["\<\"CIHideNames[] stops the names of the materials associated \
with each block label from being displayed\"\>"], "Print",
 CellTags->"Info3347223942-2217087"],

Cell[BoxData["\<\"CISnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223942-6944643"],

Cell[BoxData["\<\"CISnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223942-3967660"],

Cell[BoxData["\<\"CIZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n CIZoom[{x1,y1},{x2,y2}]\\n \
CIZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223942-9812128"],

Cell[BoxData["\<\"CIZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223942-9428271"],

Cell[BoxData["\<\"CIZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223942-5196408"],

Cell[BoxData["\<\"CIZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223942-3765753"],

Cell[BoxData["\<\"CIGetView[] grabs the current current input view and \
returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223942-7435369"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"CIAnalyze[(flag)] runs the current solver. The flag \
parameter controls whether the solver window is visible or minimized. For a \
visible window, either specify no value for flag or specify 0. For a \
minimized window, flag should be set to 1. An equivalent form is:\\n \
CIAnalyse[(flag)]\"\>"], "Print",
 CellTags->"Info3347223942-9408926"],

Cell[BoxData["\<\"CIClose[] closes the preprocessor window and destroys the \
current document.\"\>"], "Print",
 CellTags->"Info3347223942-8756152"],

Cell[BoxData["\<\"CICreateMesh[] runs triangle to create a mesh. Note that \
this is not a necessary precursor of performing an analysis, as CIAnalyze[] \
will make sure the mesh is up to date before running an analysis.\"\>"], \
"Print",
 CellTags->"Info3347223942-5512214"],

Cell[BoxData["\<\"CILoadSolution[] loads and displays the solution \
corresponding to the current geometry.\"\>"], "Print",
 CellTags->"Info3347223942-4592327"],

Cell[BoxData["\<\"CIProbDef[units,type,frequency,precision,depth,minangle] \
changes the problem definition. The units parameter specifies the units used \
for measuring length in the problem domain. Valid \\\"units\\\" entries are \
\\\"inches\\\", \\\"millimeters\\\", \\\"centimeters\\\", \\\"mils\\\", \
\\\"meters\\\", and \\\"micrometers\\\". Set problemtype to \\\"planar\\\" \
for a 2-D planar problem, or to \\\"axi\\\" for an axisymmetric problem. The \
frequency parameter denotes the frequency of the analysis in Hz. The \
precision parameter dictates the precision required by the solver. For \
example, specifying 1.E-8 requires the RMS of the residual to be less than \
10^(-8). The depth parameter, represents the depth of the problem in the \
into-the-page direction for 2-D planar problems. The minangle parameter is a \
constraint for the mesh generator. It specifies the smallest permissible \
angle in triangles that compose the finite element mesh. A good value to \
choose is 30 degrees, but smaller values may be needed for \\\"tough\\\" \
geometries that contain small angles.\"\>"], "Print",
 CellTags->"Info3347223942-2467846"],

Cell[BoxData["\<\"CIReadDXF[\\\"filename\\\"] reads in geometry information a \
DXF file specified by \\\"filename\\\"\"\>"], "Print",
 CellTags->"Info3347223942-6619667"],

Cell[BoxData["\<\"CIRefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223942-8743872"],

Cell[BoxData["\<\"CISaveAs[\\\"filename\\\"] saves the file with name \
\\\"filename\\\". Note if you use a path you must use two backslashes e.g. \\\
\"c:\\\\\\\\temp\\\\\\\\myfemmfile.fem\\\"\"\>"], "Print",
 CellTags->"Info3347223942-7645405"],

Cell[BoxData["\<\"CISaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the CISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223942-9313603"],

Cell[BoxData["\<\"CISaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the CISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223942-6658559"],

Cell[BoxData["\<\"CISetEditMode[\\\"editmode\\\"] sets the current editmode \
to:\\n \\\"nodes\\\" \[Dash] nodes\\n \\\"segments\\\" - line segments\\n \
\\\"arcsegments\\\" - arc segments\\n \\\"blocks\\\" - block labels\\n \
\\\"group\\\" - selected group\\n This command will affect all subsequent \
uses of the other editing commands, if they are used without the editaction \
parameter.\"\>"], "Print",
 CellTags->"Info3347223942-2489674"],

Cell[BoxData["\<\"CISetFocus[\\\"documentname\\\"] switches the current input \
file upon which scripting commands are to act. If more than one current input \
file is being edited at a time, this command can be used to switch between \
files so that the mutiple files can be operated upon programmatically . \
\\\"documentname\\\" should contain the name of the desired document as it \
appears on the window\[CloseCurlyQuote]s title bar.\"\>"], "Print",
 CellTags->"Info3347223942-2698508"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetics Input Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Define, Modify, or Delete Properties", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MIAddBoundProp[\\\"propname\\\",A0,A1,A2,Phi,Mu,Sig,c0,c1,\
BdryFormat] adds a new boundary property with name \\\"propname\\\" \\n \
\[Dash] For a \\\"Prescribed A\\\" type boundary condition, set the A0, A1, \
A2  and Phi parameters as required. Set all other parameters to zero.\\n \
\[Dash] For a \\\"Small Skin Depth\\\" type boundary condtion, set the Mu to \
the desired relative permeability and Sig to the desired conductivity in \
MS/m. Set BdryFormat to 1 and all other parameters to zero. \\n \[Dash] To \
obtain a \\\"Mixed\\\" type boundary condition, set C1 and C0 as required and \
BdryFormat to 2. Set all other parameters to zero. \\n \[Dash] For a \
\\\"Strategic dual image\\\" boundary, set BdryFormat to 3 and set all other \
parameters to zero.\\n \[Dash] For a \\\"Periodic\\\" boundary condition, set \
BdryFormat to 4 and set all other parameters to zero.\\n \[Dash] For an \
\\\"Anti-Perodic\\\" boundary condition, set BdryFormat to 5 set all other \
parameters to zero.\"\>"], "Print",
 CellTags->"Info3347223942-1174016"],

Cell[BoxData["\<\"MIAddCircProp[\\\"circuitname\\\",i,circuittype] adds a new \
circuit property with name \\\"circuitname\\\" with a prescribed current i. \
It is OK for the current to be complex-valued. The circuittype parameter is 0 \
for a parallel-connected circuit and 1 for a series-connected circuit.\"\>"], \
"Print",
 CellTags->"Info3347223942-3337860"],

Cell[BoxData["\"\<MIGetMaterial[\\\"materialname\\\"] fetches the named \
material from the materials library.\>"], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellChangeTimes->{{3.4961932766120605`*^9, 3.496193300298348*^9}},
 CellTags->"Info3347223942-3337860"],

Cell[BoxData["\<\"MIAddMaterial[\\\"materialname\\\",mux,muy,Hc,J,Cduct,Lamd,\
Phihmax,lamfill,LamType,Phihx,Phihy,NStrands,WireD]\\n adds a new material \
with called \\\"materialname\\\" with the material properties:\\n - mux - \
Relative permeability in the x- or r-direction (for linear materials)\\n - \
muy - Relative permeability in the y- or z-direction (for linear \
materials)\\n - Hc - Permanent magnet coercivity in Amps/Meter. \\n - J - \
Applied source current density in Amps/mm2. It is OK for J to be \
complex-valued.\\n - Cduct - Electrical conductivity of the material in MS/m.\
\\n - Lamd - Lamination thickness in millimeters. \\n - Phihmax - Hysteresis \
lag angle in degrees, used for nonlinear BH curves.\\n - Lamfill - Fraction \
of the volume occupied per lamination that is actually filled with iron (Note \
that this parameter defaults to 1 the FEMM preprocessor dialog box because, \
by default, iron completely fills the volume)\\n - Lamtype - Set to 0 for \
\\\"Not laminated or laminated in plane\\\";  1 for \\\"Laminated x or r\\\"; \
2 for \\\"Laminated y or z\\\" \\n - Phihx - Hysteresis lag in degrees in the \
x-direction for linear problems.\\n - Phihy - Hysteresis lag in degrees in \
the y-direction for linear problems.\\n - NStrands - number of strands per \
wire if the material is a wire.\\n - WireD - diameter of each strand in mm if \
the material is a wire.\"\>"], "Print",
 CellTags->"Info3347223942-7875248"],

Cell[BoxData["\<\"MIAddBHPoint[\\\"materialname\\\",b,h] adds the point {b,h} \
to the BH curve for the material specified by \\\"materialname\\\".  An \
equivalent form is:\\n MIAddBHPoint[\\\"materialname\\\",{b,h}]\"\>"], "Print",
 CellTags->"Info3347223942-3565351"],

Cell[BoxData["\<\"MIAddBHPoints[\\\"materialname\\\",list] adds all of the \
points in list to the BH curve for the material specified by \\\"materialname\
\\\"\"\>"], "Print",
 CellTags->"Info3347223942-9575072"],

Cell[BoxData["\<\"MIClearBHPoint[\\\"materialname\\\"] erases all of the BH \
points that have been defined for the material named \
\\\"materialname\\\"\"\>"], "Print",
 CellTags->"Info3347223942-1161328"],

Cell[BoxData["\<\"MIAddPointProp[\\\"pointpropname\\\",A,J] adds a new point \
property of name \\\"pointpropname\\\" with either a specified potential A in \
units of Webers/Meter or a point current J in units of Amps. It is OK for \
either A or J to be complex-valued. Set the unused parameter to 0.\"\>"], \
"Print",
 CellTags->"Info3347223942-6641394"],

Cell[BoxData["\<\"MIModifyBoundProp[\\\"BdryName\\\",propnum,value] allows \
for modification of a boundary property. The BC to be modified is specified \
by \\\"BdryName\\\". The next parameter is the number of the property to be \
set. The last number is the value to be applied to the specified property. \
The various properties that can be modified are listed below:\\n 0 - \
\\\"BdryName\\\" - Name of boundary property \\n 1 A0 - Prescribed A \
parameter\\n 2 A1 - Prescribed A parameter\\n 3 A2 - Prescribed A \
parameter\\n 4 phi - Prescribed A phase\\n 5 mu -  Small skin depth relative \
permeability \\n 6 Cduct -  Small skin depth conductivity, MS/m \\n 7 c0 - \
Mixed BC parameter \\n 8 c1 - Mixed BC parameter \\n 9 - BdryFormat.  Valid \
choices for boundary format include:\\n \\t0 = Prescribed A\\n \\t1 = Small \
skin depth\\n \\t2 = Mixed\\n \\t3 = Strategic Dual Image\\n \\t4 = \
Periodic\\n \\t5 = Antiperiodic\"\>"], "Print",
 CellTags->"Info3347223942-3253559"],

Cell[BoxData["\<\"MIModifyCircProp[\\\"circname\\\",propnum,value] allows for \
modification of a circuit property. The circuit property to be modified is \
specified by \\\"circname\\\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\\n 0 - CircName - Name of the circuit property\\n 1 - i - Total \
current. It is OK for i to be complex-valued\\n 2 - CircType -  0 = Parallel, \
1 = Series\"\>"], "Print",
 CellTags->"Info3347223942-5222545"],

Cell[BoxData["\<\"MISetCurrent[\\\"circname\\\",i] sets the current of the \
circuit named \\\"circname\\\" to the value specified by i.  It is OK for the \
current to be complex-valued.\"\>"], "Print",
 CellTags->"Info3347223942-6345755"],

Cell[BoxData["\<\"MIModifyMaterial[\\\"BlockName\\\",propnum,value] allows \
for modification of a material\[CloseCurlyQuote]s properties without \
redefining the entire material. The material to be modified is specified by \
\\\"BlockName\\\". The next parameter is the number of the property to be \
set. The last number is the value to be applied to the specified property. \
The various properties that can be modified are listed below:\\n 0 - \
\\\"BlockName\\\" - Name of the material \\n 1 - mux - x (or r) direction \
relative permeability \\n 2 - muy - y (or z) direction relative permeability \
\\n 3 - Hc - Coercivity, Amps/Meter \\n 4 - J - Current density, MA/m2.  OK \
if J is complex-valued. \\n 5 - cduct - Electrical conductivity, MS/m \\n 6 - \
dlam - Lamination thickness, mm \\n 7 - phihmax - Hysteresis lag angle for \
nonlinear problems, degrees \\n 8 - LamFill - Iron fill fraction \\n 9 - \
LamType - 0 = None/In plane, 1 = parallel to x, 2=parallel to y \\n 10 - \
phihx - Hysteresis lag in x-direction for linear problems, degrees \\n 11 - \
phihy - Hysteresis lag in y-direction for linear problems, degrees\"\>"], \
"Print",
 CellTags->"Info3347223942-3683202"],

Cell[BoxData["\<\"MIModifyPointProp[\\\"PointName\\\",propnum,value] allows \
for modification of a point property. The point property to be modified is \
specified by \\\"PointName\\\". The next parameter is the number of the \
property to be set. The last number is the value to be applied to the \
specified property. The various properties that can be modified are listed \
below:\\n 0 - PointName - Name of the point property \\n 1 - A - Nodal \
potential, Weber/Meter\\n 2 - J - Nodal current, Amps\\n It is OK if either A \
or J are complex-valued.\"\>"], "Print",
 CellTags->"Info3347223942-7858990"],

Cell[BoxData["\<\"MIDeleteBoundProp[\\\"boundpropname\\\"] deletes the \
boundary property named \\\"boundpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223942-3699623"],

Cell[BoxData["\<\"MIDeleteCircuit[\\\"circuitname\\\"] deletes the circuit \
property named \\\"circuitname\\\".\"\>"], "Print",
 CellTags->"Info3347223942-4895320"],

Cell[BoxData["\<\"MIDeleteMaterial[\\\"materialname\\\"] deletes the material \
property named \\\"materialname\\\".\"\>"], "Print",
 CellTags->"Info3347223942-9354952"],

Cell[BoxData["\<\"MIDeletePointProp[\\\"pointpropname\\\"] deletes the point \
property named \\\"pointpropname\\\".\"\>"], "Print",
 CellTags->"Info3347223942-8866994"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Drawing Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MIAddArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
electrostatics input geometry from the point nearst to {x1,y1} to the point \
nearest to {x2,y2}.  The arc spans a number of degrees specified by angle. \
Since FEMM approximates arcs by many line segments, the parameter maxseg \
specifies the maximum number of degrees that is allowed to be spanned by any \
one segment. Equivalent forms are:\\n \
MIAddArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
MIAddArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223942-7974690"],

Cell[BoxData["\<\"MIAddBlockLabel[x,y] adds a block label at the point {x,y}. \
 An equivalent form is:\\n MIAddBlockLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-7718741"],

Cell[BoxData["\<\"MIAddNode[x,y] adds a new node at {x,y}. An equivalent form \
is:\\n MIAddNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-6265237"],

Cell[BoxData["\<\"MIAddSegment[x1,y1,x2,y2] add a new line segment from node \
closest to {x1,y1} to node closest to {x2,y2}.  Equivalent forms are:\\n \
MIAddSegment[{x1,y1},{x2,y2}]\\n MIAddSegment[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223942-2127838"],

Cell[BoxData["\<\"MIDrawArc[x1,y1,x2,y2,angle,maxseg] adds an arc to the \
electrostatics input geometry by drawing points at {x1,y1} and {x2,y2} and \
then connecting them with an arc segment. The arc spans a number of degrees \
specified by angle. Since FEMM approximates arcs by many line segments, the \
parameter maxseg specifies the maximum number of degrees that is allowed to \
be spanned by any one segment. Equivalent forms are:\\n \
MIDrawArc[{x1,y1},{x2,y2},angle,maxseg]\\n \
MIDrawArc[{{x1,y1},{x2,y2}},angle,maxseg]\"\>"], "Print",
 CellTags->"Info3347223942-8061335"],

Cell[BoxData["\<\"MIDrawLine[x1,y1,x2,y2] adds points at {x1,y1} and {x2,y2} \
and then adds a segment connecting these two points.  Equivalent forms \
are:\\n MIDrawLine[{x1,y1},{x2,y2}]\\n MIDrawLine[{{x1,y1},{x2,y2}}]\"\>"], \
"Print",
 CellTags->"Info3347223942-2612802"],

Cell[BoxData["\<\"MIDrawPolygon[{{x1,y2},...,{xn,yn}}] adds new node points \
at every listed point and then draws a closed figure that connects the points\
\"\>"], "Print",
 CellTags->"Info3347223942-3525955"],

Cell[BoxData["\<\"MIDrawPolyLine[{{x1,y2},...,{xn,yn}}] draws a multi-segment \
line by adding each of the points in the list and then adding segments that \
join the listed points.\"\>"], "Print",
 CellTags->"Info3347223942-9298280"],

Cell[BoxData["\<\"MIDrawRectangle[x1,y1,x2,y2] adds nodes at {x1,y1}, \
{x1,y2}, {x2,y2} and  {x2,y1} and joins them with new segments.  Equivalent \
forms are:\\n MIDrawRectangle[{x1,y1},{x2,y2}]\\n \
MIDrawRectangle[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223942-3205867"],

Cell[BoxData["\<\"MICreateRadius[x,y,z] turns a corner located at {x,y} into \
a curve of radius r.\\n An equivalent form is: MICreateRadius[{x,y},z]\"\>"], \
"Print",
 CellTags->"Info3347223942-2715408"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Object Selection and Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MISelectArcSegment[x,y] selects the arc segment closest to \
{x,y}.  An equivalent form is:\\n MISelectArcSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-1902193"],

Cell[BoxData["\<\"MISelectGroup[n] selects the nth group of nodes, segments, \
arc segments and block labels. This function will clear all previously \
selected elements and leave the edit mode in 4 (group)\"\>"], "Print",
 CellTags->"Info3347223942-6712612"],

Cell[BoxData["\<\"MISelectLabel[x,y] selects the block label closest to \
{x,y}.  An equivalent form is:\\n MISelectLabel[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-4802586"],

Cell[BoxData["\<\"MISelectNode[x,y] selects the node closest to {x,y}.  An \
equivalent form is:\\n MISelectNode[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-6636810"],

Cell[BoxData["\<\"MISelectSegment[x,y] selects the segment closest to {x,y}.  \
An equivalent form is:\\n MISelectSegment[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-4840162"],

Cell[BoxData["\<\"MISetArcSegmentProp[maxsegdeg,\\\"propname\\\",hide,groupno]\
 sets the selected arc segments to:\\n \[Dash] Meshed with elements that span \
at most maxsegdeg degrees per element\\n \[Dash] Boundary property \
\\\"propname\\\"\\n \[Dash] hide: 0 = not hidden in post-processor, 1 == \
hidden in post processor\\n \[Dash] A member of group number groupno\"\>"], \
"Print",
 CellTags->"Info3347223942-7491570"],

Cell[BoxData["\<\"MISetBlockProp[\\\"blockname\\\",automesh,meshsize,\\\"\
incircuit\\\", magdirection,group,turns]\\n sets the selected block labels to \
have the properties:\\n \[Dash] Block property \\\"blockname\\\".\\n \[Dash] \
automesh: 0 = mesher defers to mesh size constraint defined in meshsize, 1 = \
mesher automatically chooses the mesh density.\\n \[Dash] meshsize: size \
constraint on the mesh in the block marked by this label.\\n \[Dash] Block is \
a member of the circuit named \\\"incircuit\\\" \\n \[Dash] The magnetization \
is directed along an angle in measured in degrees denoted by the parameter \
magdirection\\n \[Dash] A member of group number group\\n \[Dash] The number \
of turns associated with this label is denoted by turns.\"\>"], "Print",
 CellTags->"Info3347223942-1473756"],

Cell[BoxData["\<\"MISetNodeProp[\\\"propname\\\",groupno] set the selected \
nodes to have the nodal property \\\"propname\\\" and group number groupno.\"\
\>"], "Print",
 CellTags->"Info3347223942-1735460"],

Cell[BoxData["\<\"MISetSegmentProp[\\\"propname\\\",elementsize,automesh,hide,\
group] sets the selected segments to have:\\n \[Dash] Boundary property \
\\\"propname\\\" \\n \[Dash] Local element size along segment no greater than \
elementsize \\n \[Dash] automesh: 0 = mesher defers to the element constraint \
defined by elementsize, 1 = mesher automatically chooses mesh size along the \
selected segments \\n \[Dash] hide: 0 = not hidden in post-processor, 1 == \
hidden in post processor\\n \[Dash] A member of group number group\"\>"], \
"Print",
 CellTags->"Info3347223942-2227327"],

Cell[BoxData["\<\"MIDeleteSelected[] deletes all selected objects.\"\>"], \
"Print",
 CellTags->"Info3347223942-4747170"],

Cell[BoxData["\<\"MIDeleteSelectedArcSegments[] deletes all selected arc \
segments.\"\>"], "Print",
 CellTags->"Info3347223942-2286321"],

Cell[BoxData["\<\"MIDeleteSelectedLabels[] deletes all selected block labels.\
\"\>"], "Print",
 CellTags->"Info3347223942-8963834"],

Cell[BoxData["\<\"MIDeleteSelectedNodes[] deletes all selected nodes.\"\>"], \
"Print",
 CellTags->"Info3347223942-9305092"],

Cell[BoxData["\<\"MIDeleteSelectedSegments[] deletes all selected segments.\"\
\>"], "Print",
 CellTags->"Info3347223942-6456408"],

Cell[BoxData["\<\"MIClearSelected[] clear all selected nodes, blocks, \
segments and arc segments.\"\>"], "Print",
 CellTags->"Info3347223942-3630767"],

Cell[BoxData["\<\"MIDefineOuterSpace[Zo,Ro,Ri] defines an axisymmetric \
external region to be used in conjuction with the Kelvin Transformation \
method of modeling unbounded problems.  The Zo parameter is the z-location of \
the origin of the outer region, the Ro parameter is the radius of the outer \
region, and the Ri parameter is the radius of the inner region (i.e. the \
region of interest). In the exterior region, the permeability varies as a \
function of distance from the origin of the external region.  These \
parameters are necessary to define the permeability variation in the external \
region.\"\>"], "Print",
 CellTags->"Info3347223942-8451424"],

Cell[BoxData["\<\"MIAttachOuterSpace[] marks all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223942-9036334"],

Cell[BoxData["\<\"MIDetachOuterSpace[] undefines all selected block labels as \
members of the external region used for modeling unbounded axisymmetric \
problems via the Kelvin Transformation.\"\>"], "Print",
 CellTags->"Info3347223942-8833736"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Move/Copy/Scale", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MICopyRotate[bx,by,angle,copies,(editaction)]\\n bx, by \
base point for rotation\\n angle angle by which the selected objects are \
incrementally shifted to make each copy. This angle is measured in \
degrees.\\n copies number of copies to be produced from the selected objects \
\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, 4-group\\n An \
equivalent form is:\\n MICopyRotate[{bx,by},angle,copies,(editaction)]\"\>"], \
"Print",
 CellTags->"Info3347223942-7130020"],

Cell[BoxData["\<\"MICopyTranslate[dx,dy,copies,(editaction)]\\n {dx,dy} \
represents the distance by which the selected objects are to be incrementally \
shifted.\\n copies specifies the number of copoies to be produced from the \
selected objects\\n editaction 0-nodes, 1-segments, 2-block labels, 3-arcs, \
4-group\\n An equivalent form is:\\n \
MICopyTranslate[{dx,dy},copies,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-7499705"],

Cell[BoxData["\<\"MIMirror[x1,y1,x2,y2,(editaction)] mirrors the selected \
objects about a line passing through the points (x1,y1) and (x2,y2). Valid \
editaction entries are 0 for nodes, 1 for lines (segments), 2 for block \
labels, 3 for arc segments, and 4 for groups. Equivalent forms are:\\n \
MIMirror[{x1,y1},{x2,y2},(editaction)]\\n \
MIMirror[{{x1,y1},{x2,y2}},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-7334860"],

Cell[BoxData["\<\"MIMoveRotate[bx,by,shiftangle,(editaction)]\\n bx, by \
\[Dash] base point for rotation\\n shiftangle \[Dash] angle in degrees by \
which the selected objects are rotated.\\n editaction - 0  \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent form is:\\n \
MIMoveRotate[{bx,by},shiftangle,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-3929142"],

Cell[BoxData["\<\"MIMoveTranslate[dx,dy,(editaction)]\\n dx,dy \[Dash] \
distance by which the selected objects are shifted.\\n editaction - 0 \
\[Dash]nodes, 1 \[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] \
arc segments, 4- group\\n An equivalent form is:\\n \
MIMoveTranslate[{dx,dy},(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-4675478"],

Cell[BoxData["\<\"MIScale[bx,by,scalefactor,(editaction)]\\n bx, by \[Dash] \
base point for scaling\\n scalefactor \[Dash] a multiplier that determines \
how much the selected objects are scaled\\n editaction 0 \[Dash]nodes, 1 \
\[Dash] lines (segments), 2 \[Dash]block labels, 3 \[Dash] arc segments, 4- \
group\\n An equivalent for is: \
MIScale[{bx,by},scalefactor,(editaction)]\"\>"], "Print",
 CellTags->"Info3347223942-6544225"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MISetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the \
\\\"type\\\" parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\
\"polar\\\" for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223942-4841605"],

Cell[BoxData["\<\"MIShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223942-6260931"],

Cell[BoxData["\<\"MIHideGrid[] hides the electrostatics input grid \
points\"\>"], "Print",
 CellTags->"Info3347223942-2933636"],

Cell[BoxData["\<\"MIShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223942-6299238"],

Cell[BoxData["\<\"MIPurgeMesh[] clears the mesh out of both the screen and \
memory.\"\>"], "Print",
 CellTags->"Info3347223942-8455083"],

Cell[BoxData["\<\"MIShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223942-2761304"],

Cell[BoxData["\<\"MIHideNames[] stops the names of the materials associated \
with each block label from being displayed\"\>"], "Print",
 CellTags->"Info3347223942-7582796"],

Cell[BoxData["\<\"MISnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223942-3568316"],

Cell[BoxData["\<\"MISnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223942-8381002"],

Cell[BoxData["\<\"MIZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n MIZoom[{x1,y1},{x2,y2}]\\n \
MIZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223942-6455526"],

Cell[BoxData["\<\"MIZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223942-4808313"],

Cell[BoxData["\<\"MIZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223942-2972084"],

Cell[BoxData["\<\"MIZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223942-3404091"],

Cell[BoxData["\<\"MIGetView[] grabs the current electrostatics input view and \
returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223942-5570118"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Problem Commands", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MIAnalyze[(flag)] runs the magnetics solver. The flag \
parameter controls whether the solver window is visible or minimized. For a \
visible window, either specify no value for flag or specify 0. For a \
minimized window, flag should be set to 1. An equivalent form is:\\n \
MIAnalyse[(flag)]\"\>"], "Print",
 CellTags->"Info3347223942-9710485"],

Cell[BoxData["\<\"MIClose[] closes the preprocessor window and destroys the \
current document.\"\>"], "Print",
 CellTags->"Info3347223942-3212477"],

Cell[BoxData["\<\"MICreateMesh[] runs triangle to create a mesh. Note that \
this is not a necessary precursor of performing an analysis, as MIAnalyze[] \
will make sure the mesh is up to date before running an analysis.\"\>"], \
"Print",
 CellTags->"Info3347223942-7052201"],

Cell[BoxData["\<\"MILoadSolution[] loads and displays the solution \
corresponding to the current geometry.\"\>"], "Print",
 CellTags->"Info3347223942-1274397"],

Cell[BoxData["\<\"MIProbDef[freq,units,type,precision,depth,minangle] changes \
the problem definition. The freq parameter specifies the frequency at which \
the analysis is performed in Hz. The units parameter specifies the units used \
for measuring length in the problem domain. Valid \\\"units\\\" entries are \
\\\"inches\\\", \\\"millimeters\\\", \\\"centimeters\\\", \\\"mils\\\", \
\\\"meters\\\", and \\\"micrometers\\\". Set problemtype to \\\"planar\\\" \
for a 2-D planar problem, or to \\\"axi\\\" for an axisymmetric problem. The \
precision parameter dictates the precision required by the solver. For \
example, specifying 1.E-8 requires the RMS of the residual to be less than \
10^(-8). The depth parameter, represents the depth of the problem in the \
into-the-page direction for 2-D planar problems. The minangle parameter is a \
constraint for the mesh generator. It specifies the smallest permissible \
angle in triangles that compose the finite element mesh. A good value to \
choose is 30 degrees, but smaller values may be needed for \\\"tough\\\" \
geometries that contain small angles.\"\>"], "Print",
 CellTags->"Info3347223942-6291660"],

Cell[BoxData["\<\"MIReadDXF[\\\"filename\\\"] reads in geometry information a \
DXF file specified by \\\"filename\\\"\"\>"], "Print",
 CellTags->"Info3347223942-1780589"],

Cell[BoxData["\<\"MIRefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223942-7289647"],

Cell[BoxData["\<\"MISaveAs[\\\"filename\\\"] saves the file with name \
\\\"filename\\\". Note if you use a path you must use two backslashes e.g. \\\
\"c:\\\\\\\\temp\\\\\\\\myfemmfile.fem\\\"\"\>"], "Print",
 CellTags->"Info3347223942-3206676"],

Cell[BoxData["\<\"MISaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the MISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223942-9428676"],

Cell[BoxData["\<\"MISaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the MISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223942-7629229"],

Cell[BoxData["\<\"MISetEditMode[\\\"editmode\\\"] sets the current editmode \
to:\\n \\\"nodes\\\" \[Dash] nodes\\n \\\"segments\\\" - line segments\\n \
\\\"arcsegments\\\" - arc segments\\n \\\"blocks\\\" - block labels\\n \
\\\"group\\\" - selected group\\n This command will affect all subsequent \
uses of the other editing commands, if they are used without the editaction \
parameter.\"\>"], "Print",
 CellTags->"Info3347223942-1442542"],

Cell[BoxData["\<\"MISetFocus[\\\"documentname\\\"] switches the \
electrostatics input file upon which scripting commands are to act. If more \
than one electrostatics input file is being edited at a time, this command \
can be used to switch between files so that the mutiple files can be operated \
upon programmatically . \\\"documentname\\\" should contain the name of the \
desired document as it appears on the window\[CloseCurlyQuote]s title \
bar.\"\>"], "Print",
 CellTags->"Info3347223942-1702933"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Electrostatics Output Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EOAddContour[x,y] adds the point {x,y} to the contour that \
is used for plotting values along lines and for computing line integrals.  An \
equivalent form is:\\n EOAddContour[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-5078785"],

Cell[BoxData["\<\"EOBendContour[angle,anglestep] replaces the straight line \
formed by the last two points in the contour by an arc that spans angle \
degrees. The arc is actually composed of many straight lines, each of which \
is constrained to span no more than anglestep degrees. The angle parameter \
can take on values from -180 to 180 degrees. The anglestep parameter must be \
greater than zero. If there are less than two points defined in the contour, \
this command is ignored.\"\>"], "Print",
 CellTags->"Info3347223942-1556017"],

Cell[BoxData["\<\"EOClearContour[] clears the current contour \
selection\"\>"], "Print",
 CellTags->"Info3347223942-3937423"],

Cell[BoxData["\<\"EOSelectBlock[x,y] select the block that contains point \
{x,y}.  An equivalent form is:\\n EOSelectBlock[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223942-1584120"],

Cell[BoxData["\<\"EOSelectPoint[x,y] adds a contour point at the closest \
input point to {x,y}. If the selected point and a previous selected points \
lie at the ends of an arcsegment, a contour is added that traces along the \
arcsegment. The selectpoint command has the same functionality as the \
left-button-click contour point selection when the program is running in \
interactive mode. An equivalent form is:\\n EOSelectPoint[{x,y}]\"\>"], \
"Print",
 CellTags->"Info3347223942-8122127"],

Cell[BoxData["\<\"EOGroupSelectBlock[n] selects all of the blocks that are \
labeled by block labels that are members of group n. If no number is \
specified (i.e. EOGroupSelectBlock[]), all blocks are selected.\"\>"], "Print",
 CellTags->"Info3347223942-6550982"],

Cell[BoxData["\<\"EOClearBlock[] clears the current block selection\"\>"], \
"Print",
 CellTags->"Info3347223942-4006352"],

Cell[BoxData["\<\"EOBlockIntegral[type] calculate a block integral for the \
selected blocks. The type parameter can take on the following values:\\n 0 - \
Stored Energy\\n 1 - Block Cross-section\\n 2 - Block Volume\\n 3 - Average D \
over the block\\n 4 - Average E over the block\\n 5 - Weighted Stress Tensor \
Force\\n 6 - Weighted Stress Tensor Torque\\n returns either a single value \
or a list of two values, depending on the specified type\"\>"], "Print",
 CellTags->"Info3347223943-7268328"],

Cell[BoxData["\<\"EOLineIntegral[type] calculate the line integral for the \
defined contour. Valid type selections include:\\n 0 - E \[CenterDot]t \\n 1 \
- D\[CenterDot]n \\n 2 - Contour length \\n 3 - Force from stress tensor \\n \
4 - Torque from stress tensor \\n This integral returns either one value or a \
list of two values, depending on the type of integral\"\>"], "Print",
 CellTags->"Info3347223943-9145937"],

Cell[BoxData["\<\"EOMakePlot[PlotType,NumPoints,Filename,FileFormat]\\n This \
function allows programmatic access to FEMM's X-Y plot routines. If only \
PlotType or only PlotType and NumPoints are specified, the command is \
interpreted as a request to plot the requested plot type to the screen. If, \
in addition, the Filename parameter is specified, the plot is instead written \
to disk to the specified file name as an extended metafile. If the FileFormat \
parameter is also, the command is instead interpreted as a command to write \
the data to disk to the specfied file name, rather than display it to make a \
graphical plot. Valid entries for PlotType are: \\n 0 - V (Voltage)\\n 1 - \
|D| (Magnitude of flux density)\\n 2 - D . n (Normal flux density)\\n 3 - D . \
t (Tangential flux density)\\n 4 - |E| (Magnitude of field intensity)\\n 5 - \
E . n (Normal field intensity)\\n 6 - E . t (Tangential field \
intensity)\"\>"], "Print",
 CellTags->"Info3347223943-9840448"],

Cell[BoxData["\<\"EOGetConductorProperties[\\\"conductor\\\"] returns \
properties for the conductor property named \\\"conductor\\\". A list with \
two values is returned: The voltage of the specified conductor, and the \
charge carried on the specified conductor.\"\>"], "Print",
 CellTags->"Info3347223943-7986648"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EOGetPointValues[x,y] returns the various field values \
associated with the point at {x,y}. The return values, in order, are:\\n V - \
Voltage \\n Dx - x- or r- direction component of displacement \\n Dy - y- or \
z- direction component of displacement \\n Ex - x- or r- direction component \
of electric field intensity \\n Ey - y- or z- direction component of electric \
field intensity \\n ex - x- or r- direction component of permittivity \\n ey \
- y- or z- direction component of permittivity \\n nrg - electric field \
energy density \\n An equivalent form is: \\n EOGetPointValues[x,y]\"\>"], \
"Print",
 CellTags->"Info3347223943-7429312"],

Cell[BoxData["\<\"EOGetV[x,y] returns the voltage at point {x,y}. An \
equivalent form is:\\n EOGetV[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-7412679"],

Cell[BoxData["\<\"EOGetD[x,y] returns a list with two elements containing the \
electric flux density at point {x,y}.  An equivalent form is:\\n \
EOGetD[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-4063720"],

Cell[BoxData["\<\"EOGetE[x,y] returns a list with two elements containing the \
electric field intensity at point {x,y}.  An equivalent form is:\\n \
EOGetE[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-2445563"],

Cell[BoxData["\<\"EOGetEnergyDensity[x,y] returns the energy density, \
(E.D)/2, at point {x,y}.  An equivalent form is:\\n EOGetEnergyDensity[{x,y}]\
\"\>"], "Print",
 CellTags->"Info3347223943-6984034"],

Cell[BoxData["\<\"EOGetPerm[x,y] returns a list with two elements containing \
the permittivity at point {x,y}. An equivalent form is:\\n EOGetPerm[{x,y}]\"\
\>"], "Print",
 CellTags->"Info3347223943-7106080"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EOShowContourPlot[numcontours,lowerV,upperV] shows the V \
contour plot with options:\\n numcontours - Number of equipotential lines to \
be plotted.\\n upperV - Upper limit for contours.\\n lowerV - Lower limit for \
contours.\\n If numcontours is -1 all parameters are ignored and default \
values are used\"\>"], "Print",
 CellTags->"Info3347223943-3775443"],

Cell[BoxData["\<\"EOHideContourPlot[] hides the currently displayed contour \
plot\"\>"], "Print",
 CellTags->"Info3347223943-8151160"],

Cell[BoxData["\<\"EOShowDensityPlot[legend,gscale,type,upperD,lowerD]\\n \
Shows the flux density plot with options:\\n legend - Set to 0 to hide the \
plot legend or 1 to show the plot legend.\\n gscale - Set to 0 for a colour \
density plot or 1 for a grey scale density plot.\\n upperD - Sets the upper \
display limit for the density plot.\\n lowerD - Sets the lower display limit \
for the density plot.\\n type - Sets the type of density plot. A value of 0 \
plots voltage, 1 plots the magnitude of D, and 2 plots the magnitude of \
E\"\>"], "Print",
 CellTags->"Info3347223943-8563191"],

Cell[BoxData["\<\"EOHideDensityPlot[] hides the currently displayed density \
plot\"\>"], "Print",
 CellTags->"Info3347223943-7693835"],

Cell[BoxData["\<\"EOSetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the type \
parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\"polar\\\" \
for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223943-2142348"],

Cell[BoxData["\<\"EOShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223943-4698659"],

Cell[BoxData["\<\"EOHideGrid[] hides the grid points from view in the \
electrostatics output window\"\>"], "Print",
 CellTags->"Info3347223943-1610739"],

Cell[BoxData["\<\"EOShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223943-4515092"],

Cell[BoxData["\<\"EOHideMesh[] hides the finite element mesh from in the \
electrostatics output view\"\>"], "Print",
 CellTags->"Info3347223943-2547445"],

Cell[BoxData["\<\"EOShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223943-5690018"],

Cell[BoxData["\<\"EOHideNames[] hides material names associated with block \
labels from view in the electrostatics output window\"\>"], "Print",
 CellTags->"Info3347223943-2070076"],

Cell[BoxData["\<\"EOShowPoints[] displays the input node point as part of the \
output geometry\"\>"], "Print",
 CellTags->"Info3347223943-5398885"],

Cell[BoxData["\<\"EOHidePoints[] inhibits the display of input node points in \
the electrostatics output window\"\>"], "Print",
 CellTags->"Info3347223943-3534432"],

Cell[BoxData["\<\"EOSmoothOn[] turns on smoothing of the D and E fields.  The \
D and E fields are then displayed using a linear interpolation of the field \
from nodal values\"\>"], "Print",
 CellTags->"Info3347223943-2811507"],

Cell[BoxData["\<\"EOSmoothOff[] turns off smoothing of the D and E fields.  \
The D and E fields are then displayed using values that are piecewise \
constant over each element.\"\>"], "Print",
 CellTags->"Info3347223943-3089526"],

Cell[BoxData["\<\"EOSnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223943-4050909"],

Cell[BoxData["\<\"EOSnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223943-2256146"],

Cell[BoxData["\<\"EOZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n EOZoom[{x1,y1},{x2,y2}]\\n \
EOZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223943-2578274"],

Cell[BoxData["\<\"EOZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223943-1967258"],

Cell[BoxData["\<\"EOZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223943-3803042"],

Cell[BoxData["\<\"EOZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223943-8980657"],

Cell[BoxData["\<\"EORefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223943-4021916"],

Cell[BoxData["\<\"EOGetView[] grabs the current electrostatics output view \
and returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223943-4519082"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"EOClose[] close the current postprocessor document and \
window\"\>"], "Print",
 CellTags->"Info3347223943-1421647"],

Cell[BoxData["\<\"EOGetProblemInfo[] returns a list with two values: the \
Problem Type (0 for planar and 1 for axisymmetric) and the depth assumed for \
planar problems in units of meters.\"\>"], "Print",
 CellTags->"Info3347223943-4876034"],

Cell[BoxData["\<\"EOReload[] reloads the current electrostatics output \
file.\"\>"], "Print",
 CellTags->"Info3347223943-4053978"],

Cell[BoxData["\<\"EOSaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the EISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223943-8562188"],

Cell[BoxData["\<\"EOSaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the EISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223943-7158326"],

Cell[BoxData["\<\"EOSetEditMode[\\\"mode\\\"] sets the mode of the \
postprocessor to point, contour, or area mode. Valid entries for mode are \
\\\"point\\\", \\\"contour\\\", and \\\"area\\\".\"\>"], "Print",
 CellTags->"Info3347223943-1889904"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heat Flow Output Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HOAddContour[x,y] adds the point {x,y} to the contour that \
is used for plotting values along lines and for computing line integrals.  An \
equivalent form is:\\n HOAddContour[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-5722087"],

Cell[BoxData["\<\"HOBendContour[angle,anglestep] replaces the straight line \
formed by the last two points in the contour by an arc that spans angle \
degrees. The arc is actually composed of many straight lines, each of which \
is constrained to span no more than anglestep degrees. The angle parameter \
can take on values from -180 to 180 degrees. The anglestep parameter must be \
greater than zero. If there are less than two points defined in the contour, \
this command is ignored.\"\>"], "Print",
 CellTags->"Info3347223943-6066732"],

Cell[BoxData["\<\"HOClearContour[] clears the current contour \
selection\"\>"], "Print",
 CellTags->"Info3347223943-7540695"],

Cell[BoxData["\<\"HOSelectBlock[x,y] select the block that contains point \
{x,y}.  An equivalent form is:\\n HOSelectBlock[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-8356363"],

Cell[BoxData["\<\"HOSelectPoint[x,y] adds a contour point at the closest \
input point to {x,y}. If the selected point and a previous selected points \
lie at the ends of an arcsegment, a contour is added that traces along the \
arcsegment. The selectpoint command has the same functionality as the \
left-button-click contour point selection when the program is running in \
interactive mode. An equivalent form is:\\n HOSelectPoint[{x,y}]\"\>"], \
"Print",
 CellTags->"Info3347223943-2610039"],

Cell[BoxData["\<\"HOGroupSelectBlock[n] selects all of the blocks that are \
labeled by block labels that are members of group n. If no number is \
specified (i.e. HOGroupSelectBlock[]), all blocks are selected.\"\>"], "Print",
 CellTags->"Info3347223943-9333251"],

Cell[BoxData["\<\"HOClearBlock[] clears the current block selection\"\>"], \
"Print",
 CellTags->"Info3347223943-5741528"],

Cell[BoxData["\<\"HOBlockIntegral[type] calculate a block integral for the \
selected blocks. The type parameter can take on the following values:\\n 0 - \
Average Temperature\\n 1 - Block Cross-section\\n 2 - Block Volume\\n 3 - \
Average F over the block\\n 4 - Average G over the block\\n returns either a \
single value or a list of two values, depending on the specified type\"\>"], \
"Print",
 CellTags->"Info3347223943-2058617"],

Cell[BoxData["\<\"HOLineIntegral[type] calculate the line integral for the \
defined contour. Valid type selections include:\\n 0 - Temperature Difference \
(G\[CenterDot]t) \\n 1 - Heat Flux (F\[CenterDot]n) \\n 2 - Contour length \
\\n 3 - Average temperature \\n This integral returns either one value or a \
list of two values, depending on the type of integral\"\>"], "Print",
 CellTags->"Info3347223943-6061612"],

Cell[BoxData["\<\"HOMakePlot[PlotType,NumPoints,Filename,FileFormat]\\n This \
function allows programmatic access to FEMM's X-Y plot routines. If only \
PlotType or only PlotType and NumPoints are specified, the command is \
interpreted as a request to plot the requested plot type to the screen. If, \
in addition, the Filename parameter is specified, the plot is instead written \
to disk to the specified file name as an extended metafile. If the FileFormat \
parameter is also, the command is instead interpreted as a command to write \
the data to disk to the specfied file name, rather than display it to make a \
graphical plot. Valid entries for PlotType are: \\n 0 - T (temperature)\\n 1 \
- |F| (Magnitude of heat flux density)\\n 2 - F . n (Normal heat flux \
density)\\n 3 - F . t (Tangential heat flux density)\\n 4 - |G| (Magnitude of \
field intensity)\\n 5 - G . n (Normal temperature gradient)\\n 6 - G . t \
(Tangential temperature gradient)\"\>"], "Print",
 CellTags->"Info3347223943-5839947"],

Cell[BoxData["\<\"HOGetConductorProperties[\\\"conductor\\\"] returns \
properties for the conductor property named \\\"conductor\\\". A list with \
two values is returned: The temperature of the specified conductor, and the \
total heat flux from the specified conductor.\"\>"], "Print",
 CellTags->"Info3347223943-6964670"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HOGetPointValues[x,y] returns the various field values \
associated with the point at {x,y}. The return values, in order, are:\\n T - \
temperature \\n Fx - x- or r- direction component of heat flux density \\n Fy \
- y- or z- direction component of heat flux density \\n Gx - x- or r- \
direction component of temperature gradient \\n Gy - y- or z- direction \
component of temperature gradient \\n Kx - x- or r- direction component of \
thermal conductivity \\n Ky - y- or z- direction component of thermal \
conductivity \\n An equivalent form is: \\n HOGetPointValues[x,y]\"\>"], \
"Print",
 CellTags->"Info3347223943-7045062"],

Cell[BoxData["\<\"HOGetT[x,y] returns the temperature at point {x,y}. An \
equivalent form is:\\n HOGetT[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-3156769"],

Cell[BoxData["\<\"HOGetK[x,y] returns a list with two elements containing the \
thermal conductivity at point {x,y}. An equivalent form is:\\n \
HOGetK[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-6001645"],

Cell[BoxData["\<\"HOGetD[x,y] returns a list with two elements containing the \
heat flux density at point {x,y}.  An equivalent form is:\\n \
HOGetF[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-4852106"],

Cell[BoxData["\<\"HOGetE[x,y] returns a list with two elements containing the \
temperature gradient at point {x,y}.  An equivalent form is:\\n HOGetG[{x,y}]\
\"\>"], "Print",
 CellTags->"Info3347223943-2532118"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HOShowContourPlot[numcontours,lowerV,upperV] shows the V \
contour plot with options:\\n numcontours - Number of equipotential lines to \
be plotted.\\n upperV - Upper limit for contours.\\n lowerV - Lower limit for \
contours.\\n If numcontours is -1 all parameters are ignored and default \
values are used\"\>"], "Print",
 CellTags->"Info3347223943-7067293"],

Cell[BoxData["\<\"HOHideContourPlot[] hides the currently displayed contour \
plot\"\>"], "Print",
 CellTags->"Info3347223943-9641375"],

Cell[BoxData["\<\"HOShowDensityPlot[legend,gscale,type,upperD,lowerD]\\n \
Shows the flux density plot with options:\\n legend - Set to 0 to hide the \
plot legend or 1 to show the plot legend.\\n gscale - Set to 0 for a colour \
density plot or 1 for a grey scale density plot.\\n upperD - Sets the upper \
display limit for the density plot.\\n lowerD - Sets the lower display limit \
for the density plot.\\n type - Sets the type of density plot. A value of 0 \
plots temperature, 1 plots the magnitude of D, and 2 plots the magnitude of E\
\"\>"], "Print",
 CellTags->"Info3347223943-7839447"],

Cell[BoxData["\<\"HOHideDensityPlot[] hides the currently displayed density \
plot\"\>"], "Print",
 CellTags->"Info3347223943-3277276"],

Cell[BoxData["\<\"HOSetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the type \
parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\"polar\\\" \
for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223943-1779400"],

Cell[BoxData["\<\"HOShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223943-8626447"],

Cell[BoxData["\<\"HOHideGrid[] hides the grid points from view in the heat \
flow output window\"\>"], "Print",
 CellTags->"Info3347223943-1614004"],

Cell[BoxData["\<\"HOShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223943-1756910"],

Cell[BoxData["\<\"HOHideMesh[] hides the finite element mesh from in the heat \
flow output view\"\>"], "Print",
 CellTags->"Info3347223943-7953603"],

Cell[BoxData["\<\"HOShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223943-7285242"],

Cell[BoxData["\<\"HOHideNames[] hides material names associated with block \
labels from view in the heat flow output window\"\>"], "Print",
 CellTags->"Info3347223943-3710641"],

Cell[BoxData["\<\"HOShowPoints[] displays the input node point as part of the \
output geometry\"\>"], "Print",
 CellTags->"Info3347223943-6496722"],

Cell[BoxData["\<\"HOHidePoints[] inhibits the display of input node points in \
the heat flow output window\"\>"], "Print",
 CellTags->"Info3347223943-4583684"],

Cell[BoxData["\<\"HOSmoothOn[] turns on smoothing of the D and E fields.  The \
D and E fields are then displayed using a linear interpolation of the field \
from nodal values\"\>"], "Print",
 CellTags->"Info3347223943-5150566"],

Cell[BoxData["\<\"HOSmoothOff[] turns off smoothing of the D and E fields.  \
The D and E fields are then displayed using values that are piecewise \
constant over each element.\"\>"], "Print",
 CellTags->"Info3347223943-5115022"],

Cell[BoxData["\<\"HOSnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223943-6296956"],

Cell[BoxData["\<\"HOSnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223943-1006138"],

Cell[BoxData["\<\"HOZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n HOZoom[{x1,y1},{x2,y2}]\\n \
HOZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223943-3228834"],

Cell[BoxData["\<\"HOZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223943-1888747"],

Cell[BoxData["\<\"HOZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223943-7381528"],

Cell[BoxData["\<\"HOZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223943-8122874"],

Cell[BoxData["\<\"HORefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223943-6416613"],

Cell[BoxData["\<\"HOGetView[] grabs the current heat flow output view and \
returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223943-1079780"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"HOClose[] close the current postprocessor document and \
window\"\>"], "Print",
 CellTags->"Info3347223943-5972664"],

Cell[BoxData["\<\"HOGetProblemInfo[] returns a list with two values: the \
Problem Type (0 for planar and 1 for axisymmetric) and the depth assumed for \
planar problems in units of meters.\"\>"], "Print",
 CellTags->"Info3347223943-4112961"],

Cell[BoxData["\<\"HOReload[] reloads the current heat flow output \
file.\"\>"], "Print",
 CellTags->"Info3347223943-2709084"],

Cell[BoxData["\<\"HOSaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the HISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223943-8970379"],

Cell[BoxData["\<\"HOSaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the HISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223943-7602098"],

Cell[BoxData["\<\"HOSetEditMode[\\\"mode\\\"] sets the mode of the \
postprocessor to point, contour, or area mode. Valid entries for mode are \
\\\"point\\\", \\\"contour\\\", and \\\"area\\\".\"\>"], "Print",
 CellTags->"Info3347223943-2781622"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Current Flow Output Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"COAddContour[x,y] adds the point {x,y} to the contour that \
is used for plotting values along lines and for computing line integrals.  An \
equivalent form is:\\n COAddContour[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-1412650"],

Cell[BoxData["\<\"COBendContour[angle,anglestep] replaces the straight line \
formed by the last two points in the contour by an arc that spans angle \
degrees. The arc is actually composed of many straight lines, each of which \
is constrained to span no more than anglestep degrees. The angle parameter \
can take on values from -180 to 180 degrees. The anglestep parameter must be \
greater than zero. If there are less than two points defined in the contour, \
this command is ignored.\"\>"], "Print",
 CellTags->"Info3347223943-9876552"],

Cell[BoxData["\<\"COClearContour[] clears the current contour \
selection\"\>"], "Print",
 CellTags->"Info3347223943-9911280"],

Cell[BoxData["\<\"COSelectBlock[x,y] select the block that contains point \
{x,y}.  An equivalent form is:\\n COSelectBlock[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-6335135"],

Cell[BoxData["\<\"COSelectPoint[x,y] adds a contour point at the closest \
input point to {x,y}. If the selected point and a previous selected points \
lie at the ends of an arcsegment, a contour is added that traces along the \
arcsegment. The selectpoint command has the same functionality as the \
left-button-click contour point selection when the program is running in \
interactive mode. An equivalent form is:\\n COSelectPoint[{x,y}]\"\>"], \
"Print",
 CellTags->"Info3347223943-9595876"],

Cell[BoxData["\<\"COGroupSelectBlock[n] selects all of the blocks that are \
labeled by block labels that are members of group n. If no number is \
specified (i.e. COGroupSelectBlock[]), all blocks are selected.\"\>"], "Print",
 CellTags->"Info3347223943-5396991"],

Cell[BoxData["\<\"COClearBlock[] clears the current block selection\"\>"], \
"Print",
 CellTags->"Info3347223943-6581954"],

Cell[BoxData["\<\"COBlockIntegral[type] calculate a block integral for the \
selected blocks. The type parameter can take on the following values:\\n      \
0   Real Power \\n      1   Reactive Power \\n      2   Apparent Power \\n    \
  3   Time-Average Stored Energy \\n      4   Block cross-section area \\n    \
  5   Block volume \\n      6   x (or r) direction Weighted Stress Tensor \
force, DC component \\n      7   y (or z) direction Weighted Stress Tensor \
force, DC component \\n      8   x (or r) direction Weighted Stress Tensor \
force, 2x frequency component \\n      9   y (or z) direction Weighted Stress \
Tensor force, 2x frequency component \\n      10  Weighted Stress Tensor \
torque, DC component \\n      11  Weighted Stress Tensor torque, 2x frequency \
component \\n Returns either a single value or a list of two values, \
depending on the specified type\"\>"], "Print",
 CellTags->"Info3347223943-8464511"],

Cell[BoxData["\<\"COLineIntegral[type] calculate the line integral for the \
defined contour. Valid type selections include:\\n  0  E.t \\n  1  J.n \\n  2 \
 Contour length \\n  3  Average voltage over contour \\n  4  Force from \
stress tensor \\n  5  Torque from stress tensor \\n This integral returns \
either one value or a list of two values, depending on the type of integral\"\
\>"], "Print",
 CellTags->"Info3347223943-4874601"],

Cell[BoxData["\<\"COMakePlot[PlotType,NumPoints,Filename,FileFormat]\\n This \
function allows programmatic access to FEMM's X-Y plot routines. If only \
PlotType or only PlotType and NumPoints are specified, the command is \
interpreted as a request to plot the requested plot type to the screen. If, \
in addition, the Filename parameter is specified, the plot is instead written \
to disk to the specified file name as an extended metafile. If the FileFormat \
parameter is also, the command is instead interpreted as a command to write \
the data to disk to the specfied file name, rather than display it to make a \
graphical plot. Valid entries for PlotType are: \\n  0   V (Voltage) \\n  1   \
|J| (Magnitude of current density) \\n  2   J.n (Normal current density) \\n  \
3   J.t (Tangential current density) \\n  4   |E (Magnitude of field \
intensity) \\n  5   E.n (Normal field intensity) \\n  6   E.t (Tangential \
field intensity) \\n  7   |Jc| (Magnitude of conduction current density) \\n  \
8   Jc.n (Normal conduction current density) \\n  9   Jc.t (Tangential \
conduction current density)} \\n  10  |Jd| (Magnitude of displacement current \
density) \\n  11  Jd.n (Normal displacement current density) \\n  12  Jd.t \
(Tangential displacement current density)\"\>"], "Print",
 CellTags->"Info3347223943-5629661"],

Cell[BoxData["\<\"COGetConductorProperties[\\\"conductor\\\"] returns \
properties for the conductor property named \\\"conductor\\\". A list with \
two values is returned: The voltage of the specified conductor, and the total \
current from the specified conductor.\"\>"], "Print",
 CellTags->"Info3347223943-4925532"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"COGetPointValues[x,y] returns the various field values \
associated with the point at {x,y}. The return values, in order, are:\\n V   \
& Voltage \\n Jx  & x- or r- direction component of current density \\n Jy  & \
y- or z- direction component of current density \\n Kx  & x- or r- direction \
component of AC conductivity \\n Ky  & y- or z- direction component of AC \
conductivity \\n Ex  & x- or r- direction component of electric field \
intensity \\n Ey  & y- or z- direction component of electric field intensity \
\\n ex  & x- or r- direction component of permittivity \\n ey  & y- or z- \
direction component of permittivity \\n Jdx & x- or r- direction component of \
displacement current density \\n Jdy & y- or z- direction component of \
displacement current density \\n ox  & x- or r- direction component of \
permittivity \\n oy  & y- or z- direction component of permittivity \\n Jcx & \
x- or r- direction component of conduction current density \\n Jcy & y- or z- \
direction component of conduction current density \\n An equivalent form is: \
\\n COGetPointValues[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-5246270"],

Cell[BoxData["\<\"COGetV[x,y] returns the voltage at point {x,y}. An \
equivalent form is:\\n COGetV[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-1445452"],

Cell[BoxData["\<\"COGetJ[x,y] returns a list with two elements containing the \
current density at point {x,y}.  An equivalent form is:\\n \
COGetJ[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-4450436"],

Cell[BoxData["\<\"COGetK[x,y] returns a list with two elements containing the \
ac conductivity at point {x,y}.  An equivalent form is:\\n \
COGetK[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-3881981"],

Cell[BoxData["\<\"COGetE[x,y] returns a list with two elements containing the \
 electric field intensity at point {x,y}. An equivalent form is:\\n \
COGetE[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-7228078"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"COShowContourPlot[numcontours,lowerV,upperV] shows the V \
contour plot with options:\\n numcontours - Number of equipotential lines to \
be plotted.\\n upperV - Upper limit for contours.\\n lowerV - Lower limit for \
contours.\\n If numcontours is -1 all parameters are ignored and default \
values are used\"\>"], "Print",
 CellTags->"Info3347223943-4602624"],

Cell[BoxData["\<\"COHideContourPlot[] hides the currently displayed contour \
plot\"\>"], "Print",
 CellTags->"Info3347223943-8450963"],

Cell[BoxData["\<\"COShowDensityPlot[legend,gscale,type,upper,lower]\\n Shows \
the flux density plot with options:\\n legend - Set to 0 to hide the plot \
legend or 1 to show the plot legend.\\n gscale - Set to 0 for a colour \
density plot or 1 for a grey scale density plot.\\n upper - Sets the upper \
display limit for the density plot.\\n lower - Sets the lower display limit \
for the density plot.\\n type - Sets the type of density plot. Plot types \
include:\\n 0  |V|\\n 1  |Re(V)|   \\n 2  |Im(V)|   \\n 3  |J|       \\n 4  \
|Re(J)|    \\n 5  |Im(J)|    \\n 6  |E|       \\n 7  |Re(E)|    \\n 8  \
|Im(E)|\"\>"], "Print",
 CellTags->"Info3347223943-6220742"],

Cell[BoxData["\<\"COHideDensityPlot[] hides the currently displayed density \
plot\"\>"], "Print",
 CellTags->"Info3347223943-7000860"],

Cell[BoxData["\<\"COSetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the type \
parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\"polar\\\" \
for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223943-5567665"],

Cell[BoxData["\<\"COShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223943-5586590"],

Cell[BoxData["\<\"COHideGrid[] hides the grid points from view in the current \
output window\"\>"], "Print",
 CellTags->"Info3347223943-2736516"],

Cell[BoxData["\<\"COShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223943-4561819"],

Cell[BoxData["\<\"COHideMesh[] hides the finite element mesh from in the \
current output view\"\>"], "Print",
 CellTags->"Info3347223943-9200808"],

Cell[BoxData["\<\"COShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223943-4835101"],

Cell[BoxData["\<\"COHideNames[] hides material names associated with block \
labels from view in the current output window\"\>"], "Print",
 CellTags->"Info3347223943-7355272"],

Cell[BoxData["\<\"COShowPoints[] displays the input node point as part of the \
output geometry\"\>"], "Print",
 CellTags->"Info3347223943-1181112"],

Cell[BoxData["\<\"COHidePoints[] inhibits the display of input node points in \
the current output window\"\>"], "Print",
 CellTags->"Info3347223943-2215272"],

Cell[BoxData["\<\"COSmoothOn[] turns on smoothing of the D and E fields.  The \
D and E fields are then displayed using a linear interpolation of the field \
from nodal values\"\>"], "Print",
 CellTags->"Info3347223943-1923535"],

Cell[BoxData["\<\"COSmoothOff[] turns off smoothing of the D and E fields.  \
The D and E fields are then displayed using values that are piecewise \
constant over each element.\"\>"], "Print",
 CellTags->"Info3347223943-8093696"],

Cell[BoxData["\<\"COSnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223943-6910008"],

Cell[BoxData["\<\"COSnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223943-1493678"],

Cell[BoxData["\<\"COZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n COZoom[{x1,y1},{x2,y2}]\\n \
COZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223943-3117515"],

Cell[BoxData["\<\"COZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223943-4832411"],

Cell[BoxData["\<\"COZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223943-8404433"],

Cell[BoxData["\<\"COZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223943-7328827"],

Cell[BoxData["\<\"CORefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223943-4746551"],

Cell[BoxData["\<\"COGetView[] grabs the current output view and returns a \
bitmapped graphics object.  This object can subsequently be displayed using \
the Show[] command\"\>"], "Print",
 CellTags->"Info3347223943-8409741"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"COClose[] close the current postprocessor document and \
window\"\>"], "Print",
 CellTags->"Info3347223943-8817053"],

Cell[BoxData["\<\"COGetProblemInfo[] returns a list with two values: the \
Problem Type (0 for planar and 1 for axisymmetric) and the depth assumed for \
planar problems in units of meters.\"\>"], "Print",
 CellTags->"Info3347223943-3716282"],

Cell[BoxData["\<\"COReload[] reloads the current output file.\"\>"], "Print",
 CellTags->"Info3347223943-8999170"],

Cell[BoxData["\<\"COSaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the CISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223943-5709094"],

Cell[BoxData["\<\"COSaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the CISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223943-3657880"],

Cell[BoxData["\<\"COSetEditMode[\\\"mode\\\"] sets the mode of the \
postprocessor to point, contour, or area mode. Valid entries for mode are \
\\\"point\\\", \\\"contour\\\", and \\\"area\\\".\"\>"], "Print",
 CellTags->"Info3347223943-6348310"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Magnetics Output Commands", "Section",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell["Contours, Regions, and Integrals", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MOAddContour[x,y] adds the point {x,y} to the contour that \
is used for plotting values along lines and for computinlocatedg line \
integrals.  An equivalent form is:\\n MOAddContour[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223943-5622619"],

Cell[BoxData["\<\"MOBendContour[angle,anglestep] replaces the straight line \
formed by the last two points in curvethe contour by an arc that spans angle \
degrees. The arc is actually composed of many straight lines, each of which \
is constrained to span no more than anglestep degrees. The angle parameter \
can take on values from -180 to 180 degrees. The anglestep parameter must be \
greater than zero. If there are less than two points defined in the contour, \
this command is ignored.\"\>"], "Print",
 CellTags->"Info3347223943-3212639"],

Cell[BoxData["\<\"MOClearContour[] clears the current contour \
selection\"\>"], "Print",
 CellTags->"Info3347223944-7593278"],

Cell[BoxData["\<\"MOSelectBlock[x,y] select the block that contains point \
{x,y}.  An equivalent form is:\\n MOSelectBlock[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-1223543"],

Cell[BoxData["\<\"MOSelectPoint[x,y] adds a contour point at the closest \
input point to {x,y}. If the selected point and a previous selected points \
lie at the ends of an arcsegment, a contour is added that traces along the \
arcsegment. The selectpoint command has the same functionality as the \
left-button-click contour point selection when the program is running in \
interactive mode. An equivalent form is:\\n MOSelectPoint[{x,y}]\"\>"], \
"Print",
 CellTags->"Info3347223944-6433330"],

Cell[BoxData["\<\"MOGroupSelectBlock[n] selects all of the blocks that are \
labeled by block labels that are members of group n. If no number is \
specified (i.e. MOGroupSelectBlock[]), all blocks are selected.\"\>"], "Print",
 CellTags->"Info3347223944-8548286"],

Cell[BoxData["\<\"MOClearBlock[] clears the current block selection\"\>"], \
"Print",
 CellTags->"Info3347223944-5636726"],

Cell[BoxData["\<\"MOBlockIntegral[type] calculates a block integral over the \
selected blocks.  There is a single (possibly complex) return value. Valid \
type specifications are:\\n 0 - A\[CenterDot]J \\n 1 - A \\n 2 - Magnetic \
field energy \\n 3 - Hysteresis and/or lamination losses \\n 4 - Resistive \
losses \\n 5 - Block cross-section area \\n 6 - Total losses \\n 7 - Total \
current \\n 8 - Integral of Bx (or Br) over block \\n 9 - Integral of By (or \
Bz) over block \\n 10 - Block volume \\n 11 - x (or r) part of steady-state \
Lorentz force \\n 12 - y (or z) part of steady-state Lorentz force \\n 13 - x \
(or r) part of 2X Lorentz force \\n 14 - y (or z) part of 2X Lorentz force \
\\n 15 - Steady-state Lorentz torque \\n 16 - 2X component of Lorentz torque \
\\n 17 - Magnetic field coenergy \\n 18 - x (or r) part of steady-state \
weighted stress tensor force \\n 19 - y (or z) part of steady-state weighted \
stress tensor force \\n 20 - x (or r) part of 2X weighted stress tensor force \
\\n 21 - y (or z) part of 2X weighted stress tensor force \\n 22 - \
Steady-state weighted stress tensor torque \\n 23 - 2X component of weighted \
stress tensor torque \\n 24 - R^2 (i.e. moment of inertia / density\"\>"], \
"Print",
 CellTags->"Info3347223944-6212195"],

Cell[BoxData["\<\"MOLineIntegral[type] calculates the line integral for the \
defined contour.  The following types of line integral and the return values \
are as follows:\\n 0 - total B.n, average B.n over the contour \\n 1 - total \
H.t, average H.t over the contour \\n 2 - Contour length, surface area \\n 3 \
- Stress Tensor Force: DC r/x force, DC y/z force, 2X r/x force, 2X y/z force\
\\n 4 - Stress Tensor Torque: DC torque, 2X torque \\n 5 - total (B.n)^2, \
average (B.n)^2 \\n Typically returns two (possibly complex) values as \
results. However, the Stress Tensor Force integral returns four \
values.\"\>"], "Print",
 CellTags->"Info3347223944-2446185"],

Cell[BoxData["\<\"MOMakePlot[PlotType,NumPoints,Filename,FileFormat]\\n This \
function allows programmatic access to FEMM's X-Y plot routines. If only \
PlotType or only PlotType and NumPoints are specified, the command is \
interpreted as a request to plot the requested plot type to the screen. If, \
in addition, the Filename parameter is specified, the plot is instead written \
to disk to the specified file name as an extended metafile. If the FileFormat \
parameter is also, the command is instead interpreted as a command to write \
the data to disk to the specfied file name, rather than display it to make a \
graphical plot. Valid entries for PlotType are: \\n 0 - Potential \\n 1 - |B| \
\\n 2 B\[CenterDot]n \\n 3 - B\[CenterDot]t \\n 4 - |H| \\n 5 - H \
\[CenterDot]n \\n 6 - H \[CenterDot]t \\n 7 - Jeddy \\n 8 - \
Jsource+Jeddy\"\>"], "Print",
 CellTags->"Info3347223944-4819550"],

Cell[BoxData["\<\"MOGetCircuitProperties[\\\"circuit\\\"] is used primarily \
to obtain impedance information associated with circuit properties. \
Properties are returned for the circuit property named \\\"circuit\\\". A \
list of three values is returned by the function. In order, the elements of \
this list are:\\n current -  the current carried by the circuit.\\n volts - \
the voltage drop across the circuit in the circuit.\\n flux - the circuit\
\[CloseCurlyQuote]s flux linkage\\n Any of these entries could possibly be \
complex-valued.\"\>"], "Print",
 CellTags->"Info3347223944-6414604"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Field Values", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MOGetPointValues[x,y] get the field values at {x,y}.  The \
function returns a list of values which represent:\\n A - vector potential A, \
flux=2*Pi*r*A if axisymmetric\\n B1 - Bx if planar, Br if axisymmetric\\n B2 \
- By if planar, Bz if axisymmetric\\n Sig - conductivity\\n E - stored energy \
density\\n H1 - Hx if planar, Hr if axisymmetric\\n H2 - Hy if planar, Hz if \
axisymmetric\\n Je - Eddy current contribution to current density\\n Js - \
Source current contribution to current density\\n Mu1 - mux if planar, mur if \
axisymmetric\\n Mu2 - muy if planar, muz if axisymmetric\\n Pe - Power \
density dissipated through ohmic losses\\n Ph - Power density dissipated by \
hysteresis\\n ff - Winding fill factor\"\>"], "Print",
 CellTags->"Info3347223944-6619072"],

Cell[BoxData["\<\"MOGetA[x,y] returns the vector potential, A, for 2D planar \
problems, and it returns flux, 2*Pi*r*A, for axisymmetric problems.  The \
return value is possbly complex-valued. An equivalent form is:\\n \
MOGetA[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-4082389"],

Cell[BoxData["\<\"MOGetB[x,y] returns a list with two elements containing the \
magnetic flux density at point {x,y}.  An equivalent form is:\\n \
MOGetB[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-3243349"],

Cell[BoxData["\<\"MOGetH[x,y] returns a list with two elements containing the \
magnetic field intensity at point {x,y}.  An equivalent form is:\\n \
MOGetB[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-9833440"],

Cell[BoxData["\<\"MOGetJ[x,y] returns the electric current density at point \
{x,y}. An equivalent form is:\\n MOGetJ[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-9033299"],

Cell[BoxData["\<\"MOGetMu[x,y] returns a list with two elements containing \
the magnetic permeability at point {x,y}.  An equivalent form is:\\n \
MOGetMu[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-7106424"],

Cell[BoxData["\<\"MOGetPe[x,y] returns the electrical (ohmic) loss density at \
point {x,y}. An equivalent form is:\\n MOGetMu[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-2091162"],

Cell[BoxData["\<\"MOGetPh[x,y] returns the hysteresis and/or laminated eddy \
current loss density at point {x,y}. An equivalent form is:\\n MOGetPh[{x,y}]\
\"\>"], "Print",
 CellTags->"Info3347223944-1590385"],

Cell[BoxData["\<\"MOGetConductivity[x,y] returns the electrical conductivity \
at point {x,y}. An equivalent form is:\\n MOGetConductivity[{x,y}]\"\>"], \
"Print",
 CellTags->"Info3347223944-5449929"],

Cell[BoxData["\<\"MOGetEnergyDensity[x,y] returns the energy density in the \
magnetic field at point {x,y}. An equivalent form is:\\n \
MOGetEnergyDensity[{x,y}]\"\>"], "Print",
 CellTags->"Info3347223944-5484391"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["View Manipulation", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MOShowContourPlot[numcontours,lowerA,upperA,type] shows the \
A contour plot with options:\\n numcontours - Number of A equipotential lines \
to be plotted. \\n upperA - Upper limit for A contours. \\n lowerA - Lower \
limit for A contours. \\n type - Choice of \\\"real\\\", \\\"imag\\\", or \
\\\"both\\\" to show either the real, imaginary of both real and imaginary \
components of A.\\n If numcontours is -1, all parameters are ignored and \
default values are used\"\>"], "Print",
 CellTags->"Info3347223944-8026549"],

Cell[BoxData["\<\"MOHideContourPlot[] hides the currently displayed contour \
plot\"\>"], "Print",
 CellTags->"Info3347223944-6509291"],

Cell[BoxData["\<\"MOShowDensityPlot[legend,gscale,upperB,lowerB,type]\\n \
shows the flux density plot with the options: \\n legend - Set to 0 to hide \
the plot legend or 1 to show the plot legend.\\n gscale - Set to 0 for a \
colour density plot or 1 for a grey scaledensity plot.\\n upperB - Sets the \
upper display limit for the density plot.\\n lowerB - Sets the lower display \
limit for the density plot.\\n type - Type of density plot to display. Valid \
entries are \\\"mag\\\", \\\"real\\\", and \\\"imag\\\" for magnitude, real \
component, and imaginary component of B, respectively. Alternatively, current \
density can be displayed by specifying \\\"jmag\\\", \\\"jreal\\\", and \
\\\"jimag\\\" for magnitude, real component, and imaginary component of J, \
respectively.\\n If legend is set to -1 all parameters are ignored and \
default values are used\"\>"], "Print",
 CellTags->"Info3347223944-9854803"],

Cell[BoxData["\<\"MOHideDensityPlot[] hides the currently displayed density \
plot\"\>"], "Print",
 CellTags->"Info3347223944-4587203"],

Cell[BoxData["\<\"MOSetGrid[density,\\\"type\\\"] changes the grid spacing. \
The density parameter specifies the space between grid points, and the type \
parameter is set to \\\"cart\\\" for Cartesian coordinates or \\\"polar\\\" \
for polar coordinates.\"\>"], "Print",
 CellTags->"Info3347223944-6627152"],

Cell[BoxData["\<\"MOShowGrid[] displays the grid points\"\>"], "Print",
 CellTags->"Info3347223944-9677027"],

Cell[BoxData["\<\"MOHideGrid[] hides the grid points from view in the \
electrostatics output window\"\>"], "Print",
 CellTags->"Info3347223944-7882672"],

Cell[BoxData["\<\"MOShowMesh[] displays the mesh\"\>"], "Print",
 CellTags->"Info3347223944-5172316"],

Cell[BoxData["\<\"MOHideMesh[] hides the finite element mesh from in the \
electrostatics output view\"\>"], "Print",
 CellTags->"Info3347223944-1205732"],

Cell[BoxData["\<\"MOShowNames[] displays the material names associated with \
each block label\"\>"], "Print",
 CellTags->"Info3347223944-8443384"],

Cell[BoxData["\<\"MOHideNames[] hides material names associated with block \
labels from view in the electrostatics output window\"\>"], "Print",
 CellTags->"Info3347223944-8424884"],

Cell[BoxData["\<\"MOShowPoints[] displays the input node point as part of the \
output geometry\"\>"], "Print",
 CellTags->"Info3347223944-9112071"],

Cell[BoxData["\<\"MOHidePoints[] inhibits the display of input node points in \
the electrostatics output window\"\>"], "Print",
 CellTags->"Info3347223944-5725100"],

Cell[BoxData["\<\"MOSmoothOn[] turns on smoothing of the D and E fields.  The \
D and E fields are then displayed using a linear interpolation of the field \
from nodal values\"\>"], "Print",
 CellTags->"Info3347223944-3763668"],

Cell[BoxData["\<\"MOSmoothOff[] turns off smoothing of the D and E fields.  \
The D and E fields are then displayed using values that are piecewise \
constant over each element.\"\>"], "Print",
 CellTags->"Info3347223944-5023528"],

Cell[BoxData["\<\"MOSnapGridOn[] turns on snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223944-6332496"],

Cell[BoxData["\<\"MOSnapGridOff[] turns off snap-to-grid\"\>"], "Print",
 CellTags->"Info3347223944-1601766"],

Cell[BoxData["\<\"MOZoom[x1,y1,x2,y2] Set the display area to be from the \
bottom left corner specified by {x1,y1} to the top right corner specified by \
{x2,y2}. Equivalent forms are:\\n MOZoom[{x1,y1},{x2,y2}]\\n \
MOZoom[{{x1,y1},{x2,y2}}]\"\>"], "Print",
 CellTags->"Info3347223944-9984544"],

Cell[BoxData["\<\"MOZoomIn[] zooms out by a factor of 200%.\"\>"], "Print",
 CellTags->"Info3347223944-8912656"],

Cell[BoxData["\<\"MOZoomNatural[] zooms to a \\\"natural\\\" view with \
sensible extents.\"\>"], "Print",
 CellTags->"Info3347223944-6144805"],

Cell[BoxData["\<\"MOZoomOut[] zooms out by a factor of 50%.\"\>"], "Print",
 CellTags->"Info3347223944-4339604"],

Cell[BoxData["\<\"MORefreshView[] Redraws the current view.\"\>"], "Print",
 CellTags->"Info3347223944-7164196"],

Cell[BoxData["\<\"MOGetView[] grabs the current electrostatics output view \
and returns a bitmapped graphics object.  This object can subsequently be \
displayed using the Show[] command\"\>"], "Print",
 CellTags->"Info3347223944-7748027"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Miscellaneous", "Subsection",
 GeneratedCell->True,
 CellAutoOverwrite->True],

Cell[CellGroupData[{

Cell[BoxData["\<\"MOClose[] close the current postprocessor document and \
window\"\>"], "Print",
 CellTags->"Info3347223944-7495296"],

Cell[BoxData["\<\"MOGetProblemInfo[] returns a list of two values: the \
problem type (0 for planar, 1 for axisymmetric) and the analysis frequency in \
Hz.\"\>"], "Print",
 CellTags->"Info3347223944-8982714"],

Cell[BoxData["\<\"MOReload[] reloads the current electrostatics output \
file.\"\>"], "Print",
 CellTags->"Info3347223944-8993898"],

Cell[BoxData["\<\"MOSaveBitmap[\\\"filename\\\"] saves a bitmapped screenshot \
of the current view to the file specified by \\\"filename\\\", subject to the \
printf-type formatting explained previously for the EISaveAs command.\"\>"], \
"Print",
 CellTags->"Info3347223944-1732994"],

Cell[BoxData["\<\"MOSaveMetafile[\\\"filename\\\"] saves an extended metafile \
screenshot of the current view to the file specified by \\\"filename\\\", \
subject to the printf-type formatting explained previously for the EISaveAs \
command.\"\>"], "Print",
 CellTags->"Info3347223944-1385772"],

Cell[BoxData["\<\"MOSetEditMode[\\\"mode\\\"] sets the mode of the \
postprocessor to point, contour, or area mode. Valid entries for mode are \
\\\"point\\\", \\\"contour\\\", and \\\"area\\\".\"\>"], "Print",
 CellTags->"Info3347223944-8600115"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1101, 751},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"7.0 for Microsoft Windows (32-bit) (November 10, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3347223940-6631621"->{
  Cell[2633, 71, 170, 2, 23, "Print",
   CellTags->"Info3347223940-6631621"]},
 "Info3347223940-4294206"->{
  Cell[2806, 75, 172, 2, 23, "Print",
   CellTags->"Info3347223940-4294206"]},
 "Info3347223940-6810511"->{
  Cell[2981, 79, 359, 5, 62, "Print",
   CellTags->"Info3347223940-6810511"]},
 "Info3347223940-7389295"->{
  Cell[3343, 86, 151, 2, 23, "Print",
   CellTags->"Info3347223940-7389295"]},
 "Info3347223940-2382490"->{
  Cell[3497, 90, 126, 2, 23, "Print",
   CellTags->"Info3347223940-2382490"]},
 "Info3347223940-6023529"->{
  Cell[3626, 94, 133, 2, 23, "Print",
   CellTags->"Info3347223940-6023529"]},
 "Info3347223940-6503571"->{
  Cell[3762, 98, 114, 1, 23, "Print",
   CellTags->"Info3347223940-6503571"]},
 "Info3347223940-5379615"->{
  Cell[3879, 101, 123, 2, 23, "Print",
   CellTags->"Info3347223940-5379615"]},
 "Info3347223940-1834069"->{
  Cell[4005, 105, 160, 2, 23, "Print",
   CellTags->"Info3347223940-1834069"]},
 "Info3347223940-7924268"->{
  Cell[4168, 109, 255, 3, 43, "Print",
   CellTags->"Info3347223940-7924268"]},
 "Info3347223940-7939632"->{
  Cell[4426, 114, 154, 2, 23, "Print",
   CellTags->"Info3347223940-7939632"]},
 "Info3347223940-6833855"->{
  Cell[4583, 118, 275, 4, 43, "Print",
   CellTags->"Info3347223940-6833855"]},
 "Info3347223940-1189387"->{
  Cell[4861, 124, 141, 2, 23, "Print",
   CellTags->"Info3347223940-1189387"]},
 "Info3347223940-1293541"->{
  Cell[5005, 128, 66, 1, 23, "Print",
   CellTags->"Info3347223940-1293541"],
  Cell[5074, 131, 967, 26, 23, "Print",
   CellTags->"Info3347223940-1293541"]},
 "Info3347223940-8692552"->{
  Cell[6342, 175, 815, 11, 119, "Print",
   CellTags->"Info3347223940-8692552"]},
 "Info3347223940-9972450"->{
  Cell[7160, 188, 383, 5, 62, "Print",
   CellTags->"Info3347223940-9972450"],
  Cell[7546, 195, 283, 5, 23, "Print",
   CellTags->"Info3347223940-9972450"],
  Cell[31507, 703, 280, 5, 23, "Print",
   CellTags->"Info3347223940-9972450"],
  Cell[56122, 1221, 334, 6, 23, "Print",
   CellTags->"Info3347223940-9972450"]},
 "Info3347223940-4605738"->{
  Cell[7832, 202, 360, 5, 81, "Print",
   CellTags->"Info3347223940-4605738"]},
 "Info3347223940-4732625"->{
  Cell[8195, 209, 254, 3, 43, "Print",
   CellTags->"Info3347223940-4732625"]},
 "Info3347223940-4167237"->{
  Cell[8452, 214, 750, 10, 176, "Print",
   CellTags->"Info3347223940-4167237"]},
 "Info3347223940-9087758"->{
  Cell[9205, 226, 659, 9, 138, "Print",
   CellTags->"Info3347223940-9087758"]},
 "Info3347223940-5926772"->{
  Cell[9867, 237, 708, 9, 119, "Print",
   CellTags->"Info3347223940-5926772"]},
 "Info3347223940-8501482"->{
  Cell[10578, 248, 562, 7, 119, "Print",
   CellTags->"Info3347223940-8501482"]},
 "Info3347223940-7144037"->{
  Cell[11143, 257, 172, 2, 23, "Print",
   CellTags->"Info3347223940-7144037"]},
 "Info3347223940-2011507"->{
  Cell[11318, 261, 173, 2, 23, "Print",
   CellTags->"Info3347223940-2011507"]},
 "Info3347223940-6339513"->{
  Cell[11494, 265, 169, 2, 23, "Print",
   CellTags->"Info3347223940-6339513"]},
 "Info3347223940-5174597"->{
  Cell[11666, 269, 169, 2, 23, "Print",
   CellTags->"Info3347223940-5174597"]},
 "Info3347223940-1062849"->{
  Cell[12002, 283, 560, 8, 100, "Print",
   CellTags->"Info3347223940-1062849"]},
 "Info3347223940-3542961"->{
  Cell[12565, 293, 182, 2, 43, "Print",
   CellTags->"Info3347223940-3542961"]},
 "Info3347223940-1600426"->{
  Cell[12750, 297, 156, 2, 43, "Print",
   CellTags->"Info3347223940-1600426"]},
 "Info3347223940-4337716"->{
  Cell[12909, 301, 273, 4, 62, "Print",
   CellTags->"Info3347223940-4337716"]},
 "Info3347223941-1813366"->{
  Cell[13185, 307, 583, 8, 119, "Print",
   CellTags->"Info3347223941-1813366"]},
 "Info3347223941-1118594"->{
  Cell[13771, 317, 275, 4, 62, "Print",
   CellTags->"Info3347223941-1118594"]},
 "Info3347223941-5737972"->{
  Cell[14049, 323, 210, 3, 23, "Print",
   CellTags->"Info3347223941-5737972"]},
 "Info3347223941-7410441"->{
  Cell[14262, 328, 234, 3, 43, "Print",
   CellTags->"Info3347223941-7410441"]},
 "Info3347223941-8640170"->{
  Cell[14499, 333, 289, 4, 62, "Print",
   CellTags->"Info3347223941-8640170"]},
 "Info3347223941-1951187"->{
  Cell[14791, 339, 204, 3, 43, "Print",
   CellTags->"Info3347223941-1951187"]},
 "Info3347223941-8197922"->{
  Cell[15172, 354, 191, 2, 43, "Print",
   CellTags->"Info3347223941-8197922"]},
 "Info3347223941-2611265"->{
  Cell[15366, 358, 259, 3, 43, "Print",
   CellTags->"Info3347223941-2611265"]},
 "Info3347223941-9442840"->{
  Cell[15628, 363, 181, 2, 43, "Print",
   CellTags->"Info3347223941-9442840"]},
 "Info3347223941-7245219"->{
  Cell[15812, 367, 172, 2, 43, "Print",
   CellTags->"Info3347223941-7245219"]},
 "Info3347223941-5798128"->{
  Cell[15987, 371, 181, 2, 43, "Print",
   CellTags->"Info3347223941-5798128"]},
 "Info3347223941-1459018"->{
  Cell[16171, 375, 830, 11, 138, "Print",
   CellTags->"Info3347223941-1459018"]},
 "Info3347223941-1589458"->{
  Cell[17004, 388, 495, 6, 100, "Print",
   CellTags->"Info3347223941-1589458"]},
 "Info3347223941-8534708"->{
  Cell[17502, 396, 421, 5, 62, "Print",
   CellTags->"Info3347223941-8534708"]},
 "Info3347223941-7553760"->{
  Cell[17926, 403, 740, 9, 176, "Print",
   CellTags->"Info3347223941-7553760"]},
 "Info3347223941-9188284"->{
  Cell[18669, 414, 121, 2, 23, "Print",
   CellTags->"Info3347223941-9188284"]},
 "Info3347223941-7542695"->{
  Cell[18793, 418, 137, 2, 23, "Print",
   CellTags->"Info3347223941-7542695"]},
 "Info3347223941-2715154"->{
  Cell[18933, 422, 132, 2, 23, "Print",
   CellTags->"Info3347223941-2715154"]},
 "Info3347223941-2795720"->{
  Cell[19068, 426, 124, 2, 23, "Print",
   CellTags->"Info3347223941-2795720"]},
 "Info3347223941-9823357"->{
  Cell[19195, 430, 130, 2, 23, "Print",
   CellTags->"Info3347223941-9823357"]},
 "Info3347223941-8020983"->{
  Cell[19328, 434, 151, 2, 23, "Print",
   CellTags->"Info3347223941-8020983"]},
 "Info3347223941-4999920"->{
  Cell[19482, 438, 666, 9, 100, "Print",
   CellTags->"Info3347223941-4999920"]},
 "Info3347223941-6637905"->{
  Cell[20151, 449, 242, 3, 43, "Print",
   CellTags->"Info3347223941-6637905"]},
 "Info3347223941-9601905"->{
  Cell[20396, 454, 246, 3, 43, "Print",
   CellTags->"Info3347223941-9601905"]},
 "Info3347223941-1464798"->{
  Cell[20803, 469, 500, 7, 138, "Print",
   CellTags->"Info3347223941-1464798"]},
 "Info3347223941-1770110"->{
  Cell[21306, 478, 445, 6, 119, "Print",
   CellTags->"Info3347223941-1770110"]},
 "Info3347223941-2471642"->{
  Cell[21754, 486, 437, 6, 100, "Print",
   CellTags->"Info3347223941-2471642"]},
 "Info3347223941-7586356"->{
  Cell[22194, 494, 440, 6, 119, "Print",
   CellTags->"Info3347223941-7586356"]},
 "Info3347223941-4155620"->{
  Cell[22637, 502, 366, 5, 100, "Print",
   CellTags->"Info3347223941-4155620"]},
 "Info3347223941-3197855"->{
  Cell[23006, 509, 435, 6, 100, "Print",
   CellTags->"Info3347223941-3197855"]},
 "Info3347223941-8920274"->{
  Cell[23602, 527, 317, 4, 43, "Print",
   CellTags->"Info3347223941-8920274"]},
 "Info3347223941-2580618"->{
  Cell[23922, 533, 108, 1, 23, "Print",
   CellTags->"Info3347223941-2580618"]},
 "Info3347223941-5009207"->{
  Cell[24033, 536, 128, 2, 23, "Print",
   CellTags->"Info3347223941-5009207"]},
 "Info3347223941-1486463"->{
  Cell[24164, 540, 101, 1, 23, "Print",
   CellTags->"Info3347223941-1486463"]},
 "Info3347223941-2487122"->{
  Cell[24268, 543, 137, 2, 23, "Print",
   CellTags->"Info3347223941-2487122"]},
 "Info3347223941-6450972"->{
  Cell[24408, 547, 147, 2, 23, "Print",
   CellTags->"Info3347223941-6450972"]},
 "Info3347223941-4162216"->{
  Cell[24558, 551, 173, 2, 23, "Print",
   CellTags->"Info3347223941-4162216"]},
 "Info3347223941-6354640"->{
  Cell[24734, 555, 107, 1, 23, "Print",
   CellTags->"Info3347223941-6354640"]},
 "Info3347223941-5746827"->{
  Cell[24844, 558, 109, 1, 23, "Print",
   CellTags->"Info3347223941-5746827"]},
 "Info3347223941-2691935"->{
  Cell[24956, 561, 296, 4, 81, "Print",
   CellTags->"Info3347223941-2691935"]},
 "Info3347223941-7877067"->{
  Cell[25255, 567, 112, 1, 23, "Print",
   CellTags->"Info3347223941-7877067"]},
 "Info3347223941-7749989"->{
  Cell[25370, 570, 143, 2, 23, "Print",
   CellTags->"Info3347223941-7749989"]},
 "Info3347223941-3231106"->{
  Cell[25516, 574, 112, 1, 23, "Print",
   CellTags->"Info3347223941-3231106"]},
 "Info3347223941-3377092"->{
  Cell[25631, 577, 239, 3, 43, "Print",
   CellTags->"Info3347223941-3377092"]},
 "Info3347223941-4876077"->{
  Cell[26030, 592, 369, 5, 62, "Print",
   CellTags->"Info3347223941-4876077"]},
 "Info3347223941-3439479"->{
  Cell[26402, 599, 148, 2, 23, "Print",
   CellTags->"Info3347223941-3439479"]},
 "Info3347223941-7653090"->{
  Cell[26553, 603, 275, 4, 43, "Print",
   CellTags->"Info3347223941-7653090"]},
 "Info3347223941-7874582"->{
  Cell[26831, 609, 160, 2, 23, "Print",
   CellTags->"Info3347223941-7874582"]},
 "Info3347223941-5235115"->{
  Cell[26994, 613, 1073, 14, 138, "Print",
   CellTags->"Info3347223941-5235115"]},
 "Info3347223941-7704576"->{
  Cell[28070, 629, 171, 2, 23, "Print",
   CellTags->"Info3347223941-7704576"]},
 "Info3347223941-4043808"->{
  Cell[28244, 633, 112, 1, 23, "Print",
   CellTags->"Info3347223941-4043808"]},
 "Info3347223941-3418109"->{
  Cell[28359, 636, 246, 3, 43, "Print",
   CellTags->"Info3347223941-3418109"]},
 "Info3347223941-6580237"->{
  Cell[28608, 641, 284, 4, 43, "Print",
   CellTags->"Info3347223941-6580237"]},
 "Info3347223941-6852624"->{
  Cell[28895, 647, 295, 4, 43, "Print",
   CellTags->"Info3347223941-6852624"]},
 "Info3347223941-1422078"->{
  Cell[29193, 653, 444, 6, 138, "Print",
   CellTags->"Info3347223941-1422078"]},
 "Info3347223941-2029304"->{
  Cell[29640, 661, 508, 7, 62, "Print",
   CellTags->"Info3347223941-2029304"]},
 "Info3347223941-8989917"->{
  Cell[30456, 687, 1048, 14, 176, "Print",
   CellTags->"Info3347223941-8989917"]},
 "Info3347223941-3552733"->{
  Cell[31790, 710, 394, 5, 62, "Print",
   CellTags->"Info3347223941-3552733"]},
 "Info3347223941-6176457"->{
  Cell[32187, 717, 367, 5, 81, "Print",
   CellTags->"Info3347223941-6176457"]},
 "Info3347223941-8109493"->{
  Cell[32557, 724, 258, 3, 43, "Print",
   CellTags->"Info3347223941-8109493"]},
 "Info3347223941-6089851"->{
  Cell[32818, 729, 811, 11, 195, "Print",
   CellTags->"Info3347223941-6089851"]},
 "Info3347223941-7134049"->{
  Cell[33632, 742, 673, 9, 138, "Print",
   CellTags->"Info3347223941-7134049"]},
 "Info3347223941-7244468"->{
  Cell[34308, 753, 715, 9, 119, "Print",
   CellTags->"Info3347223941-7244468"]},
 "Info3347223941-4415755"->{
  Cell[35026, 764, 567, 7, 119, "Print",
   CellTags->"Info3347223941-4415755"]},
 "Info3347223941-9094170"->{
  Cell[35596, 773, 172, 2, 23, "Print",
   CellTags->"Info3347223941-9094170"]},
 "Info3347223941-3611725"->{
  Cell[35771, 777, 173, 2, 23, "Print",
   CellTags->"Info3347223941-3611725"]},
 "Info3347223941-9967462"->{
  Cell[35947, 781, 169, 2, 23, "Print",
   CellTags->"Info3347223941-9967462"]},
 "Info3347223941-4309295"->{
  Cell[36119, 785, 169, 2, 23, "Print",
   CellTags->"Info3347223941-4309295"]},
 "Info3347223941-8260624"->{
  Cell[36455, 799, 560, 8, 100, "Print",
   CellTags->"Info3347223941-8260624"]},
 "Info3347223941-8492284"->{
  Cell[37018, 809, 182, 2, 43, "Print",
   CellTags->"Info3347223941-8492284"]},
 "Info3347223941-8438704"->{
  Cell[37203, 813, 156, 2, 43, "Print",
   CellTags->"Info3347223941-8438704"]},
 "Info3347223941-3285558"->{
  Cell[37362, 817, 273, 4, 62, "Print",
   CellTags->"Info3347223941-3285558"]},
 "Info3347223941-1354509"->{
  Cell[37638, 823, 578, 8, 119, "Print",
   CellTags->"Info3347223941-1354509"]},
 "Info3347223941-1355904"->{
  Cell[38219, 833, 275, 4, 62, "Print",
   CellTags->"Info3347223941-1355904"]},
 "Info3347223941-8370622"->{
  Cell[38497, 839, 210, 3, 23, "Print",
   CellTags->"Info3347223941-8370622"]},
 "Info3347223941-2291614"->{
  Cell[38710, 844, 234, 3, 43, "Print",
   CellTags->"Info3347223941-2291614"]},
 "Info3347223941-7771765"->{
  Cell[38947, 849, 289, 4, 62, "Print",
   CellTags->"Info3347223941-7771765"]},
 "Info3347223941-7568170"->{
  Cell[39239, 855, 204, 3, 43, "Print",
   CellTags->"Info3347223941-7568170"]},
 "Info3347223941-5343679"->{
  Cell[39620, 870, 191, 2, 43, "Print",
   CellTags->"Info3347223941-5343679"]},
 "Info3347223941-5864838"->{
  Cell[39814, 874, 259, 3, 43, "Print",
   CellTags->"Info3347223941-5864838"]},
 "Info3347223941-7809650"->{
  Cell[40076, 879, 181, 2, 43, "Print",
   CellTags->"Info3347223941-7809650"]},
 "Info3347223941-2458221"->{
  Cell[40260, 883, 172, 2, 43, "Print",
   CellTags->"Info3347223941-2458221"]},
 "Info3347223941-1974298"->{
  Cell[40435, 887, 181, 2, 43, "Print",
   CellTags->"Info3347223941-1974298"]},
 "Info3347223941-7595909"->{
  Cell[40619, 891, 830, 11, 138, "Print",
   CellTags->"Info3347223941-7595909"]},
 "Info3347223941-2077596"->{
  Cell[41452, 904, 495, 6, 100, "Print",
   CellTags->"Info3347223941-2077596"]},
 "Info3347223941-6833115"->{
  Cell[41950, 912, 421, 5, 62, "Print",
   CellTags->"Info3347223941-6833115"]},
 "Info3347223941-8415350"->{
  Cell[42374, 919, 740, 9, 176, "Print",
   CellTags->"Info3347223941-8415350"]},
 "Info3347223941-7920837"->{
  Cell[43117, 930, 121, 2, 23, "Print",
   CellTags->"Info3347223941-7920837"]},
 "Info3347223941-5070483"->{
  Cell[43241, 934, 137, 2, 23, "Print",
   CellTags->"Info3347223941-5070483"]},
 "Info3347223941-1032206"->{
  Cell[43381, 938, 132, 2, 23, "Print",
   CellTags->"Info3347223941-1032206"]},
 "Info3347223941-1376349"->{
  Cell[43516, 942, 124, 2, 23, "Print",
   CellTags->"Info3347223941-1376349"]},
 "Info3347223941-7407861"->{
  Cell[43643, 946, 130, 2, 23, "Print",
   CellTags->"Info3347223941-7407861"]},
 "Info3347223941-2948475"->{
  Cell[43776, 950, 151, 2, 23, "Print",
   CellTags->"Info3347223941-2948475"]},
 "Info3347223941-8742318"->{
  Cell[43930, 954, 666, 9, 100, "Print",
   CellTags->"Info3347223941-8742318"]},
 "Info3347223941-9656730"->{
  Cell[44599, 965, 242, 3, 43, "Print",
   CellTags->"Info3347223941-9656730"]},
 "Info3347223941-1145073"->{
  Cell[44844, 970, 246, 3, 43, "Print",
   CellTags->"Info3347223941-1145073"]},
 "Info3347223941-4193583"->{
  Cell[45251, 985, 500, 7, 138, "Print",
   CellTags->"Info3347223941-4193583"]},
 "Info3347223941-6993551"->{
  Cell[45754, 994, 445, 6, 119, "Print",
   CellTags->"Info3347223941-6993551"]},
 "Info3347223941-6453383"->{
  Cell[46202, 1002, 437, 6, 100, "Print",
   CellTags->"Info3347223941-6453383"]},
 "Info3347223941-7559587"->{
  Cell[46642, 1010, 440, 6, 119, "Print",
   CellTags->"Info3347223941-7559587"]},
 "Info3347223941-5358822"->{
  Cell[47085, 1018, 366, 5, 100, "Print",
   CellTags->"Info3347223941-5358822"]},
 "Info3347223941-6682568"->{
  Cell[47454, 1025, 435, 6, 100, "Print",
   CellTags->"Info3347223941-6682568"]},
 "Info3347223941-3512651"->{
  Cell[48050, 1043, 317, 4, 43, "Print",
   CellTags->"Info3347223941-3512651"]},
 "Info3347223941-8850662"->{
  Cell[48370, 1049, 108, 1, 23, "Print",
   CellTags->"Info3347223941-8850662"]},
 "Info3347223941-7730051"->{
  Cell[48481, 1052, 123, 2, 23, "Print",
   CellTags->"Info3347223941-7730051"]},
 "Info3347223941-2942451"->{
  Cell[48607, 1056, 101, 1, 23, "Print",
   CellTags->"Info3347223941-2942451"]},
 "Info3347223941-3089129"->{
  Cell[48711, 1059, 137, 2, 23, "Print",
   CellTags->"Info3347223941-3089129"]},
 "Info3347223941-3186031"->{
  Cell[48851, 1063, 147, 2, 23, "Print",
   CellTags->"Info3347223941-3186031"]},
 "Info3347223941-4802215"->{
  Cell[49001, 1067, 173, 2, 23, "Print",
   CellTags->"Info3347223941-4802215"]},
 "Info3347223941-8163804"->{
  Cell[49177, 1071, 107, 1, 23, "Print",
   CellTags->"Info3347223941-8163804"]},
 "Info3347223941-6931229"->{
  Cell[49287, 1074, 109, 1, 23, "Print",
   CellTags->"Info3347223941-6931229"]},
 "Info3347223941-9964984"->{
  Cell[49399, 1077, 296, 4, 81, "Print",
   CellTags->"Info3347223941-9964984"]},
 "Info3347223941-4270299"->{
  Cell[49698, 1083, 112, 1, 23, "Print",
   CellTags->"Info3347223941-4270299"]},
 "Info3347223941-7308454"->{
  Cell[49813, 1086, 143, 2, 23, "Print",
   CellTags->"Info3347223941-7308454"]},
 "Info3347223941-7750860"->{
  Cell[49959, 1090, 112, 1, 23, "Print",
   CellTags->"Info3347223941-7750860"]},
 "Info3347223941-3895549"->{
  Cell[50074, 1093, 234, 3, 43, "Print",
   CellTags->"Info3347223941-3895549"]},
 "Info3347223941-4236356"->{
  Cell[50468, 1108, 364, 5, 62, "Print",
   CellTags->"Info3347223941-4236356"]},
 "Info3347223941-2245144"->{
  Cell[50835, 1115, 148, 2, 23, "Print",
   CellTags->"Info3347223941-2245144"]},
 "Info3347223941-8159017"->{
  Cell[50986, 1119, 275, 4, 43, "Print",
   CellTags->"Info3347223941-8159017"]},
 "Info3347223941-8125029"->{
  Cell[51264, 1125, 160, 2, 23, "Print",
   CellTags->"Info3347223941-8125029"]},
 "Info3347223941-5725470"->{
  Cell[51427, 1129, 1073, 14, 138, "Print",
   CellTags->"Info3347223941-5725470"]},
 "Info3347223941-8114379"->{
  Cell[52503, 1145, 171, 2, 23, "Print",
   CellTags->"Info3347223941-8114379"]},
 "Info3347223941-7760450"->{
  Cell[52677, 1149, 112, 1, 23, "Print",
   CellTags->"Info3347223941-7760450"]},
 "Info3347223941-7609199"->{
  Cell[52792, 1152, 246, 3, 43, "Print",
   CellTags->"Info3347223941-7609199"]},
 "Info3347223941-8492301"->{
  Cell[53041, 1157, 284, 4, 43, "Print",
   CellTags->"Info3347223941-8492301"]},
 "Info3347223941-8350572"->{
  Cell[53328, 1163, 295, 4, 43, "Print",
   CellTags->"Info3347223941-8350572"]},
 "Info3347223941-7702967"->{
  Cell[53626, 1169, 444, 6, 138, "Print",
   CellTags->"Info3347223941-7702967"]},
 "Info3347223941-7628927"->{
  Cell[54073, 1177, 496, 6, 62, "Print",
   CellTags->"Info3347223941-7628927"]},
 "Info3347223941-2550021"->{
  Cell[54902, 1201, 830, 11, 119, "Print",
   CellTags->"Info3347223941-2550021"]},
 "Info3347223941-9246453"->{
  Cell[55735, 1214, 384, 5, 62, "Print",
   CellTags->"Info3347223941-9246453"]},
 "Info3347223941-6719514"->{
  Cell[56459, 1229, 579, 8, 138, "Print",
   CellTags->"Info3347223941-6719514"]},
 "Info3347223941-3075263"->{
  Cell[57041, 1239, 254, 3, 43, "Print",
   CellTags->"Info3347223941-3075263"]},
 "Info3347223941-1794145"->{
  Cell[57298, 1244, 763, 10, 195, "Print",
   CellTags->"Info3347223941-1794145"]},
 "Info3347223941-2809827"->{
  Cell[58064, 1256, 661, 9, 138, "Print",
   CellTags->"Info3347223941-2809827"]},
 "Info3347223941-3602638"->{
  Cell[58728, 1267, 939, 12, 214, "Print",
   CellTags->"Info3347223941-3602638"]},
 "Info3347223941-4062804"->{
  Cell[59670, 1281, 555, 7, 119, "Print",
   CellTags->"Info3347223941-4062804"]},
 "Info3347223941-8484718"->{
  Cell[60228, 1290, 172, 2, 23, "Print",
   CellTags->"Info3347223941-8484718"]},
 "Info3347223941-8368394"->{
  Cell[60403, 1294, 173, 2, 23, "Print",
   CellTags->"Info3347223941-8368394"]},
 "Info3347223941-5771336"->{
  Cell[60579, 1298, 169, 2, 23, "Print",
   CellTags->"Info3347223941-5771336"]},
 "Info3347223941-5718574"->{
  Cell[60751, 1302, 169, 2, 23, "Print",
   CellTags->"Info3347223941-5718574"]},
 "Info3347223941-9029670"->{
  Cell[61087, 1316, 560, 8, 100, "Print",
   CellTags->"Info3347223941-9029670"]},
 "Info3347223941-8579298"->{
  Cell[61650, 1326, 182, 2, 43, "Print",
   CellTags->"Info3347223941-8579298"]},
 "Info3347223941-4116126"->{
  Cell[61835, 1330, 156, 2, 43, "Print",
   CellTags->"Info3347223941-4116126"]},
 "Info3347223942-6124645"->{
  Cell[61994, 1334, 273, 4, 62, "Print",
   CellTags->"Info3347223942-6124645"]},
 "Info3347223942-3619064"->{
  Cell[62270, 1340, 576, 8, 100, "Print",
   CellTags->"Info3347223942-3619064"]},
 "Info3347223942-4004828"->{
  Cell[62849, 1350, 275, 4, 62, "Print",
   CellTags->"Info3347223942-4004828"]},
 "Info3347223942-3596063"->{
  Cell[63127, 1356, 210, 3, 23, "Print",
   CellTags->"Info3347223942-3596063"]},
 "Info3347223942-5797197"->{
  Cell[63340, 1361, 234, 3, 43, "Print",
   CellTags->"Info3347223942-5797197"]},
 "Info3347223942-2688418"->{
  Cell[63577, 1366, 289, 4, 62, "Print",
   CellTags->"Info3347223942-2688418"]},
 "Info3347223942-4889550"->{
  Cell[63869, 1372, 204, 3, 43, "Print",
   CellTags->"Info3347223942-4889550"]},
 "Info3347223942-4775645"->{
  Cell[64250, 1387, 191, 2, 43, "Print",
   CellTags->"Info3347223942-4775645"]},
 "Info3347223942-9433219"->{
  Cell[64444, 1391, 259, 3, 43, "Print",
   CellTags->"Info3347223942-9433219"]},
 "Info3347223942-1224636"->{
  Cell[64706, 1396, 181, 2, 43, "Print",
   CellTags->"Info3347223942-1224636"]},
 "Info3347223942-4362745"->{
  Cell[64890, 1400, 172, 2, 43, "Print",
   CellTags->"Info3347223942-4362745"]},
 "Info3347223942-3956808"->{
  Cell[65065, 1404, 181, 2, 43, "Print",
   CellTags->"Info3347223942-3956808"]},
 "Info3347223942-7340812"->{
  Cell[65249, 1408, 830, 11, 138, "Print",
   CellTags->"Info3347223942-7340812"]},
 "Info3347223942-7747929"->{
  Cell[66082, 1421, 495, 6, 100, "Print",
   CellTags->"Info3347223942-7747929"]},
 "Info3347223942-1072148"->{
  Cell[66580, 1429, 421, 5, 62, "Print",
   CellTags->"Info3347223942-1072148"]},
 "Info3347223942-4833943"->{
  Cell[67004, 1436, 740, 9, 176, "Print",
   CellTags->"Info3347223942-4833943"]},
 "Info3347223942-3215298"->{
  Cell[67747, 1447, 121, 2, 23, "Print",
   CellTags->"Info3347223942-3215298"]},
 "Info3347223942-3062770"->{
  Cell[67871, 1451, 137, 2, 23, "Print",
   CellTags->"Info3347223942-3062770"]},
 "Info3347223942-1478151"->{
  Cell[68011, 1455, 132, 2, 23, "Print",
   CellTags->"Info3347223942-1478151"]},
 "Info3347223942-4873634"->{
  Cell[68146, 1459, 124, 2, 23, "Print",
   CellTags->"Info3347223942-4873634"]},
 "Info3347223942-1405457"->{
  Cell[68273, 1463, 130, 2, 23, "Print",
   CellTags->"Info3347223942-1405457"]},
 "Info3347223942-3777925"->{
  Cell[68406, 1467, 151, 2, 23, "Print",
   CellTags->"Info3347223942-3777925"]},
 "Info3347223942-2152760"->{
  Cell[68560, 1471, 666, 9, 100, "Print",
   CellTags->"Info3347223942-2152760"]},
 "Info3347223942-5073193"->{
  Cell[69229, 1482, 242, 3, 43, "Print",
   CellTags->"Info3347223942-5073193"]},
 "Info3347223942-3551327"->{
  Cell[69474, 1487, 246, 3, 43, "Print",
   CellTags->"Info3347223942-3551327"]},
 "Info3347223942-9096541"->{
  Cell[69881, 1502, 500, 7, 138, "Print",
   CellTags->"Info3347223942-9096541"]},
 "Info3347223942-2626858"->{
  Cell[70384, 1511, 445, 6, 119, "Print",
   CellTags->"Info3347223942-2626858"]},
 "Info3347223942-9568268"->{
  Cell[70832, 1519, 437, 6, 100, "Print",
   CellTags->"Info3347223942-9568268"]},
 "Info3347223942-6949674"->{
  Cell[71272, 1527, 440, 6, 119, "Print",
   CellTags->"Info3347223942-6949674"]},
 "Info3347223942-3601001"->{
  Cell[71715, 1535, 366, 5, 100, "Print",
   CellTags->"Info3347223942-3601001"]},
 "Info3347223942-6609419"->{
  Cell[72084, 1542, 435, 6, 100, "Print",
   CellTags->"Info3347223942-6609419"]},
 "Info3347223942-9958241"->{
  Cell[72680, 1560, 317, 4, 43, "Print",
   CellTags->"Info3347223942-9958241"]},
 "Info3347223942-7543440"->{
  Cell[73000, 1566, 108, 1, 23, "Print",
   CellTags->"Info3347223942-7543440"]},
 "Info3347223942-5025554"->{
  Cell[73111, 1569, 121, 2, 23, "Print",
   CellTags->"Info3347223942-5025554"]},
 "Info3347223942-6965775"->{
  Cell[73235, 1573, 101, 1, 23, "Print",
   CellTags->"Info3347223942-6965775"]},
 "Info3347223942-3888279"->{
  Cell[73339, 1576, 137, 2, 23, "Print",
   CellTags->"Info3347223942-3888279"]},
 "Info3347223942-5334754"->{
  Cell[73479, 1580, 147, 2, 23, "Print",
   CellTags->"Info3347223942-5334754"]},
 "Info3347223942-2217087"->{
  Cell[73629, 1584, 173, 2, 23, "Print",
   CellTags->"Info3347223942-2217087"]},
 "Info3347223942-6944643"->{
  Cell[73805, 1588, 107, 1, 23, "Print",
   CellTags->"Info3347223942-6944643"]},
 "Info3347223942-3967660"->{
  Cell[73915, 1591, 109, 1, 23, "Print",
   CellTags->"Info3347223942-3967660"]},
 "Info3347223942-9812128"->{
  Cell[74027, 1594, 296, 4, 81, "Print",
   CellTags->"Info3347223942-9812128"]},
 "Info3347223942-9428271"->{
  Cell[74326, 1600, 112, 1, 23, "Print",
   CellTags->"Info3347223942-9428271"]},
 "Info3347223942-5196408"->{
  Cell[74441, 1603, 143, 2, 23, "Print",
   CellTags->"Info3347223942-5196408"]},
 "Info3347223942-3765753"->{
  Cell[74587, 1607, 112, 1, 23, "Print",
   CellTags->"Info3347223942-3765753"]},
 "Info3347223942-7435369"->{
  Cell[74702, 1610, 232, 3, 43, "Print",
   CellTags->"Info3347223942-7435369"]},
 "Info3347223942-9408926"->{
  Cell[75094, 1625, 362, 5, 62, "Print",
   CellTags->"Info3347223942-9408926"]},
 "Info3347223942-8756152"->{
  Cell[75459, 1632, 148, 2, 23, "Print",
   CellTags->"Info3347223942-8756152"]},
 "Info3347223942-5512214"->{
  Cell[75610, 1636, 275, 4, 43, "Print",
   CellTags->"Info3347223942-5512214"]},
 "Info3347223942-4592327"->{
  Cell[75888, 1642, 160, 2, 23, "Print",
   CellTags->"Info3347223942-4592327"]},
 "Info3347223942-2467846"->{
  Cell[76051, 1646, 1154, 15, 157, "Print",
   CellTags->"Info3347223942-2467846"]},
 "Info3347223942-6619667"->{
  Cell[77208, 1663, 171, 2, 23, "Print",
   CellTags->"Info3347223942-6619667"]},
 "Info3347223942-8743872"->{
  Cell[77382, 1667, 112, 1, 23, "Print",
   CellTags->"Info3347223942-8743872"]},
 "Info3347223942-7645405"->{
  Cell[77497, 1670, 246, 3, 43, "Print",
   CellTags->"Info3347223942-7645405"]},
 "Info3347223942-9313603"->{
  Cell[77746, 1675, 284, 4, 43, "Print",
   CellTags->"Info3347223942-9313603"]},
 "Info3347223942-6658559"->{
  Cell[78033, 1681, 295, 4, 43, "Print",
   CellTags->"Info3347223942-6658559"]},
 "Info3347223942-2489674"->{
  Cell[78331, 1687, 444, 6, 138, "Print",
   CellTags->"Info3347223942-2489674"]},
 "Info3347223942-2698508"->{
  Cell[78778, 1695, 492, 6, 62, "Print",
   CellTags->"Info3347223942-2698508"]},
 "Info3347223942-1174016"->{
  Cell[79578, 1720, 1069, 14, 157, "Print",
   CellTags->"Info3347223942-1174016"]},
 "Info3347223942-3337860"->{
  Cell[80650, 1736, 363, 5, 43, "Print",
   CellTags->"Info3347223942-3337860"],
  Cell[81016, 1743, 279, 5, 23, "Print",
   CellTags->"Info3347223942-3337860"]},
 "Info3347223942-7875248"->{
  Cell[81298, 1750, 1459, 19, 309, "Print",
   CellTags->"Info3347223942-7875248"]},
 "Info3347223942-3565351"->{
  Cell[82760, 1771, 270, 3, 62, "Print",
   CellTags->"Info3347223942-3565351"]},
 "Info3347223942-9575072"->{
  Cell[83033, 1776, 213, 3, 23, "Print",
   CellTags->"Info3347223942-9575072"]},
 "Info3347223942-1161328"->{
  Cell[83249, 1781, 206, 3, 23, "Print",
   CellTags->"Info3347223942-1161328"]},
 "Info3347223942-6641394"->{
  Cell[83458, 1786, 356, 5, 43, "Print",
   CellTags->"Info3347223942-6641394"]},
 "Info3347223942-3253559"->{
  Cell[83817, 1793, 986, 13, 366, "Print",
   CellTags->"Info3347223942-3253559"]},
 "Info3347223942-5222545"->{
  Cell[84806, 1808, 595, 8, 119, "Print",
   CellTags->"Info3347223942-5222545"]},
 "Info3347223942-6345755"->{
  Cell[85404, 1818, 239, 3, 43, "Print",
   CellTags->"Info3347223942-6345755"]},
 "Info3347223942-3683202"->{
  Cell[85646, 1823, 1189, 16, 290, "Print",
   CellTags->"Info3347223942-3683202"]},
 "Info3347223942-7858990"->{
  Cell[86838, 1841, 608, 8, 138, "Print",
   CellTags->"Info3347223942-7858990"]},
 "Info3347223942-3699623"->{
  Cell[87449, 1851, 172, 2, 23, "Print",
   CellTags->"Info3347223942-3699623"]},
 "Info3347223942-4895320"->{
  Cell[87624, 1855, 165, 2, 23, "Print",
   CellTags->"Info3347223942-4895320"]},
 "Info3347223942-9354952"->{
  Cell[87792, 1859, 169, 2, 23, "Print",
   CellTags->"Info3347223942-9354952"]},
 "Info3347223942-8866994"->{
  Cell[87964, 1863, 169, 2, 23, "Print",
   CellTags->"Info3347223942-8866994"]},
 "Info3347223942-7974690"->{
  Cell[88300, 1877, 560, 8, 100, "Print",
   CellTags->"Info3347223942-7974690"]},
 "Info3347223942-7718741"->{
  Cell[88863, 1887, 182, 2, 44, "Print",
   CellTags->"Info3347223942-7718741"]},
 "Info3347223942-6265237"->{
  Cell[89048, 1891, 156, 2, 44, "Print",
   CellTags->"Info3347223942-6265237"]},
 "Info3347223942-2127838"->{
  Cell[89207, 1895, 273, 4, 82, "Print",
   CellTags->"Info3347223942-2127838"]},
 "Info3347223942-8061335"->{
  Cell[89483, 1901, 583, 8, 158, "Print",
   CellTags->"Info3347223942-8061335"]},
 "Info3347223942-2612802"->{
  Cell[90069, 1911, 275, 4, 82, "Print",
   CellTags->"Info3347223942-2612802"]},
 "Info3347223942-3525955"->{
  Cell[90347, 1917, 210, 3, 44, "Print",
   CellTags->"Info3347223942-3525955"]},
 "Info3347223942-9298280"->{
  Cell[90560, 1922, 234, 3, 44, "Print",
   CellTags->"Info3347223942-9298280"]},
 "Info3347223942-3205867"->{
  Cell[90797, 1927, 289, 4, 82, "Print",
   CellTags->"Info3347223942-3205867"]},
 "Info3347223942-2715408"->{
  Cell[91089, 1933, 204, 3, 44, "Print",
   CellTags->"Info3347223942-2715408"]},
 "Info3347223942-1902193"->{
  Cell[91470, 1948, 191, 2, 63, "Print",
   CellTags->"Info3347223942-1902193"]},
 "Info3347223942-6712612"->{
  Cell[91664, 1952, 259, 3, 63, "Print",
   CellTags->"Info3347223942-6712612"]},
 "Info3347223942-4802586"->{
  Cell[91926, 1957, 181, 2, 44, "Print",
   CellTags->"Info3347223942-4802586"]},
 "Info3347223942-6636810"->{
  Cell[92110, 1961, 172, 2, 44, "Print",
   CellTags->"Info3347223942-6636810"]},
 "Info3347223942-4840162"->{
  Cell[92285, 1965, 181, 2, 44, "Print",
   CellTags->"Info3347223942-4840162"]},
 "Info3347223942-7491570"->{
  Cell[92469, 1969, 427, 6, 120, "Print",
   CellTags->"Info3347223942-7491570"]},
 "Info3347223942-1473756"->{
  Cell[92899, 1977, 813, 10, 215, "Print",
   CellTags->"Info3347223942-1473756"]},
 "Info3347223942-1735460"->{
  Cell[93715, 1989, 207, 3, 44, "Print",
   CellTags->"Info3347223942-1735460"]},
 "Info3347223942-2227327"->{
  Cell[93925, 1994, 591, 8, 158, "Print",
   CellTags->"Info3347223942-2227327"]},
 "Info3347223942-4747170"->{
  Cell[94519, 2004, 121, 2, 25, "Print",
   CellTags->"Info3347223942-4747170"]},
 "Info3347223942-2286321"->{
  Cell[94643, 2008, 137, 2, 25, "Print",
   CellTags->"Info3347223942-2286321"]},
 "Info3347223942-8963834"->{
  Cell[94783, 2012, 132, 2, 25, "Print",
   CellTags->"Info3347223942-8963834"]},
 "Info3347223942-9305092"->{
  Cell[94918, 2016, 124, 2, 25, "Print",
   CellTags->"Info3347223942-9305092"]},
 "Info3347223942-6456408"->{
  Cell[95045, 2020, 130, 2, 25, "Print",
   CellTags->"Info3347223942-6456408"]},
 "Info3347223942-3630767"->{
  Cell[95178, 2024, 151, 2, 25, "Print",
   CellTags->"Info3347223942-3630767"]},
 "Info3347223942-8451424"->{
  Cell[95332, 2028, 666, 9, 158, "Print",
   CellTags->"Info3347223942-8451424"]},
 "Info3347223942-9036334"->{
  Cell[96001, 2039, 242, 3, 44, "Print",
   CellTags->"Info3347223942-9036334"]},
 "Info3347223942-8833736"->{
  Cell[96246, 2044, 246, 3, 63, "Print",
   CellTags->"Info3347223942-8833736"]},
 "Info3347223942-7130020"->{
  Cell[96651, 2059, 500, 7, 158, "Print",
   CellTags->"Info3347223942-7130020"]},
 "Info3347223942-7499705"->{
  Cell[97154, 2068, 445, 6, 139, "Print",
   CellTags->"Info3347223942-7499705"]},
 "Info3347223942-7334860"->{
  Cell[97602, 2076, 437, 6, 120, "Print",
   CellTags->"Info3347223942-7334860"]},
 "Info3347223942-3929142"->{
  Cell[98042, 2084, 440, 6, 139, "Print",
   CellTags->"Info3347223942-3929142"]},
 "Info3347223942-4675478"->{
  Cell[98485, 2092, 366, 5, 120, "Print",
   CellTags->"Info3347223942-4675478"]},
 "Info3347223942-6544225"->{
  Cell[98854, 2099, 435, 6, 120, "Print",
   CellTags->"Info3347223942-6544225"]},
 "Info3347223942-4841605"->{
  Cell[99450, 2117, 317, 4, 63, "Print",
   CellTags->"Info3347223942-4841605"]},
 "Info3347223942-6260931"->{
  Cell[99770, 2123, 108, 1, 25, "Print",
   CellTags->"Info3347223942-6260931"]},
 "Info3347223942-2933636"->{
  Cell[99881, 2126, 128, 2, 25, "Print",
   CellTags->"Info3347223942-2933636"]},
 "Info3347223942-6299238"->{
  Cell[100012, 2130, 101, 1, 25, "Print",
   CellTags->"Info3347223942-6299238"]},
 "Info3347223942-8455083"->{
  Cell[100116, 2133, 137, 2, 25, "Print",
   CellTags->"Info3347223942-8455083"]},
 "Info3347223942-2761304"->{
  Cell[100256, 2137, 147, 2, 25, "Print",
   CellTags->"Info3347223942-2761304"]},
 "Info3347223942-7582796"->{
  Cell[100406, 2141, 173, 2, 44, "Print",
   CellTags->"Info3347223942-7582796"]},
 "Info3347223942-3568316"->{
  Cell[100582, 2145, 107, 1, 25, "Print",
   CellTags->"Info3347223942-3568316"]},
 "Info3347223942-8381002"->{
  Cell[100692, 2148, 109, 1, 25, "Print",
   CellTags->"Info3347223942-8381002"]},
 "Info3347223942-6455526"->{
  Cell[100804, 2151, 296, 4, 82, "Print",
   CellTags->"Info3347223942-6455526"]},
 "Info3347223942-4808313"->{
  Cell[101103, 2157, 112, 1, 25, "Print",
   CellTags->"Info3347223942-4808313"]},
 "Info3347223942-2972084"->{
  Cell[101218, 2160, 143, 2, 25, "Print",
   CellTags->"Info3347223942-2972084"]},
 "Info3347223942-3404091"->{
  Cell[101364, 2164, 112, 1, 25, "Print",
   CellTags->"Info3347223942-3404091"]},
 "Info3347223942-5570118"->{
  Cell[101479, 2167, 239, 3, 44, "Print",
   CellTags->"Info3347223942-5570118"]},
 "Info3347223942-9710485"->{
  Cell[101878, 2182, 364, 5, 101, "Print",
   CellTags->"Info3347223942-9710485"]},
 "Info3347223942-3212477"->{
  Cell[102245, 2189, 148, 2, 25, "Print",
   CellTags->"Info3347223942-3212477"]},
 "Info3347223942-7052201"->{
  Cell[102396, 2193, 275, 4, 63, "Print",
   CellTags->"Info3347223942-7052201"]},
 "Info3347223942-1274397"->{
  Cell[102674, 2199, 160, 2, 25, "Print",
   CellTags->"Info3347223942-1274397"]},
 "Info3347223942-6291660"->{
  Cell[102837, 2203, 1165, 15, 272, "Print",
   CellTags->"Info3347223942-6291660"]},
 "Info3347223942-1780589"->{
  Cell[104005, 2220, 171, 2, 25, "Print",
   CellTags->"Info3347223942-1780589"]},
 "Info3347223942-7289647"->{
  Cell[104179, 2224, 112, 1, 25, "Print",
   CellTags->"Info3347223942-7289647"]},
 "Info3347223942-3206676"->{
  Cell[104294, 2227, 246, 3, 44, "Print",
   CellTags->"Info3347223942-3206676"]},
 "Info3347223942-9428676"->{
  Cell[104543, 2232, 284, 4, 63, "Print",
   CellTags->"Info3347223942-9428676"]},
 "Info3347223942-7629229"->{
  Cell[104830, 2238, 295, 4, 63, "Print",
   CellTags->"Info3347223942-7629229"]},
 "Info3347223942-1442542"->{
  Cell[105128, 2244, 444, 6, 158, "Print",
   CellTags->"Info3347223942-1442542"]},
 "Info3347223942-1702933"->{
  Cell[105575, 2252, 508, 7, 101, "Print",
   CellTags->"Info3347223942-1702933"]},
 "Info3347223942-5078785"->{
  Cell[106393, 2278, 254, 3, 63, "Print",
   CellTags->"Info3347223942-5078785"]},
 "Info3347223942-1556017"->{
  Cell[106650, 2283, 542, 7, 120, "Print",
   CellTags->"Info3347223942-1556017"]},
 "Info3347223942-3937423"->{
  Cell[107195, 2292, 126, 2, 25, "Print",
   CellTags->"Info3347223942-3937423"]},
 "Info3347223942-1584120"->{
  Cell[107324, 2296, 183, 2, 44, "Print",
   CellTags->"Info3347223942-1584120"]},
 "Info3347223942-8122127"->{
  Cell[107510, 2300, 495, 7, 120, "Print",
   CellTags->"Info3347223942-8122127"]},
 "Info3347223942-6550982"->{
  Cell[108008, 2309, 264, 3, 63, "Print",
   CellTags->"Info3347223942-6550982"]},
 "Info3347223942-4006352"->{
  Cell[108275, 2314, 122, 2, 25, "Print",
   CellTags->"Info3347223942-4006352"]},
 "Info3347223943-7268328"->{
  Cell[108400, 2318, 502, 6, 215, "Print",
   CellTags->"Info3347223943-7268328"]},
 "Info3347223943-9145937"->{
  Cell[108905, 2326, 421, 5, 177, "Print",
   CellTags->"Info3347223943-9145937"]},
 "Info3347223943-9840448"->{
  Cell[109329, 2333, 984, 13, 310, "Print",
   CellTags->"Info3347223943-9840448"]},
 "Info3347223943-7986648"->{
  Cell[110316, 2348, 318, 4, 63, "Print",
   CellTags->"Info3347223943-7986648"]},
 "Info3347223943-7429312"->{
  Cell[110790, 2364, 667, 9, 234, "Print",
   CellTags->"Info3347223943-7429312"]},
 "Info3347223943-7412679"->{
  Cell[111460, 2375, 160, 2, 44, "Print",
   CellTags->"Info3347223943-7412679"]},
 "Info3347223943-4063720"->{
  Cell[111623, 2379, 213, 3, 63, "Print",
   CellTags->"Info3347223943-4063720"]},
 "Info3347223943-2445563"->{
  Cell[111839, 2384, 216, 3, 63, "Print",
   CellTags->"Info3347223943-2445563"]},
 "Info3347223943-6984034"->{
  Cell[112058, 2389, 204, 3, 63, "Print",
   CellTags->"Info3347223943-6984034"]},
 "Info3347223943-7106080"->{
  Cell[112265, 2394, 209, 3, 63, "Print",
   CellTags->"Info3347223943-7106080"]},
 "Info3347223943-3775443"->{
  Cell[112635, 2409, 379, 5, 101, "Print",
   CellTags->"Info3347223943-3775443"]},
 "Info3347223943-8151160"->{
  Cell[113017, 2416, 135, 2, 25, "Print",
   CellTags->"Info3347223943-8151160"]},
 "Info3347223943-8563191"->{
  Cell[113155, 2420, 593, 8, 158, "Print",
   CellTags->"Info3347223943-8563191"]},
 "Info3347223943-7693835"->{
  Cell[113751, 2430, 135, 2, 25, "Print",
   CellTags->"Info3347223943-7693835"]},
 "Info3347223943-2142348"->{
  Cell[113889, 2434, 309, 4, 63, "Print",
   CellTags->"Info3347223943-2142348"]},
 "Info3347223943-4698659"->{
  Cell[114201, 2440, 108, 1, 25, "Print",
   CellTags->"Info3347223943-4698659"]},
 "Info3347223943-1610739"->{
  Cell[114312, 2443, 153, 2, 25, "Print",
   CellTags->"Info3347223943-1610739"]},
 "Info3347223943-4515092"->{
  Cell[114468, 2447, 101, 1, 25, "Print",
   CellTags->"Info3347223943-4515092"]},
 "Info3347223943-2547445"->{
  Cell[114572, 2450, 154, 2, 25, "Print",
   CellTags->"Info3347223943-2547445"]},
 "Info3347223943-5690018"->{
  Cell[114729, 2454, 147, 2, 25, "Print",
   CellTags->"Info3347223943-5690018"]},
 "Info3347223943-2070076"->{
  Cell[114879, 2458, 182, 2, 44, "Print",
   CellTags->"Info3347223943-2070076"]},
 "Info3347223943-5398885"->{
  Cell[115064, 2462, 148, 2, 25, "Print",
   CellTags->"Info3347223943-5398885"]},
 "Info3347223943-3534432"->{
  Cell[115215, 2466, 165, 2, 44, "Print",
   CellTags->"Info3347223943-3534432"]},
 "Info3347223943-2811507"->{
  Cell[115383, 2470, 228, 3, 44, "Print",
   CellTags->"Info3347223943-2811507"]},
 "Info3347223943-3089526"->{
  Cell[115614, 2475, 230, 3, 44, "Print",
   CellTags->"Info3347223943-3089526"]},
 "Info3347223943-4050909"->{
  Cell[115847, 2480, 107, 1, 25, "Print",
   CellTags->"Info3347223943-4050909"]},
 "Info3347223943-2256146"->{
  Cell[115957, 2483, 109, 1, 25, "Print",
   CellTags->"Info3347223943-2256146"]},
 "Info3347223943-2578274"->{
  Cell[116069, 2486, 296, 4, 82, "Print",
   CellTags->"Info3347223943-2578274"]},
 "Info3347223943-1967258"->{
  Cell[116368, 2492, 112, 1, 25, "Print",
   CellTags->"Info3347223943-1967258"]},
 "Info3347223943-3803042"->{
  Cell[116483, 2495, 143, 2, 25, "Print",
   CellTags->"Info3347223943-3803042"]},
 "Info3347223943-8980657"->{
  Cell[116629, 2499, 112, 1, 25, "Print",
   CellTags->"Info3347223943-8980657"]},
 "Info3347223943-4021916"->{
  Cell[116744, 2502, 112, 1, 25, "Print",
   CellTags->"Info3347223943-4021916"]},
 "Info3347223943-4519082"->{
  Cell[116859, 2505, 240, 3, 44, "Print",
   CellTags->"Info3347223943-4519082"]},
 "Info3347223943-1421647"->{
  Cell[117256, 2520, 134, 2, 25, "Print",
   CellTags->"Info3347223943-1421647"]},
 "Info3347223943-4876034"->{
  Cell[117393, 2524, 242, 3, 44, "Print",
   CellTags->"Info3347223943-4876034"]},
 "Info3347223943-4053978"->{
  Cell[117638, 2529, 131, 2, 25, "Print",
   CellTags->"Info3347223943-4053978"]},
 "Info3347223943-8562188"->{
  Cell[117772, 2533, 284, 4, 63, "Print",
   CellTags->"Info3347223943-8562188"]},
 "Info3347223943-7158326"->{
  Cell[118059, 2539, 295, 4, 63, "Print",
   CellTags->"Info3347223943-7158326"]},
 "Info3347223943-1889904"->{
  Cell[118357, 2545, 247, 3, 44, "Print",
   CellTags->"Info3347223943-1889904"]},
 "Info3347223943-5722087"->{
  Cell[118909, 2567, 254, 3, 63, "Print",
   CellTags->"Info3347223943-5722087"]},
 "Info3347223943-6066732"->{
  Cell[119166, 2572, 542, 7, 120, "Print",
   CellTags->"Info3347223943-6066732"]},
 "Info3347223943-7540695"->{
  Cell[119711, 2581, 126, 2, 25, "Print",
   CellTags->"Info3347223943-7540695"]},
 "Info3347223943-8356363"->{
  Cell[119840, 2585, 183, 2, 44, "Print",
   CellTags->"Info3347223943-8356363"]},
 "Info3347223943-2610039"->{
  Cell[120026, 2589, 495, 7, 120, "Print",
   CellTags->"Info3347223943-2610039"]},
 "Info3347223943-9333251"->{
  Cell[120524, 2598, 264, 3, 63, "Print",
   CellTags->"Info3347223943-9333251"]},
 "Info3347223943-5741528"->{
  Cell[120791, 2603, 122, 2, 25, "Print",
   CellTags->"Info3347223943-5741528"]},
 "Info3347223943-2058617"->{
  Cell[120916, 2607, 435, 6, 177, "Print",
   CellTags->"Info3347223943-2058617"]},
 "Info3347223943-6061612"->{
  Cell[121354, 2615, 418, 5, 158, "Print",
   CellTags->"Info3347223943-6061612"]},
 "Info3347223943-5839947"->{
  Cell[121775, 2622, 1013, 13, 310, "Print",
   CellTags->"Info3347223943-5839947"]},
 "Info3347223943-6964670"->{
  Cell[122791, 2637, 325, 4, 63, "Print",
   CellTags->"Info3347223943-6964670"]},
 "Info3347223943-7045062"->{
  Cell[123272, 2653, 649, 9, 215, "Print",
   CellTags->"Info3347223943-7045062"]},
 "Info3347223943-3156769"->{
  Cell[123924, 2664, 164, 2, 44, "Print",
   CellTags->"Info3347223943-3156769"]},
 "Info3347223943-6001645"->{
  Cell[124091, 2668, 211, 3, 63, "Print",
   CellTags->"Info3347223943-6001645"]},
 "Info3347223943-4852106"->{
  Cell[124305, 2673, 209, 3, 63, "Print",
   CellTags->"Info3347223943-4852106"]},
 "Info3347223943-2532118"->{
  Cell[124517, 2678, 212, 3, 63, "Print",
   CellTags->"Info3347223943-2532118"]},
 "Info3347223943-7067293"->{
  Cell[124890, 2693, 379, 5, 101, "Print",
   CellTags->"Info3347223943-7067293"]},
 "Info3347223943-9641375"->{
  Cell[125272, 2700, 135, 2, 25, "Print",
   CellTags->"Info3347223943-9641375"]},
 "Info3347223943-7839447"->{
  Cell[125410, 2704, 597, 8, 158, "Print",
   CellTags->"Info3347223943-7839447"]},
 "Info3347223943-3277276"->{
  Cell[126010, 2714, 135, 2, 25, "Print",
   CellTags->"Info3347223943-3277276"]},
 "Info3347223943-1779400"->{
  Cell[126148, 2718, 309, 4, 63, "Print",
   CellTags->"Info3347223943-1779400"]},
 "Info3347223943-8626447"->{
  Cell[126460, 2724, 108, 1, 25, "Print",
   CellTags->"Info3347223943-8626447"]},
 "Info3347223943-1614004"->{
  Cell[126571, 2727, 148, 2, 25, "Print",
   CellTags->"Info3347223943-1614004"]},
 "Info3347223943-1756910"->{
  Cell[126722, 2731, 101, 1, 25, "Print",
   CellTags->"Info3347223943-1756910"]},
 "Info3347223943-7953603"->{
  Cell[126826, 2734, 149, 2, 25, "Print",
   CellTags->"Info3347223943-7953603"]},
 "Info3347223943-7285242"->{
  Cell[126978, 2738, 147, 2, 25, "Print",
   CellTags->"Info3347223943-7285242"]},
 "Info3347223943-3710641"->{
  Cell[127128, 2742, 177, 2, 44, "Print",
   CellTags->"Info3347223943-3710641"]},
 "Info3347223943-6496722"->{
  Cell[127308, 2746, 148, 2, 25, "Print",
   CellTags->"Info3347223943-6496722"]},
 "Info3347223943-4583684"->{
  Cell[127459, 2750, 160, 2, 25, "Print",
   CellTags->"Info3347223943-4583684"]},
 "Info3347223943-5150566"->{
  Cell[127622, 2754, 228, 3, 44, "Print",
   CellTags->"Info3347223943-5150566"]},
 "Info3347223943-5115022"->{
  Cell[127853, 2759, 230, 3, 44, "Print",
   CellTags->"Info3347223943-5115022"]},
 "Info3347223943-6296956"->{
  Cell[128086, 2764, 107, 1, 25, "Print",
   CellTags->"Info3347223943-6296956"]},
 "Info3347223943-1006138"->{
  Cell[128196, 2767, 109, 1, 25, "Print",
   CellTags->"Info3347223943-1006138"]},
 "Info3347223943-3228834"->{
  Cell[128308, 2770, 296, 4, 82, "Print",
   CellTags->"Info3347223943-3228834"]},
 "Info3347223943-1888747"->{
  Cell[128607, 2776, 112, 1, 25, "Print",
   CellTags->"Info3347223943-1888747"]},
 "Info3347223943-7381528"->{
  Cell[128722, 2779, 143, 2, 25, "Print",
   CellTags->"Info3347223943-7381528"]},
 "Info3347223943-8122874"->{
  Cell[128868, 2783, 112, 1, 25, "Print",
   CellTags->"Info3347223943-8122874"]},
 "Info3347223943-6416613"->{
  Cell[128983, 2786, 112, 1, 25, "Print",
   CellTags->"Info3347223943-6416613"]},
 "Info3347223943-1079780"->{
  Cell[129098, 2789, 235, 3, 44, "Print",
   CellTags->"Info3347223943-1079780"]},
 "Info3347223943-5972664"->{
  Cell[129490, 2804, 134, 2, 25, "Print",
   CellTags->"Info3347223943-5972664"]},
 "Info3347223943-4112961"->{
  Cell[129627, 2808, 242, 3, 44, "Print",
   CellTags->"Info3347223943-4112961"]},
 "Info3347223943-2709084"->{
  Cell[129872, 2813, 126, 2, 25, "Print",
   CellTags->"Info3347223943-2709084"]},
 "Info3347223943-8970379"->{
  Cell[130001, 2817, 284, 4, 63, "Print",
   CellTags->"Info3347223943-8970379"]},
 "Info3347223943-7602098"->{
  Cell[130288, 2823, 295, 4, 63, "Print",
   CellTags->"Info3347223943-7602098"]},
 "Info3347223943-2781622"->{
  Cell[130586, 2829, 247, 3, 44, "Print",
   CellTags->"Info3347223943-2781622"]},
 "Info3347223943-1412650"->{
  Cell[131141, 2851, 254, 3, 63, "Print",
   CellTags->"Info3347223943-1412650"]},
 "Info3347223943-9876552"->{
  Cell[131398, 2856, 542, 7, 120, "Print",
   CellTags->"Info3347223943-9876552"]},
 "Info3347223943-9911280"->{
  Cell[131943, 2865, 126, 2, 25, "Print",
   CellTags->"Info3347223943-9911280"]},
 "Info3347223943-6335135"->{
  Cell[132072, 2869, 183, 2, 44, "Print",
   CellTags->"Info3347223943-6335135"]},
 "Info3347223943-9595876"->{
  Cell[132258, 2873, 495, 7, 120, "Print",
   CellTags->"Info3347223943-9595876"]},
 "Info3347223943-5396991"->{
  Cell[132756, 2882, 264, 3, 63, "Print",
   CellTags->"Info3347223943-5396991"]},
 "Info3347223943-6581954"->{
  Cell[133023, 2887, 122, 2, 25, "Print",
   CellTags->"Info3347223943-6581954"]},
 "Info3347223943-8464511"->{
  Cell[133148, 2891, 937, 12, 310, "Print",
   CellTags->"Info3347223943-8464511"]},
 "Info3347223943-4874601"->{
  Cell[134088, 2905, 437, 6, 196, "Print",
   CellTags->"Info3347223943-4874601"]},
 "Info3347223943-5629661"->{
  Cell[134528, 2913, 1332, 17, 424, "Print",
   CellTags->"Info3347223943-5629661"]},
 "Info3347223943-4925532"->{
  Cell[135863, 2932, 319, 4, 63, "Print",
   CellTags->"Info3347223943-4925532"]},
 "Info3347223943-5246270"->{
  Cell[136338, 2948, 1161, 15, 367, "Print",
   CellTags->"Info3347223943-5246270"]},
 "Info3347223943-1445452"->{
  Cell[137502, 2965, 160, 2, 44, "Print",
   CellTags->"Info3347223943-1445452"]},
 "Info3347223943-4450436"->{
  Cell[137665, 2969, 207, 3, 63, "Print",
   CellTags->"Info3347223943-4450436"]},
 "Info3347223943-3881981"->{
  Cell[137875, 2974, 207, 3, 63, "Print",
   CellTags->"Info3347223943-3881981"]},
 "Info3347223943-7228078"->{
  Cell[138085, 2979, 216, 3, 63, "Print",
   CellTags->"Info3347223943-7228078"]},
 "Info3347223943-4602624"->{
  Cell[138462, 2994, 379, 5, 101, "Print",
   CellTags->"Info3347223943-4602624"]},
 "Info3347223943-8450963"->{
  Cell[138844, 3001, 135, 2, 25, "Print",
   CellTags->"Info3347223943-8450963"]},
 "Info3347223943-6220742"->{
  Cell[138982, 3005, 670, 9, 310, "Print",
   CellTags->"Info3347223943-6220742"]},
 "Info3347223943-7000860"->{
  Cell[139655, 3016, 135, 2, 25, "Print",
   CellTags->"Info3347223943-7000860"]},
 "Info3347223943-5567665"->{
  Cell[139793, 3020, 309, 4, 63, "Print",
   CellTags->"Info3347223943-5567665"]},
 "Info3347223943-5586590"->{
  Cell[140105, 3026, 108, 1, 25, "Print",
   CellTags->"Info3347223943-5586590"]},
 "Info3347223943-2736516"->{
  Cell[140216, 3029, 146, 2, 25, "Print",
   CellTags->"Info3347223943-2736516"]},
 "Info3347223943-4561819"->{
  Cell[140365, 3033, 101, 1, 25, "Print",
   CellTags->"Info3347223943-4561819"]},
 "Info3347223943-9200808"->{
  Cell[140469, 3036, 147, 2, 25, "Print",
   CellTags->"Info3347223943-9200808"]},
 "Info3347223943-4835101"->{
  Cell[140619, 3040, 147, 2, 25, "Print",
   CellTags->"Info3347223943-4835101"]},
 "Info3347223943-7355272"->{
  Cell[140769, 3044, 175, 2, 44, "Print",
   CellTags->"Info3347223943-7355272"]},
 "Info3347223943-1181112"->{
  Cell[140947, 3048, 148, 2, 25, "Print",
   CellTags->"Info3347223943-1181112"]},
 "Info3347223943-2215272"->{
  Cell[141098, 3052, 158, 2, 25, "Print",
   CellTags->"Info3347223943-2215272"]},
 "Info3347223943-1923535"->{
  Cell[141259, 3056, 228, 3, 44, "Print",
   CellTags->"Info3347223943-1923535"]},
 "Info3347223943-8093696"->{
  Cell[141490, 3061, 230, 3, 44, "Print",
   CellTags->"Info3347223943-8093696"]},
 "Info3347223943-6910008"->{
  Cell[141723, 3066, 107, 1, 25, "Print",
   CellTags->"Info3347223943-6910008"]},
 "Info3347223943-1493678"->{
  Cell[141833, 3069, 109, 1, 25, "Print",
   CellTags->"Info3347223943-1493678"]},
 "Info3347223943-3117515"->{
  Cell[141945, 3072, 296, 4, 82, "Print",
   CellTags->"Info3347223943-3117515"]},
 "Info3347223943-4832411"->{
  Cell[142244, 3078, 112, 1, 25, "Print",
   CellTags->"Info3347223943-4832411"]},
 "Info3347223943-8404433"->{
  Cell[142359, 3081, 143, 2, 25, "Print",
   CellTags->"Info3347223943-8404433"]},
 "Info3347223943-7328827"->{
  Cell[142505, 3085, 112, 1, 25, "Print",
   CellTags->"Info3347223943-7328827"]},
 "Info3347223943-4746551"->{
  Cell[142620, 3088, 112, 1, 25, "Print",
   CellTags->"Info3347223943-4746551"]},
 "Info3347223943-8409741"->{
  Cell[142735, 3091, 225, 3, 44, "Print",
   CellTags->"Info3347223943-8409741"]},
 "Info3347223943-8817053"->{
  Cell[143117, 3106, 134, 2, 25, "Print",
   CellTags->"Info3347223943-8817053"]},
 "Info3347223943-3716282"->{
  Cell[143254, 3110, 242, 3, 44, "Print",
   CellTags->"Info3347223943-3716282"]},
 "Info3347223943-8999170"->{
  Cell[143499, 3115, 114, 1, 25, "Print",
   CellTags->"Info3347223943-8999170"]},
 "Info3347223943-5709094"->{
  Cell[143616, 3118, 284, 4, 63, "Print",
   CellTags->"Info3347223943-5709094"]},
 "Info3347223943-3657880"->{
  Cell[143903, 3124, 295, 4, 63, "Print",
   CellTags->"Info3347223943-3657880"]},
 "Info3347223943-6348310"->{
  Cell[144201, 3130, 247, 3, 44, "Print",
   CellTags->"Info3347223943-6348310"]},
 "Info3347223943-5622619"->{
  Cell[144753, 3152, 261, 3, 63, "Print",
   CellTags->"Info3347223943-5622619"]},
 "Info3347223943-3212639"->{
  Cell[145017, 3157, 547, 7, 120, "Print",
   CellTags->"Info3347223943-3212639"]},
 "Info3347223944-7593278"->{
  Cell[145567, 3166, 126, 2, 25, "Print",
   CellTags->"Info3347223944-7593278"]},
 "Info3347223944-1223543"->{
  Cell[145696, 3170, 183, 2, 44, "Print",
   CellTags->"Info3347223944-1223543"]},
 "Info3347223944-6433330"->{
  Cell[145882, 3174, 495, 7, 120, "Print",
   CellTags->"Info3347223944-6433330"]},
 "Info3347223944-8548286"->{
  Cell[146380, 3183, 264, 3, 63, "Print",
   CellTags->"Info3347223944-8548286"]},
 "Info3347223944-5636726"->{
  Cell[146647, 3188, 122, 2, 25, "Print",
   CellTags->"Info3347223944-5636726"]},
 "Info3347223944-6212195"->{
  Cell[146772, 3192, 1282, 17, 519, "Print",
   CellTags->"Info3347223944-6212195"]},
 "Info3347223944-2446185"->{
  Cell[148057, 3211, 669, 9, 196, "Print",
   CellTags->"Info3347223944-2446185"]},
 "Info3347223944-4819550"->{
  Cell[148729, 3222, 897, 12, 348, "Print",
   CellTags->"Info3347223944-4819550"]},
 "Info3347223944-6414604"->{
  Cell[149629, 3236, 600, 8, 158, "Print",
   CellTags->"Info3347223944-6414604"]},
 "Info3347223944-6619072"->{
  Cell[150385, 3256, 794, 10, 310, "Print",
   CellTags->"Info3347223944-6619072"]},
 "Info3347223944-4082389"->{
  Cell[151182, 3268, 288, 4, 82, "Print",
   CellTags->"Info3347223944-4082389"]},
 "Info3347223944-3243349"->{
  Cell[151473, 3274, 213, 3, 63, "Print",
   CellTags->"Info3347223944-3243349"]},
 "Info3347223944-9833440"->{
  Cell[151689, 3279, 216, 3, 63, "Print",
   CellTags->"Info3347223944-9833440"]},
 "Info3347223944-9033299"->{
  Cell[151908, 3284, 177, 2, 63, "Print",
   CellTags->"Info3347223944-9033299"]},
 "Info3347223944-7106424"->{
  Cell[152088, 3288, 215, 3, 63, "Print",
   CellTags->"Info3347223944-7106424"]},
 "Info3347223944-2091162"->{
  Cell[152306, 3293, 186, 2, 63, "Print",
   CellTags->"Info3347223944-2091162"]},
 "Info3347223944-1590385"->{
  Cell[152495, 3297, 210, 3, 63, "Print",
   CellTags->"Info3347223944-1590385"]},
 "Info3347223944-5449929"->{
  Cell[152708, 3302, 200, 3, 63, "Print",
   CellTags->"Info3347223944-5449929"]},
 "Info3347223944-5484391"->{
  Cell[152911, 3307, 215, 3, 63, "Print",
   CellTags->"Info3347223944-5484391"]},
 "Info3347223944-8026549"->{
  Cell[153287, 3322, 541, 7, 158, "Print",
   CellTags->"Info3347223944-8026549"]},
 "Info3347223944-6509291"->{
  Cell[153831, 3331, 135, 2, 25, "Print",
   CellTags->"Info3347223944-6509291"]},
 "Info3347223944-9854803"->{
  Cell[153969, 3335, 922, 12, 234, "Print",
   CellTags->"Info3347223944-9854803"]},
 "Info3347223944-4587203"->{
  Cell[154894, 3349, 135, 2, 25, "Print",
   CellTags->"Info3347223944-4587203"]},
 "Info3347223944-6627152"->{
  Cell[155032, 3353, 309, 4, 63, "Print",
   CellTags->"Info3347223944-6627152"]},
 "Info3347223944-9677027"->{
  Cell[155344, 3359, 108, 1, 25, "Print",
   CellTags->"Info3347223944-9677027"]},
 "Info3347223944-7882672"->{
  Cell[155455, 3362, 153, 2, 25, "Print",
   CellTags->"Info3347223944-7882672"]},
 "Info3347223944-5172316"->{
  Cell[155611, 3366, 101, 1, 25, "Print",
   CellTags->"Info3347223944-5172316"]},
 "Info3347223944-1205732"->{
  Cell[155715, 3369, 154, 2, 25, "Print",
   CellTags->"Info3347223944-1205732"]},
 "Info3347223944-8443384"->{
  Cell[155872, 3373, 147, 2, 25, "Print",
   CellTags->"Info3347223944-8443384"]},
 "Info3347223944-8424884"->{
  Cell[156022, 3377, 182, 2, 44, "Print",
   CellTags->"Info3347223944-8424884"]},
 "Info3347223944-9112071"->{
  Cell[156207, 3381, 148, 2, 25, "Print",
   CellTags->"Info3347223944-9112071"]},
 "Info3347223944-5725100"->{
  Cell[156358, 3385, 165, 2, 44, "Print",
   CellTags->"Info3347223944-5725100"]},
 "Info3347223944-3763668"->{
  Cell[156526, 3389, 228, 3, 44, "Print",
   CellTags->"Info3347223944-3763668"]},
 "Info3347223944-5023528"->{
  Cell[156757, 3394, 230, 3, 44, "Print",
   CellTags->"Info3347223944-5023528"]},
 "Info3347223944-6332496"->{
  Cell[156990, 3399, 107, 1, 25, "Print",
   CellTags->"Info3347223944-6332496"]},
 "Info3347223944-1601766"->{
  Cell[157100, 3402, 109, 1, 25, "Print",
   CellTags->"Info3347223944-1601766"]},
 "Info3347223944-9984544"->{
  Cell[157212, 3405, 296, 4, 82, "Print",
   CellTags->"Info3347223944-9984544"]},
 "Info3347223944-8912656"->{
  Cell[157511, 3411, 112, 1, 25, "Print",
   CellTags->"Info3347223944-8912656"]},
 "Info3347223944-6144805"->{
  Cell[157626, 3414, 143, 2, 25, "Print",
   CellTags->"Info3347223944-6144805"]},
 "Info3347223944-4339604"->{
  Cell[157772, 3418, 112, 1, 25, "Print",
   CellTags->"Info3347223944-4339604"]},
 "Info3347223944-7164196"->{
  Cell[157887, 3421, 112, 1, 25, "Print",
   CellTags->"Info3347223944-7164196"]},
 "Info3347223944-7748027"->{
  Cell[158002, 3424, 240, 3, 44, "Print",
   CellTags->"Info3347223944-7748027"]},
 "Info3347223944-7495296"->{
  Cell[158399, 3439, 134, 2, 25, "Print",
   CellTags->"Info3347223944-7495296"]},
 "Info3347223944-8982714"->{
  Cell[158536, 3443, 209, 3, 44, "Print",
   CellTags->"Info3347223944-8982714"]},
 "Info3347223944-8993898"->{
  Cell[158748, 3448, 131, 2, 25, "Print",
   CellTags->"Info3347223944-8993898"]},
 "Info3347223944-1732994"->{
  Cell[158882, 3452, 284, 4, 63, "Print",
   CellTags->"Info3347223944-1732994"]},
 "Info3347223944-1385772"->{
  Cell[159169, 3458, 295, 4, 63, "Print",
   CellTags->"Info3347223944-1385772"]},
 "Info3347223944-8600115"->{
  Cell[159467, 3464, 247, 3, 44, "Print",
   CellTags->"Info3347223944-8600115"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3347223940-6631621", 160074, 3483},
 {"Info3347223940-4294206", 160182, 3486},
 {"Info3347223940-6810511", 160290, 3489},
 {"Info3347223940-7389295", 160398, 3492},
 {"Info3347223940-2382490", 160506, 3495},
 {"Info3347223940-6023529", 160614, 3498},
 {"Info3347223940-6503571", 160722, 3501},
 {"Info3347223940-5379615", 160830, 3504},
 {"Info3347223940-1834069", 160939, 3507},
 {"Info3347223940-7924268", 161048, 3510},
 {"Info3347223940-7939632", 161157, 3513},
 {"Info3347223940-6833855", 161266, 3516},
 {"Info3347223940-1189387", 161375, 3519},
 {"Info3347223940-1293541", 161484, 3522},
 {"Info3347223940-8692552", 161672, 3527},
 {"Info3347223940-9972450", 161783, 3530},
 {"Info3347223940-4605738", 162132, 3539},
 {"Info3347223940-4732625", 162241, 3542},
 {"Info3347223940-4167237", 162350, 3545},
 {"Info3347223940-9087758", 162461, 3548},
 {"Info3347223940-5926772", 162571, 3551},
 {"Info3347223940-8501482", 162681, 3554},
 {"Info3347223940-7144037", 162792, 3557},
 {"Info3347223940-2011507", 162902, 3560},
 {"Info3347223940-6339513", 163012, 3563},
 {"Info3347223940-5174597", 163122, 3566},
 {"Info3347223940-1062849", 163232, 3569},
 {"Info3347223940-3542961", 163343, 3572},
 {"Info3347223940-1600426", 163453, 3575},
 {"Info3347223940-4337716", 163563, 3578},
 {"Info3347223941-1813366", 163673, 3581},
 {"Info3347223941-1118594", 163784, 3584},
 {"Info3347223941-5737972", 163894, 3587},
 {"Info3347223941-7410441", 164004, 3590},
 {"Info3347223941-8640170", 164114, 3593},
 {"Info3347223941-1951187", 164224, 3596},
 {"Info3347223941-8197922", 164334, 3599},
 {"Info3347223941-2611265", 164444, 3602},
 {"Info3347223941-9442840", 164554, 3605},
 {"Info3347223941-7245219", 164664, 3608},
 {"Info3347223941-5798128", 164774, 3611},
 {"Info3347223941-1459018", 164884, 3614},
 {"Info3347223941-1589458", 164996, 3617},
 {"Info3347223941-8534708", 165107, 3620},
 {"Info3347223941-7553760", 165217, 3623},
 {"Info3347223941-9188284", 165328, 3626},
 {"Info3347223941-7542695", 165438, 3629},
 {"Info3347223941-2715154", 165548, 3632},
 {"Info3347223941-2795720", 165658, 3635},
 {"Info3347223941-9823357", 165768, 3638},
 {"Info3347223941-8020983", 165878, 3641},
 {"Info3347223941-4999920", 165988, 3644},
 {"Info3347223941-6637905", 166099, 3647},
 {"Info3347223941-9601905", 166209, 3650},
 {"Info3347223941-1464798", 166319, 3653},
 {"Info3347223941-1770110", 166430, 3656},
 {"Info3347223941-2471642", 166541, 3659},
 {"Info3347223941-7586356", 166652, 3662},
 {"Info3347223941-4155620", 166763, 3665},
 {"Info3347223941-3197855", 166874, 3668},
 {"Info3347223941-8920274", 166985, 3671},
 {"Info3347223941-2580618", 167095, 3674},
 {"Info3347223941-5009207", 167205, 3677},
 {"Info3347223941-1486463", 167315, 3680},
 {"Info3347223941-2487122", 167425, 3683},
 {"Info3347223941-6450972", 167535, 3686},
 {"Info3347223941-4162216", 167645, 3689},
 {"Info3347223941-6354640", 167755, 3692},
 {"Info3347223941-5746827", 167865, 3695},
 {"Info3347223941-2691935", 167975, 3698},
 {"Info3347223941-7877067", 168085, 3701},
 {"Info3347223941-7749989", 168195, 3704},
 {"Info3347223941-3231106", 168305, 3707},
 {"Info3347223941-3377092", 168415, 3710},
 {"Info3347223941-4876077", 168525, 3713},
 {"Info3347223941-3439479", 168635, 3716},
 {"Info3347223941-7653090", 168745, 3719},
 {"Info3347223941-7874582", 168855, 3722},
 {"Info3347223941-5235115", 168965, 3725},
 {"Info3347223941-7704576", 169078, 3728},
 {"Info3347223941-4043808", 169188, 3731},
 {"Info3347223941-3418109", 169298, 3734},
 {"Info3347223941-6580237", 169408, 3737},
 {"Info3347223941-6852624", 169518, 3740},
 {"Info3347223941-1422078", 169628, 3743},
 {"Info3347223941-2029304", 169739, 3746},
 {"Info3347223941-8989917", 169849, 3749},
 {"Info3347223941-3552733", 169962, 3752},
 {"Info3347223941-6176457", 170072, 3755},
 {"Info3347223941-8109493", 170182, 3758},
 {"Info3347223941-6089851", 170292, 3761},
 {"Info3347223941-7134049", 170404, 3764},
 {"Info3347223941-7244468", 170515, 3767},
 {"Info3347223941-4415755", 170626, 3770},
 {"Info3347223941-9094170", 170737, 3773},
 {"Info3347223941-3611725", 170847, 3776},
 {"Info3347223941-9967462", 170957, 3779},
 {"Info3347223941-4309295", 171067, 3782},
 {"Info3347223941-8260624", 171177, 3785},
 {"Info3347223941-8492284", 171288, 3788},
 {"Info3347223941-8438704", 171398, 3791},
 {"Info3347223941-3285558", 171508, 3794},
 {"Info3347223941-1354509", 171618, 3797},
 {"Info3347223941-1355904", 171729, 3800},
 {"Info3347223941-8370622", 171839, 3803},
 {"Info3347223941-2291614", 171949, 3806},
 {"Info3347223941-7771765", 172059, 3809},
 {"Info3347223941-7568170", 172169, 3812},
 {"Info3347223941-5343679", 172279, 3815},
 {"Info3347223941-5864838", 172389, 3818},
 {"Info3347223941-7809650", 172499, 3821},
 {"Info3347223941-2458221", 172609, 3824},
 {"Info3347223941-1974298", 172719, 3827},
 {"Info3347223941-7595909", 172829, 3830},
 {"Info3347223941-2077596", 172941, 3833},
 {"Info3347223941-6833115", 173052, 3836},
 {"Info3347223941-8415350", 173162, 3839},
 {"Info3347223941-7920837", 173273, 3842},
 {"Info3347223941-5070483", 173383, 3845},
 {"Info3347223941-1032206", 173493, 3848},
 {"Info3347223941-1376349", 173603, 3851},
 {"Info3347223941-7407861", 173713, 3854},
 {"Info3347223941-2948475", 173823, 3857},
 {"Info3347223941-8742318", 173933, 3860},
 {"Info3347223941-9656730", 174044, 3863},
 {"Info3347223941-1145073", 174154, 3866},
 {"Info3347223941-4193583", 174264, 3869},
 {"Info3347223941-6993551", 174375, 3872},
 {"Info3347223941-6453383", 174486, 3875},
 {"Info3347223941-7559587", 174598, 3878},
 {"Info3347223941-5358822", 174710, 3881},
 {"Info3347223941-6682568", 174822, 3884},
 {"Info3347223941-3512651", 174934, 3887},
 {"Info3347223941-8850662", 175045, 3890},
 {"Info3347223941-7730051", 175156, 3893},
 {"Info3347223941-2942451", 175267, 3896},
 {"Info3347223941-3089129", 175378, 3899},
 {"Info3347223941-3186031", 175489, 3902},
 {"Info3347223941-4802215", 175600, 3905},
 {"Info3347223941-8163804", 175711, 3908},
 {"Info3347223941-6931229", 175822, 3911},
 {"Info3347223941-9964984", 175933, 3914},
 {"Info3347223941-4270299", 176044, 3917},
 {"Info3347223941-7308454", 176155, 3920},
 {"Info3347223941-7750860", 176266, 3923},
 {"Info3347223941-3895549", 176377, 3926},
 {"Info3347223941-4236356", 176488, 3929},
 {"Info3347223941-2245144", 176599, 3932},
 {"Info3347223941-8159017", 176710, 3935},
 {"Info3347223941-8125029", 176821, 3938},
 {"Info3347223941-5725470", 176932, 3941},
 {"Info3347223941-8114379", 177046, 3944},
 {"Info3347223941-7760450", 177157, 3947},
 {"Info3347223941-7609199", 177268, 3950},
 {"Info3347223941-8492301", 177379, 3953},
 {"Info3347223941-8350572", 177490, 3956},
 {"Info3347223941-7702967", 177601, 3959},
 {"Info3347223941-7628927", 177713, 3962},
 {"Info3347223941-2550021", 177824, 3965},
 {"Info3347223941-9246453", 177937, 3968},
 {"Info3347223941-6719514", 178048, 3971},
 {"Info3347223941-3075263", 178160, 3974},
 {"Info3347223941-1794145", 178271, 3977},
 {"Info3347223941-2809827", 178384, 3980},
 {"Info3347223941-3602638", 178496, 3983},
 {"Info3347223941-4062804", 178609, 3986},
 {"Info3347223941-8484718", 178721, 3989},
 {"Info3347223941-8368394", 178832, 3992},
 {"Info3347223941-5771336", 178943, 3995},
 {"Info3347223941-5718574", 179054, 3998},
 {"Info3347223941-9029670", 179165, 4001},
 {"Info3347223941-8579298", 179277, 4004},
 {"Info3347223941-4116126", 179388, 4007},
 {"Info3347223942-6124645", 179499, 4010},
 {"Info3347223942-3619064", 179610, 4013},
 {"Info3347223942-4004828", 179722, 4016},
 {"Info3347223942-3596063", 179833, 4019},
 {"Info3347223942-5797197", 179944, 4022},
 {"Info3347223942-2688418", 180055, 4025},
 {"Info3347223942-4889550", 180166, 4028},
 {"Info3347223942-4775645", 180277, 4031},
 {"Info3347223942-9433219", 180388, 4034},
 {"Info3347223942-1224636", 180499, 4037},
 {"Info3347223942-4362745", 180610, 4040},
 {"Info3347223942-3956808", 180721, 4043},
 {"Info3347223942-7340812", 180832, 4046},
 {"Info3347223942-7747929", 180945, 4049},
 {"Info3347223942-1072148", 181057, 4052},
 {"Info3347223942-4833943", 181168, 4055},
 {"Info3347223942-3215298", 181280, 4058},
 {"Info3347223942-3062770", 181391, 4061},
 {"Info3347223942-1478151", 181502, 4064},
 {"Info3347223942-4873634", 181613, 4067},
 {"Info3347223942-1405457", 181724, 4070},
 {"Info3347223942-3777925", 181835, 4073},
 {"Info3347223942-2152760", 181946, 4076},
 {"Info3347223942-5073193", 182058, 4079},
 {"Info3347223942-3551327", 182169, 4082},
 {"Info3347223942-9096541", 182280, 4085},
 {"Info3347223942-2626858", 182392, 4088},
 {"Info3347223942-9568268", 182504, 4091},
 {"Info3347223942-6949674", 182616, 4094},
 {"Info3347223942-3601001", 182728, 4097},
 {"Info3347223942-6609419", 182840, 4100},
 {"Info3347223942-9958241", 182952, 4103},
 {"Info3347223942-7543440", 183063, 4106},
 {"Info3347223942-5025554", 183174, 4109},
 {"Info3347223942-6965775", 183285, 4112},
 {"Info3347223942-3888279", 183396, 4115},
 {"Info3347223942-5334754", 183507, 4118},
 {"Info3347223942-2217087", 183618, 4121},
 {"Info3347223942-6944643", 183729, 4124},
 {"Info3347223942-3967660", 183840, 4127},
 {"Info3347223942-9812128", 183951, 4130},
 {"Info3347223942-9428271", 184062, 4133},
 {"Info3347223942-5196408", 184173, 4136},
 {"Info3347223942-3765753", 184284, 4139},
 {"Info3347223942-7435369", 184395, 4142},
 {"Info3347223942-9408926", 184506, 4145},
 {"Info3347223942-8756152", 184617, 4148},
 {"Info3347223942-5512214", 184728, 4151},
 {"Info3347223942-4592327", 184839, 4154},
 {"Info3347223942-2467846", 184950, 4157},
 {"Info3347223942-6619667", 185064, 4160},
 {"Info3347223942-8743872", 185175, 4163},
 {"Info3347223942-7645405", 185286, 4166},
 {"Info3347223942-9313603", 185397, 4169},
 {"Info3347223942-6658559", 185508, 4172},
 {"Info3347223942-2489674", 185619, 4175},
 {"Info3347223942-2698508", 185731, 4178},
 {"Info3347223942-1174016", 185842, 4181},
 {"Info3347223942-3337860", 185956, 4184},
 {"Info3347223942-7875248", 186148, 4189},
 {"Info3347223942-3565351", 186262, 4192},
 {"Info3347223942-9575072", 186373, 4195},
 {"Info3347223942-1161328", 186484, 4198},
 {"Info3347223942-6641394", 186595, 4201},
 {"Info3347223942-3253559", 186706, 4204},
 {"Info3347223942-5222545", 186819, 4207},
 {"Info3347223942-6345755", 186931, 4210},
 {"Info3347223942-3683202", 187042, 4213},
 {"Info3347223942-7858990", 187156, 4216},
 {"Info3347223942-3699623", 187268, 4219},
 {"Info3347223942-4895320", 187379, 4222},
 {"Info3347223942-9354952", 187490, 4225},
 {"Info3347223942-8866994", 187601, 4228},
 {"Info3347223942-7974690", 187712, 4231},
 {"Info3347223942-7718741", 187824, 4234},
 {"Info3347223942-6265237", 187935, 4237},
 {"Info3347223942-2127838", 188046, 4240},
 {"Info3347223942-8061335", 188157, 4243},
 {"Info3347223942-2612802", 188269, 4246},
 {"Info3347223942-3525955", 188380, 4249},
 {"Info3347223942-9298280", 188491, 4252},
 {"Info3347223942-3205867", 188602, 4255},
 {"Info3347223942-2715408", 188713, 4258},
 {"Info3347223942-1902193", 188824, 4261},
 {"Info3347223942-6712612", 188935, 4264},
 {"Info3347223942-4802586", 189046, 4267},
 {"Info3347223942-6636810", 189157, 4270},
 {"Info3347223942-4840162", 189268, 4273},
 {"Info3347223942-7491570", 189379, 4276},
 {"Info3347223942-1473756", 189491, 4279},
 {"Info3347223942-1735460", 189604, 4282},
 {"Info3347223942-2227327", 189715, 4285},
 {"Info3347223942-4747170", 189827, 4288},
 {"Info3347223942-2286321", 189938, 4291},
 {"Info3347223942-8963834", 190049, 4294},
 {"Info3347223942-9305092", 190160, 4297},
 {"Info3347223942-6456408", 190271, 4300},
 {"Info3347223942-3630767", 190382, 4303},
 {"Info3347223942-8451424", 190493, 4306},
 {"Info3347223942-9036334", 190605, 4309},
 {"Info3347223942-8833736", 190716, 4312},
 {"Info3347223942-7130020", 190827, 4315},
 {"Info3347223942-7499705", 190939, 4318},
 {"Info3347223942-7334860", 191051, 4321},
 {"Info3347223942-3929142", 191163, 4324},
 {"Info3347223942-4675478", 191275, 4327},
 {"Info3347223942-6544225", 191387, 4330},
 {"Info3347223942-4841605", 191499, 4333},
 {"Info3347223942-6260931", 191610, 4336},
 {"Info3347223942-2933636", 191721, 4339},
 {"Info3347223942-6299238", 191832, 4342},
 {"Info3347223942-8455083", 191944, 4345},
 {"Info3347223942-2761304", 192056, 4348},
 {"Info3347223942-7582796", 192168, 4351},
 {"Info3347223942-3568316", 192280, 4354},
 {"Info3347223942-8381002", 192392, 4357},
 {"Info3347223942-6455526", 192504, 4360},
 {"Info3347223942-4808313", 192616, 4363},
 {"Info3347223942-2972084", 192728, 4366},
 {"Info3347223942-3404091", 192840, 4369},
 {"Info3347223942-5570118", 192952, 4372},
 {"Info3347223942-9710485", 193064, 4375},
 {"Info3347223942-3212477", 193177, 4378},
 {"Info3347223942-7052201", 193289, 4381},
 {"Info3347223942-1274397", 193401, 4384},
 {"Info3347223942-6291660", 193513, 4387},
 {"Info3347223942-1780589", 193628, 4390},
 {"Info3347223942-7289647", 193740, 4393},
 {"Info3347223942-3206676", 193852, 4396},
 {"Info3347223942-9428676", 193964, 4399},
 {"Info3347223942-7629229", 194076, 4402},
 {"Info3347223942-1442542", 194188, 4405},
 {"Info3347223942-1702933", 194301, 4408},
 {"Info3347223942-5078785", 194414, 4411},
 {"Info3347223942-1556017", 194526, 4414},
 {"Info3347223942-3937423", 194639, 4417},
 {"Info3347223942-1584120", 194751, 4420},
 {"Info3347223942-8122127", 194863, 4423},
 {"Info3347223942-6550982", 194976, 4426},
 {"Info3347223942-4006352", 195088, 4429},
 {"Info3347223943-7268328", 195200, 4432},
 {"Info3347223943-9145937", 195313, 4435},
 {"Info3347223943-9840448", 195426, 4438},
 {"Info3347223943-7986648", 195540, 4441},
 {"Info3347223943-7429312", 195652, 4444},
 {"Info3347223943-7412679", 195765, 4447},
 {"Info3347223943-4063720", 195877, 4450},
 {"Info3347223943-2445563", 195989, 4453},
 {"Info3347223943-6984034", 196101, 4456},
 {"Info3347223943-7106080", 196213, 4459},
 {"Info3347223943-3775443", 196325, 4462},
 {"Info3347223943-8151160", 196438, 4465},
 {"Info3347223943-8563191", 196550, 4468},
 {"Info3347223943-7693835", 196663, 4471},
 {"Info3347223943-2142348", 196775, 4474},
 {"Info3347223943-4698659", 196887, 4477},
 {"Info3347223943-1610739", 196999, 4480},
 {"Info3347223943-4515092", 197111, 4483},
 {"Info3347223943-2547445", 197223, 4486},
 {"Info3347223943-5690018", 197335, 4489},
 {"Info3347223943-2070076", 197447, 4492},
 {"Info3347223943-5398885", 197559, 4495},
 {"Info3347223943-3534432", 197671, 4498},
 {"Info3347223943-2811507", 197783, 4501},
 {"Info3347223943-3089526", 197895, 4504},
 {"Info3347223943-4050909", 198007, 4507},
 {"Info3347223943-2256146", 198119, 4510},
 {"Info3347223943-2578274", 198231, 4513},
 {"Info3347223943-1967258", 198343, 4516},
 {"Info3347223943-3803042", 198455, 4519},
 {"Info3347223943-8980657", 198567, 4522},
 {"Info3347223943-4021916", 198679, 4525},
 {"Info3347223943-4519082", 198791, 4528},
 {"Info3347223943-1421647", 198903, 4531},
 {"Info3347223943-4876034", 199015, 4534},
 {"Info3347223943-4053978", 199127, 4537},
 {"Info3347223943-8562188", 199239, 4540},
 {"Info3347223943-7158326", 199351, 4543},
 {"Info3347223943-1889904", 199463, 4546},
 {"Info3347223943-5722087", 199575, 4549},
 {"Info3347223943-6066732", 199687, 4552},
 {"Info3347223943-7540695", 199800, 4555},
 {"Info3347223943-8356363", 199912, 4558},
 {"Info3347223943-2610039", 200024, 4561},
 {"Info3347223943-9333251", 200137, 4564},
 {"Info3347223943-5741528", 200249, 4567},
 {"Info3347223943-2058617", 200361, 4570},
 {"Info3347223943-6061612", 200474, 4573},
 {"Info3347223943-5839947", 200587, 4576},
 {"Info3347223943-6964670", 200702, 4579},
 {"Info3347223943-7045062", 200814, 4582},
 {"Info3347223943-3156769", 200927, 4585},
 {"Info3347223943-6001645", 201039, 4588},
 {"Info3347223943-4852106", 201151, 4591},
 {"Info3347223943-2532118", 201263, 4594},
 {"Info3347223943-7067293", 201375, 4597},
 {"Info3347223943-9641375", 201488, 4600},
 {"Info3347223943-7839447", 201600, 4603},
 {"Info3347223943-3277276", 201713, 4606},
 {"Info3347223943-1779400", 201825, 4609},
 {"Info3347223943-8626447", 201937, 4612},
 {"Info3347223943-1614004", 202049, 4615},
 {"Info3347223943-1756910", 202161, 4618},
 {"Info3347223943-7953603", 202273, 4621},
 {"Info3347223943-7285242", 202385, 4624},
 {"Info3347223943-3710641", 202497, 4627},
 {"Info3347223943-6496722", 202609, 4630},
 {"Info3347223943-4583684", 202721, 4633},
 {"Info3347223943-5150566", 202833, 4636},
 {"Info3347223943-5115022", 202945, 4639},
 {"Info3347223943-6296956", 203057, 4642},
 {"Info3347223943-1006138", 203169, 4645},
 {"Info3347223943-3228834", 203281, 4648},
 {"Info3347223943-1888747", 203393, 4651},
 {"Info3347223943-7381528", 203505, 4654},
 {"Info3347223943-8122874", 203617, 4657},
 {"Info3347223943-6416613", 203729, 4660},
 {"Info3347223943-1079780", 203841, 4663},
 {"Info3347223943-5972664", 203953, 4666},
 {"Info3347223943-4112961", 204065, 4669},
 {"Info3347223943-2709084", 204177, 4672},
 {"Info3347223943-8970379", 204289, 4675},
 {"Info3347223943-7602098", 204401, 4678},
 {"Info3347223943-2781622", 204513, 4681},
 {"Info3347223943-1412650", 204625, 4684},
 {"Info3347223943-9876552", 204737, 4687},
 {"Info3347223943-9911280", 204850, 4690},
 {"Info3347223943-6335135", 204962, 4693},
 {"Info3347223943-9595876", 205074, 4696},
 {"Info3347223943-5396991", 205187, 4699},
 {"Info3347223943-6581954", 205299, 4702},
 {"Info3347223943-8464511", 205411, 4705},
 {"Info3347223943-4874601", 205525, 4708},
 {"Info3347223943-5629661", 205638, 4711},
 {"Info3347223943-4925532", 205753, 4714},
 {"Info3347223943-5246270", 205865, 4717},
 {"Info3347223943-1445452", 205980, 4720},
 {"Info3347223943-4450436", 206092, 4723},
 {"Info3347223943-3881981", 206204, 4726},
 {"Info3347223943-7228078", 206316, 4729},
 {"Info3347223943-4602624", 206428, 4732},
 {"Info3347223943-8450963", 206541, 4735},
 {"Info3347223943-6220742", 206653, 4738},
 {"Info3347223943-7000860", 206766, 4741},
 {"Info3347223943-5567665", 206878, 4744},
 {"Info3347223943-5586590", 206990, 4747},
 {"Info3347223943-2736516", 207102, 4750},
 {"Info3347223943-4561819", 207214, 4753},
 {"Info3347223943-9200808", 207326, 4756},
 {"Info3347223943-4835101", 207438, 4759},
 {"Info3347223943-7355272", 207550, 4762},
 {"Info3347223943-1181112", 207662, 4765},
 {"Info3347223943-2215272", 207774, 4768},
 {"Info3347223943-1923535", 207886, 4771},
 {"Info3347223943-8093696", 207998, 4774},
 {"Info3347223943-6910008", 208110, 4777},
 {"Info3347223943-1493678", 208222, 4780},
 {"Info3347223943-3117515", 208334, 4783},
 {"Info3347223943-4832411", 208446, 4786},
 {"Info3347223943-8404433", 208558, 4789},
 {"Info3347223943-7328827", 208670, 4792},
 {"Info3347223943-4746551", 208782, 4795},
 {"Info3347223943-8409741", 208894, 4798},
 {"Info3347223943-8817053", 209006, 4801},
 {"Info3347223943-3716282", 209118, 4804},
 {"Info3347223943-8999170", 209230, 4807},
 {"Info3347223943-5709094", 209342, 4810},
 {"Info3347223943-3657880", 209454, 4813},
 {"Info3347223943-6348310", 209566, 4816},
 {"Info3347223943-5622619", 209678, 4819},
 {"Info3347223943-3212639", 209790, 4822},
 {"Info3347223944-7593278", 209903, 4825},
 {"Info3347223944-1223543", 210015, 4828},
 {"Info3347223944-6433330", 210127, 4831},
 {"Info3347223944-8548286", 210240, 4834},
 {"Info3347223944-5636726", 210352, 4837},
 {"Info3347223944-6212195", 210464, 4840},
 {"Info3347223944-2446185", 210579, 4843},
 {"Info3347223944-4819550", 210692, 4846},
 {"Info3347223944-6414604", 210806, 4849},
 {"Info3347223944-6619072", 210919, 4852},
 {"Info3347223944-4082389", 211033, 4855},
 {"Info3347223944-3243349", 211145, 4858},
 {"Info3347223944-9833440", 211257, 4861},
 {"Info3347223944-9033299", 211369, 4864},
 {"Info3347223944-7106424", 211481, 4867},
 {"Info3347223944-2091162", 211593, 4870},
 {"Info3347223944-1590385", 211705, 4873},
 {"Info3347223944-5449929", 211817, 4876},
 {"Info3347223944-5484391", 211929, 4879},
 {"Info3347223944-8026549", 212041, 4882},
 {"Info3347223944-6509291", 212154, 4885},
 {"Info3347223944-9854803", 212266, 4888},
 {"Info3347223944-4587203", 212380, 4891},
 {"Info3347223944-6627152", 212492, 4894},
 {"Info3347223944-9677027", 212604, 4897},
 {"Info3347223944-7882672", 212716, 4900},
 {"Info3347223944-5172316", 212828, 4903},
 {"Info3347223944-1205732", 212940, 4906},
 {"Info3347223944-8443384", 213052, 4909},
 {"Info3347223944-8424884", 213164, 4912},
 {"Info3347223944-9112071", 213276, 4915},
 {"Info3347223944-5725100", 213388, 4918},
 {"Info3347223944-3763668", 213500, 4921},
 {"Info3347223944-5023528", 213612, 4924},
 {"Info3347223944-6332496", 213724, 4927},
 {"Info3347223944-1601766", 213836, 4930},
 {"Info3347223944-9984544", 213948, 4933},
 {"Info3347223944-8912656", 214060, 4936},
 {"Info3347223944-6144805", 214172, 4939},
 {"Info3347223944-4339604", 214284, 4942},
 {"Info3347223944-7164196", 214396, 4945},
 {"Info3347223944-7748027", 214508, 4948},
 {"Info3347223944-7495296", 214620, 4951},
 {"Info3347223944-8982714", 214732, 4954},
 {"Info3347223944-8993898", 214844, 4957},
 {"Info3347223944-1732994", 214956, 4960},
 {"Info3347223944-1385772", 215068, 4963},
 {"Info3347223944-8600115", 215180, 4966}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 206, 5, 172, "Subtitle"],
Cell[CellGroupData[{
Cell[798, 31, 41, 0, 71, "Section"],
Cell[842, 33, 1647, 27, 317, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2526, 65, 82, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[2633, 71, 170, 2, 23, "Print",
 CellTags->"Info3347223940-6631621"],
Cell[2806, 75, 172, 2, 23, "Print",
 CellTags->"Info3347223940-4294206"],
Cell[2981, 79, 359, 5, 62, "Print",
 CellTags->"Info3347223940-6810511"],
Cell[3343, 86, 151, 2, 23, "Print",
 CellTags->"Info3347223940-7389295"],
Cell[3497, 90, 126, 2, 23, "Print",
 CellTags->"Info3347223940-2382490"],
Cell[3626, 94, 133, 2, 23, "Print",
 CellTags->"Info3347223940-6023529"],
Cell[3762, 98, 114, 1, 23, "Print",
 CellTags->"Info3347223940-6503571"],
Cell[3879, 101, 123, 2, 23, "Print",
 CellTags->"Info3347223940-5379615"],
Cell[4005, 105, 160, 2, 23, "Print",
 CellTags->"Info3347223940-1834069"],
Cell[4168, 109, 255, 3, 43, "Print",
 CellTags->"Info3347223940-7924268"],
Cell[4426, 114, 154, 2, 23, "Print",
 CellTags->"Info3347223940-7939632"],
Cell[4583, 118, 275, 4, 43, "Print",
 CellTags->"Info3347223940-6833855"],
Cell[4861, 124, 141, 2, 23, "Print",
 CellTags->"Info3347223940-1189387"],
Cell[5005, 128, 66, 1, 23, "Print",
 CellTags->"Info3347223940-1293541"],
Cell[5074, 131, 967, 26, 23, "Print",
 CellTags->"Info3347223940-1293541"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6090, 163, 96, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[6211, 169, 106, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[6342, 175, 815, 11, 119, "Print",
 CellTags->"Info3347223940-8692552"],
Cell[7160, 188, 383, 5, 62, "Print",
 CellTags->"Info3347223940-9972450"],
Cell[7546, 195, 283, 5, 23, "Print",
 CellTags->"Info3347223940-9972450"],
Cell[7832, 202, 360, 5, 81, "Print",
 CellTags->"Info3347223940-4605738"],
Cell[8195, 209, 254, 3, 43, "Print",
 CellTags->"Info3347223940-4732625"],
Cell[8452, 214, 750, 10, 176, "Print",
 CellTags->"Info3347223940-4167237"],
Cell[9205, 226, 659, 9, 138, "Print",
 CellTags->"Info3347223940-9087758"],
Cell[9867, 237, 708, 9, 119, "Print",
 CellTags->"Info3347223940-5926772"],
Cell[10578, 248, 562, 7, 119, "Print",
 CellTags->"Info3347223940-8501482"],
Cell[11143, 257, 172, 2, 23, "Print",
 CellTags->"Info3347223940-7144037"],
Cell[11318, 261, 173, 2, 23, "Print",
 CellTags->"Info3347223940-2011507"],
Cell[11494, 265, 169, 2, 23, "Print",
 CellTags->"Info3347223940-6339513"],
Cell[11666, 269, 169, 2, 23, "Print",
 CellTags->"Info3347223940-5174597"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11884, 277, 93, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[12002, 283, 560, 8, 100, "Print",
 CellTags->"Info3347223940-1062849"],
Cell[12565, 293, 182, 2, 43, "Print",
 CellTags->"Info3347223940-3542961"],
Cell[12750, 297, 156, 2, 43, "Print",
 CellTags->"Info3347223940-1600426"],
Cell[12909, 301, 273, 4, 62, "Print",
 CellTags->"Info3347223940-4337716"],
Cell[13185, 307, 583, 8, 119, "Print",
 CellTags->"Info3347223941-1813366"],
Cell[13771, 317, 275, 4, 62, "Print",
 CellTags->"Info3347223941-1118594"],
Cell[14049, 323, 210, 3, 23, "Print",
 CellTags->"Info3347223941-5737972"],
Cell[14262, 328, 234, 3, 43, "Print",
 CellTags->"Info3347223941-7410441"],
Cell[14499, 333, 289, 4, 62, "Print",
 CellTags->"Info3347223941-8640170"],
Cell[14791, 339, 204, 3, 43, "Print",
 CellTags->"Info3347223941-1951187"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[15044, 348, 103, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[15172, 354, 191, 2, 43, "Print",
 CellTags->"Info3347223941-8197922"],
Cell[15366, 358, 259, 3, 43, "Print",
 CellTags->"Info3347223941-2611265"],
Cell[15628, 363, 181, 2, 43, "Print",
 CellTags->"Info3347223941-9442840"],
Cell[15812, 367, 172, 2, 43, "Print",
 CellTags->"Info3347223941-7245219"],
Cell[15987, 371, 181, 2, 43, "Print",
 CellTags->"Info3347223941-5798128"],
Cell[16171, 375, 830, 11, 138, "Print",
 CellTags->"Info3347223941-1459018"],
Cell[17004, 388, 495, 6, 100, "Print",
 CellTags->"Info3347223941-1589458"],
Cell[17502, 396, 421, 5, 62, "Print",
 CellTags->"Info3347223941-8534708"],
Cell[17926, 403, 740, 9, 176, "Print",
 CellTags->"Info3347223941-7553760"],
Cell[18669, 414, 121, 2, 23, "Print",
 CellTags->"Info3347223941-9188284"],
Cell[18793, 418, 137, 2, 23, "Print",
 CellTags->"Info3347223941-7542695"],
Cell[18933, 422, 132, 2, 23, "Print",
 CellTags->"Info3347223941-2715154"],
Cell[19068, 426, 124, 2, 23, "Print",
 CellTags->"Info3347223941-2795720"],
Cell[19195, 430, 130, 2, 23, "Print",
 CellTags->"Info3347223941-9823357"],
Cell[19328, 434, 151, 2, 23, "Print",
 CellTags->"Info3347223941-8020983"],
Cell[19482, 438, 666, 9, 100, "Print",
 CellTags->"Info3347223941-4999920"],
Cell[20151, 449, 242, 3, 43, "Print",
 CellTags->"Info3347223941-6637905"],
Cell[20396, 454, 246, 3, 43, "Print",
 CellTags->"Info3347223941-9601905"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20691, 463, 87, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[20803, 469, 500, 7, 138, "Print",
 CellTags->"Info3347223941-1464798"],
Cell[21306, 478, 445, 6, 119, "Print",
 CellTags->"Info3347223941-1770110"],
Cell[21754, 486, 437, 6, 100, "Print",
 CellTags->"Info3347223941-2471642"],
Cell[22194, 494, 440, 6, 119, "Print",
 CellTags->"Info3347223941-7586356"],
Cell[22637, 502, 366, 5, 100, "Print",
 CellTags->"Info3347223941-4155620"],
Cell[23006, 509, 435, 6, 100, "Print",
 CellTags->"Info3347223941-3197855"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[23490, 521, 87, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[23602, 527, 317, 4, 43, "Print",
 CellTags->"Info3347223941-8920274"],
Cell[23922, 533, 108, 1, 23, "Print",
 CellTags->"Info3347223941-2580618"],
Cell[24033, 536, 128, 2, 23, "Print",
 CellTags->"Info3347223941-5009207"],
Cell[24164, 540, 101, 1, 23, "Print",
 CellTags->"Info3347223941-1486463"],
Cell[24268, 543, 137, 2, 23, "Print",
 CellTags->"Info3347223941-2487122"],
Cell[24408, 547, 147, 2, 23, "Print",
 CellTags->"Info3347223941-6450972"],
Cell[24558, 551, 173, 2, 23, "Print",
 CellTags->"Info3347223941-4162216"],
Cell[24734, 555, 107, 1, 23, "Print",
 CellTags->"Info3347223941-6354640"],
Cell[24844, 558, 109, 1, 23, "Print",
 CellTags->"Info3347223941-5746827"],
Cell[24956, 561, 296, 4, 81, "Print",
 CellTags->"Info3347223941-2691935"],
Cell[25255, 567, 112, 1, 23, "Print",
 CellTags->"Info3347223941-7877067"],
Cell[25370, 570, 143, 2, 23, "Print",
 CellTags->"Info3347223941-7749989"],
Cell[25516, 574, 112, 1, 23, "Print",
 CellTags->"Info3347223941-3231106"],
Cell[25631, 577, 239, 3, 43, "Print",
 CellTags->"Info3347223941-3377092"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[25919, 586, 86, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[26030, 592, 369, 5, 62, "Print",
 CellTags->"Info3347223941-4876077"],
Cell[26402, 599, 148, 2, 23, "Print",
 CellTags->"Info3347223941-3439479"],
Cell[26553, 603, 275, 4, 43, "Print",
 CellTags->"Info3347223941-7653090"],
Cell[26831, 609, 160, 2, 23, "Print",
 CellTags->"Info3347223941-7874582"],
Cell[26994, 613, 1073, 14, 138, "Print",
 CellTags->"Info3347223941-5235115"],
Cell[28070, 629, 171, 2, 23, "Print",
 CellTags->"Info3347223941-7704576"],
Cell[28244, 633, 112, 1, 23, "Print",
 CellTags->"Info3347223941-4043808"],
Cell[28359, 636, 246, 3, 43, "Print",
 CellTags->"Info3347223941-3418109"],
Cell[28608, 641, 284, 4, 43, "Print",
 CellTags->"Info3347223941-6580237"],
Cell[28895, 647, 295, 4, 43, "Print",
 CellTags->"Info3347223941-6852624"],
Cell[29193, 653, 444, 6, 138, "Print",
 CellTags->"Info3347223941-1422078"],
Cell[29640, 661, 508, 7, 62, "Print",
 CellTags->"Info3347223941-2029304"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30209, 675, 91, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[30325, 681, 106, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[30456, 687, 1048, 14, 176, "Print",
 CellTags->"Info3347223941-8989917"],
Cell[31507, 703, 280, 5, 23, "Print",
 CellTags->"Info3347223940-9972450"],
Cell[31790, 710, 394, 5, 62, "Print",
 CellTags->"Info3347223941-3552733"],
Cell[32187, 717, 367, 5, 81, "Print",
 CellTags->"Info3347223941-6176457"],
Cell[32557, 724, 258, 3, 43, "Print",
 CellTags->"Info3347223941-8109493"],
Cell[32818, 729, 811, 11, 195, "Print",
 CellTags->"Info3347223941-6089851"],
Cell[33632, 742, 673, 9, 138, "Print",
 CellTags->"Info3347223941-7134049"],
Cell[34308, 753, 715, 9, 119, "Print",
 CellTags->"Info3347223941-7244468"],
Cell[35026, 764, 567, 7, 119, "Print",
 CellTags->"Info3347223941-4415755"],
Cell[35596, 773, 172, 2, 23, "Print",
 CellTags->"Info3347223941-9094170"],
Cell[35771, 777, 173, 2, 23, "Print",
 CellTags->"Info3347223941-3611725"],
Cell[35947, 781, 169, 2, 23, "Print",
 CellTags->"Info3347223941-9967462"],
Cell[36119, 785, 169, 2, 23, "Print",
 CellTags->"Info3347223941-4309295"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[36337, 793, 93, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[36455, 799, 560, 8, 100, "Print",
 CellTags->"Info3347223941-8260624"],
Cell[37018, 809, 182, 2, 43, "Print",
 CellTags->"Info3347223941-8492284"],
Cell[37203, 813, 156, 2, 43, "Print",
 CellTags->"Info3347223941-8438704"],
Cell[37362, 817, 273, 4, 62, "Print",
 CellTags->"Info3347223941-3285558"],
Cell[37638, 823, 578, 8, 119, "Print",
 CellTags->"Info3347223941-1354509"],
Cell[38219, 833, 275, 4, 62, "Print",
 CellTags->"Info3347223941-1355904"],
Cell[38497, 839, 210, 3, 23, "Print",
 CellTags->"Info3347223941-8370622"],
Cell[38710, 844, 234, 3, 43, "Print",
 CellTags->"Info3347223941-2291614"],
Cell[38947, 849, 289, 4, 62, "Print",
 CellTags->"Info3347223941-7771765"],
Cell[39239, 855, 204, 3, 43, "Print",
 CellTags->"Info3347223941-7568170"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39492, 864, 103, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[39620, 870, 191, 2, 43, "Print",
 CellTags->"Info3347223941-5343679"],
Cell[39814, 874, 259, 3, 43, "Print",
 CellTags->"Info3347223941-5864838"],
Cell[40076, 879, 181, 2, 43, "Print",
 CellTags->"Info3347223941-7809650"],
Cell[40260, 883, 172, 2, 43, "Print",
 CellTags->"Info3347223941-2458221"],
Cell[40435, 887, 181, 2, 43, "Print",
 CellTags->"Info3347223941-1974298"],
Cell[40619, 891, 830, 11, 138, "Print",
 CellTags->"Info3347223941-7595909"],
Cell[41452, 904, 495, 6, 100, "Print",
 CellTags->"Info3347223941-2077596"],
Cell[41950, 912, 421, 5, 62, "Print",
 CellTags->"Info3347223941-6833115"],
Cell[42374, 919, 740, 9, 176, "Print",
 CellTags->"Info3347223941-8415350"],
Cell[43117, 930, 121, 2, 23, "Print",
 CellTags->"Info3347223941-7920837"],
Cell[43241, 934, 137, 2, 23, "Print",
 CellTags->"Info3347223941-5070483"],
Cell[43381, 938, 132, 2, 23, "Print",
 CellTags->"Info3347223941-1032206"],
Cell[43516, 942, 124, 2, 23, "Print",
 CellTags->"Info3347223941-1376349"],
Cell[43643, 946, 130, 2, 23, "Print",
 CellTags->"Info3347223941-7407861"],
Cell[43776, 950, 151, 2, 23, "Print",
 CellTags->"Info3347223941-2948475"],
Cell[43930, 954, 666, 9, 100, "Print",
 CellTags->"Info3347223941-8742318"],
Cell[44599, 965, 242, 3, 43, "Print",
 CellTags->"Info3347223941-9656730"],
Cell[44844, 970, 246, 3, 43, "Print",
 CellTags->"Info3347223941-1145073"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45139, 979, 87, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[45251, 985, 500, 7, 138, "Print",
 CellTags->"Info3347223941-4193583"],
Cell[45754, 994, 445, 6, 119, "Print",
 CellTags->"Info3347223941-6993551"],
Cell[46202, 1002, 437, 6, 100, "Print",
 CellTags->"Info3347223941-6453383"],
Cell[46642, 1010, 440, 6, 119, "Print",
 CellTags->"Info3347223941-7559587"],
Cell[47085, 1018, 366, 5, 100, "Print",
 CellTags->"Info3347223941-5358822"],
Cell[47454, 1025, 435, 6, 100, "Print",
 CellTags->"Info3347223941-6682568"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47938, 1037, 87, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[48050, 1043, 317, 4, 43, "Print",
 CellTags->"Info3347223941-3512651"],
Cell[48370, 1049, 108, 1, 23, "Print",
 CellTags->"Info3347223941-8850662"],
Cell[48481, 1052, 123, 2, 23, "Print",
 CellTags->"Info3347223941-7730051"],
Cell[48607, 1056, 101, 1, 23, "Print",
 CellTags->"Info3347223941-2942451"],
Cell[48711, 1059, 137, 2, 23, "Print",
 CellTags->"Info3347223941-3089129"],
Cell[48851, 1063, 147, 2, 23, "Print",
 CellTags->"Info3347223941-3186031"],
Cell[49001, 1067, 173, 2, 23, "Print",
 CellTags->"Info3347223941-4802215"],
Cell[49177, 1071, 107, 1, 23, "Print",
 CellTags->"Info3347223941-8163804"],
Cell[49287, 1074, 109, 1, 23, "Print",
 CellTags->"Info3347223941-6931229"],
Cell[49399, 1077, 296, 4, 81, "Print",
 CellTags->"Info3347223941-9964984"],
Cell[49698, 1083, 112, 1, 23, "Print",
 CellTags->"Info3347223941-4270299"],
Cell[49813, 1086, 143, 2, 23, "Print",
 CellTags->"Info3347223941-7308454"],
Cell[49959, 1090, 112, 1, 23, "Print",
 CellTags->"Info3347223941-7750860"],
Cell[50074, 1093, 234, 3, 43, "Print",
 CellTags->"Info3347223941-3895549"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50357, 1102, 86, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[50468, 1108, 364, 5, 62, "Print",
 CellTags->"Info3347223941-4236356"],
Cell[50835, 1115, 148, 2, 23, "Print",
 CellTags->"Info3347223941-2245144"],
Cell[50986, 1119, 275, 4, 43, "Print",
 CellTags->"Info3347223941-8159017"],
Cell[51264, 1125, 160, 2, 23, "Print",
 CellTags->"Info3347223941-8125029"],
Cell[51427, 1129, 1073, 14, 138, "Print",
 CellTags->"Info3347223941-5725470"],
Cell[52503, 1145, 171, 2, 23, "Print",
 CellTags->"Info3347223941-8114379"],
Cell[52677, 1149, 112, 1, 23, "Print",
 CellTags->"Info3347223941-7760450"],
Cell[52792, 1152, 246, 3, 43, "Print",
 CellTags->"Info3347223941-7609199"],
Cell[53041, 1157, 284, 4, 43, "Print",
 CellTags->"Info3347223941-8492301"],
Cell[53328, 1163, 295, 4, 43, "Print",
 CellTags->"Info3347223941-8350572"],
Cell[53626, 1169, 444, 6, 138, "Print",
 CellTags->"Info3347223941-7702967"],
Cell[54073, 1177, 496, 6, 62, "Print",
 CellTags->"Info3347223941-7628927"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[54630, 1190, 116, 1, 71, "Section"],
Cell[CellGroupData[{
Cell[54771, 1195, 106, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[54902, 1201, 830, 11, 119, "Print",
 CellTags->"Info3347223941-2550021"],
Cell[55735, 1214, 384, 5, 62, "Print",
 CellTags->"Info3347223941-9246453"],
Cell[56122, 1221, 334, 6, 23, "Print",
 CellTags->"Info3347223940-9972450"],
Cell[56459, 1229, 579, 8, 138, "Print",
 CellTags->"Info3347223941-6719514"],
Cell[57041, 1239, 254, 3, 43, "Print",
 CellTags->"Info3347223941-3075263"],
Cell[57298, 1244, 763, 10, 195, "Print",
 CellTags->"Info3347223941-1794145"],
Cell[58064, 1256, 661, 9, 138, "Print",
 CellTags->"Info3347223941-2809827"],
Cell[58728, 1267, 939, 12, 214, "Print",
 CellTags->"Info3347223941-3602638"],
Cell[59670, 1281, 555, 7, 119, "Print",
 CellTags->"Info3347223941-4062804"],
Cell[60228, 1290, 172, 2, 23, "Print",
 CellTags->"Info3347223941-8484718"],
Cell[60403, 1294, 173, 2, 23, "Print",
 CellTags->"Info3347223941-8368394"],
Cell[60579, 1298, 169, 2, 23, "Print",
 CellTags->"Info3347223941-5771336"],
Cell[60751, 1302, 169, 2, 23, "Print",
 CellTags->"Info3347223941-5718574"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60969, 1310, 93, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[61087, 1316, 560, 8, 100, "Print",
 CellTags->"Info3347223941-9029670"],
Cell[61650, 1326, 182, 2, 43, "Print",
 CellTags->"Info3347223941-8579298"],
Cell[61835, 1330, 156, 2, 43, "Print",
 CellTags->"Info3347223941-4116126"],
Cell[61994, 1334, 273, 4, 62, "Print",
 CellTags->"Info3347223942-6124645"],
Cell[62270, 1340, 576, 8, 100, "Print",
 CellTags->"Info3347223942-3619064"],
Cell[62849, 1350, 275, 4, 62, "Print",
 CellTags->"Info3347223942-4004828"],
Cell[63127, 1356, 210, 3, 23, "Print",
 CellTags->"Info3347223942-3596063"],
Cell[63340, 1361, 234, 3, 43, "Print",
 CellTags->"Info3347223942-5797197"],
Cell[63577, 1366, 289, 4, 62, "Print",
 CellTags->"Info3347223942-2688418"],
Cell[63869, 1372, 204, 3, 43, "Print",
 CellTags->"Info3347223942-4889550"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[64122, 1381, 103, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[64250, 1387, 191, 2, 43, "Print",
 CellTags->"Info3347223942-4775645"],
Cell[64444, 1391, 259, 3, 43, "Print",
 CellTags->"Info3347223942-9433219"],
Cell[64706, 1396, 181, 2, 43, "Print",
 CellTags->"Info3347223942-1224636"],
Cell[64890, 1400, 172, 2, 43, "Print",
 CellTags->"Info3347223942-4362745"],
Cell[65065, 1404, 181, 2, 43, "Print",
 CellTags->"Info3347223942-3956808"],
Cell[65249, 1408, 830, 11, 138, "Print",
 CellTags->"Info3347223942-7340812"],
Cell[66082, 1421, 495, 6, 100, "Print",
 CellTags->"Info3347223942-7747929"],
Cell[66580, 1429, 421, 5, 62, "Print",
 CellTags->"Info3347223942-1072148"],
Cell[67004, 1436, 740, 9, 176, "Print",
 CellTags->"Info3347223942-4833943"],
Cell[67747, 1447, 121, 2, 23, "Print",
 CellTags->"Info3347223942-3215298"],
Cell[67871, 1451, 137, 2, 23, "Print",
 CellTags->"Info3347223942-3062770"],
Cell[68011, 1455, 132, 2, 23, "Print",
 CellTags->"Info3347223942-1478151"],
Cell[68146, 1459, 124, 2, 23, "Print",
 CellTags->"Info3347223942-4873634"],
Cell[68273, 1463, 130, 2, 23, "Print",
 CellTags->"Info3347223942-1405457"],
Cell[68406, 1467, 151, 2, 23, "Print",
 CellTags->"Info3347223942-3777925"],
Cell[68560, 1471, 666, 9, 100, "Print",
 CellTags->"Info3347223942-2152760"],
Cell[69229, 1482, 242, 3, 43, "Print",
 CellTags->"Info3347223942-5073193"],
Cell[69474, 1487, 246, 3, 43, "Print",
 CellTags->"Info3347223942-3551327"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[69769, 1496, 87, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[69881, 1502, 500, 7, 138, "Print",
 CellTags->"Info3347223942-9096541"],
Cell[70384, 1511, 445, 6, 119, "Print",
 CellTags->"Info3347223942-2626858"],
Cell[70832, 1519, 437, 6, 100, "Print",
 CellTags->"Info3347223942-9568268"],
Cell[71272, 1527, 440, 6, 119, "Print",
 CellTags->"Info3347223942-6949674"],
Cell[71715, 1535, 366, 5, 100, "Print",
 CellTags->"Info3347223942-3601001"],
Cell[72084, 1542, 435, 6, 100, "Print",
 CellTags->"Info3347223942-6609419"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72568, 1554, 87, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[72680, 1560, 317, 4, 43, "Print",
 CellTags->"Info3347223942-9958241"],
Cell[73000, 1566, 108, 1, 23, "Print",
 CellTags->"Info3347223942-7543440"],
Cell[73111, 1569, 121, 2, 23, "Print",
 CellTags->"Info3347223942-5025554"],
Cell[73235, 1573, 101, 1, 23, "Print",
 CellTags->"Info3347223942-6965775"],
Cell[73339, 1576, 137, 2, 23, "Print",
 CellTags->"Info3347223942-3888279"],
Cell[73479, 1580, 147, 2, 23, "Print",
 CellTags->"Info3347223942-5334754"],
Cell[73629, 1584, 173, 2, 23, "Print",
 CellTags->"Info3347223942-2217087"],
Cell[73805, 1588, 107, 1, 23, "Print",
 CellTags->"Info3347223942-6944643"],
Cell[73915, 1591, 109, 1, 23, "Print",
 CellTags->"Info3347223942-3967660"],
Cell[74027, 1594, 296, 4, 81, "Print",
 CellTags->"Info3347223942-9812128"],
Cell[74326, 1600, 112, 1, 23, "Print",
 CellTags->"Info3347223942-9428271"],
Cell[74441, 1603, 143, 2, 23, "Print",
 CellTags->"Info3347223942-5196408"],
Cell[74587, 1607, 112, 1, 23, "Print",
 CellTags->"Info3347223942-3765753"],
Cell[74702, 1610, 232, 3, 43, "Print",
 CellTags->"Info3347223942-7435369"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[74983, 1619, 86, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[75094, 1625, 362, 5, 62, "Print",
 CellTags->"Info3347223942-9408926"],
Cell[75459, 1632, 148, 2, 23, "Print",
 CellTags->"Info3347223942-8756152"],
Cell[75610, 1636, 275, 4, 43, "Print",
 CellTags->"Info3347223942-5512214"],
Cell[75888, 1642, 160, 2, 23, "Print",
 CellTags->"Info3347223942-4592327"],
Cell[76051, 1646, 1154, 15, 157, "Print",
 CellTags->"Info3347223942-2467846"],
Cell[77208, 1663, 171, 2, 23, "Print",
 CellTags->"Info3347223942-6619667"],
Cell[77382, 1667, 112, 1, 23, "Print",
 CellTags->"Info3347223942-8743872"],
Cell[77497, 1670, 246, 3, 43, "Print",
 CellTags->"Info3347223942-7645405"],
Cell[77746, 1675, 284, 4, 43, "Print",
 CellTags->"Info3347223942-9313603"],
Cell[78033, 1681, 295, 4, 43, "Print",
 CellTags->"Info3347223942-6658559"],
Cell[78331, 1687, 444, 6, 138, "Print",
 CellTags->"Info3347223942-2489674"],
Cell[78778, 1695, 492, 6, 62, "Print",
 CellTags->"Info3347223942-2698508"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[79331, 1708, 91, 2, 71, "Section"],
Cell[CellGroupData[{
Cell[79447, 1714, 106, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[79578, 1720, 1069, 14, 157, "Print",
 CellTags->"Info3347223942-1174016"],
Cell[80650, 1736, 363, 5, 43, "Print",
 CellTags->"Info3347223942-3337860"],
Cell[81016, 1743, 279, 5, 23, "Print",
 CellTags->"Info3347223942-3337860"],
Cell[81298, 1750, 1459, 19, 309, "Print",
 CellTags->"Info3347223942-7875248"],
Cell[82760, 1771, 270, 3, 62, "Print",
 CellTags->"Info3347223942-3565351"],
Cell[83033, 1776, 213, 3, 23, "Print",
 CellTags->"Info3347223942-9575072"],
Cell[83249, 1781, 206, 3, 23, "Print",
 CellTags->"Info3347223942-1161328"],
Cell[83458, 1786, 356, 5, 43, "Print",
 CellTags->"Info3347223942-6641394"],
Cell[83817, 1793, 986, 13, 366, "Print",
 CellTags->"Info3347223942-3253559"],
Cell[84806, 1808, 595, 8, 119, "Print",
 CellTags->"Info3347223942-5222545"],
Cell[85404, 1818, 239, 3, 43, "Print",
 CellTags->"Info3347223942-6345755"],
Cell[85646, 1823, 1189, 16, 290, "Print",
 CellTags->"Info3347223942-3683202"],
Cell[86838, 1841, 608, 8, 138, "Print",
 CellTags->"Info3347223942-7858990"],
Cell[87449, 1851, 172, 2, 23, "Print",
 CellTags->"Info3347223942-3699623"],
Cell[87624, 1855, 165, 2, 23, "Print",
 CellTags->"Info3347223942-4895320"],
Cell[87792, 1859, 169, 2, 23, "Print",
 CellTags->"Info3347223942-9354952"],
Cell[87964, 1863, 169, 2, 23, "Print",
 CellTags->"Info3347223942-8866994"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[88182, 1871, 93, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[88300, 1877, 560, 8, 100, "Print",
 CellTags->"Info3347223942-7974690"],
Cell[88863, 1887, 182, 2, 44, "Print",
 CellTags->"Info3347223942-7718741"],
Cell[89048, 1891, 156, 2, 44, "Print",
 CellTags->"Info3347223942-6265237"],
Cell[89207, 1895, 273, 4, 82, "Print",
 CellTags->"Info3347223942-2127838"],
Cell[89483, 1901, 583, 8, 158, "Print",
 CellTags->"Info3347223942-8061335"],
Cell[90069, 1911, 275, 4, 82, "Print",
 CellTags->"Info3347223942-2612802"],
Cell[90347, 1917, 210, 3, 44, "Print",
 CellTags->"Info3347223942-3525955"],
Cell[90560, 1922, 234, 3, 44, "Print",
 CellTags->"Info3347223942-9298280"],
Cell[90797, 1927, 289, 4, 82, "Print",
 CellTags->"Info3347223942-3205867"],
Cell[91089, 1933, 204, 3, 44, "Print",
 CellTags->"Info3347223942-2715408"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[91342, 1942, 103, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[91470, 1948, 191, 2, 63, "Print",
 CellTags->"Info3347223942-1902193"],
Cell[91664, 1952, 259, 3, 63, "Print",
 CellTags->"Info3347223942-6712612"],
Cell[91926, 1957, 181, 2, 44, "Print",
 CellTags->"Info3347223942-4802586"],
Cell[92110, 1961, 172, 2, 44, "Print",
 CellTags->"Info3347223942-6636810"],
Cell[92285, 1965, 181, 2, 44, "Print",
 CellTags->"Info3347223942-4840162"],
Cell[92469, 1969, 427, 6, 120, "Print",
 CellTags->"Info3347223942-7491570"],
Cell[92899, 1977, 813, 10, 215, "Print",
 CellTags->"Info3347223942-1473756"],
Cell[93715, 1989, 207, 3, 44, "Print",
 CellTags->"Info3347223942-1735460"],
Cell[93925, 1994, 591, 8, 158, "Print",
 CellTags->"Info3347223942-2227327"],
Cell[94519, 2004, 121, 2, 25, "Print",
 CellTags->"Info3347223942-4747170"],
Cell[94643, 2008, 137, 2, 25, "Print",
 CellTags->"Info3347223942-2286321"],
Cell[94783, 2012, 132, 2, 25, "Print",
 CellTags->"Info3347223942-8963834"],
Cell[94918, 2016, 124, 2, 25, "Print",
 CellTags->"Info3347223942-9305092"],
Cell[95045, 2020, 130, 2, 25, "Print",
 CellTags->"Info3347223942-6456408"],
Cell[95178, 2024, 151, 2, 25, "Print",
 CellTags->"Info3347223942-3630767"],
Cell[95332, 2028, 666, 9, 158, "Print",
 CellTags->"Info3347223942-8451424"],
Cell[96001, 2039, 242, 3, 44, "Print",
 CellTags->"Info3347223942-9036334"],
Cell[96246, 2044, 246, 3, 63, "Print",
 CellTags->"Info3347223942-8833736"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96541, 2053, 85, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[96651, 2059, 500, 7, 158, "Print",
 CellTags->"Info3347223942-7130020"],
Cell[97154, 2068, 445, 6, 139, "Print",
 CellTags->"Info3347223942-7499705"],
Cell[97602, 2076, 437, 6, 120, "Print",
 CellTags->"Info3347223942-7334860"],
Cell[98042, 2084, 440, 6, 139, "Print",
 CellTags->"Info3347223942-3929142"],
Cell[98485, 2092, 366, 5, 120, "Print",
 CellTags->"Info3347223942-4675478"],
Cell[98854, 2099, 435, 6, 120, "Print",
 CellTags->"Info3347223942-6544225"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[99338, 2111, 87, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[99450, 2117, 317, 4, 63, "Print",
 CellTags->"Info3347223942-4841605"],
Cell[99770, 2123, 108, 1, 25, "Print",
 CellTags->"Info3347223942-6260931"],
Cell[99881, 2126, 128, 2, 25, "Print",
 CellTags->"Info3347223942-2933636"],
Cell[100012, 2130, 101, 1, 25, "Print",
 CellTags->"Info3347223942-6299238"],
Cell[100116, 2133, 137, 2, 25, "Print",
 CellTags->"Info3347223942-8455083"],
Cell[100256, 2137, 147, 2, 25, "Print",
 CellTags->"Info3347223942-2761304"],
Cell[100406, 2141, 173, 2, 44, "Print",
 CellTags->"Info3347223942-7582796"],
Cell[100582, 2145, 107, 1, 25, "Print",
 CellTags->"Info3347223942-3568316"],
Cell[100692, 2148, 109, 1, 25, "Print",
 CellTags->"Info3347223942-8381002"],
Cell[100804, 2151, 296, 4, 82, "Print",
 CellTags->"Info3347223942-6455526"],
Cell[101103, 2157, 112, 1, 25, "Print",
 CellTags->"Info3347223942-4808313"],
Cell[101218, 2160, 143, 2, 25, "Print",
 CellTags->"Info3347223942-2972084"],
Cell[101364, 2164, 112, 1, 25, "Print",
 CellTags->"Info3347223942-3404091"],
Cell[101479, 2167, 239, 3, 44, "Print",
 CellTags->"Info3347223942-5570118"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[101767, 2176, 86, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[101878, 2182, 364, 5, 101, "Print",
 CellTags->"Info3347223942-9710485"],
Cell[102245, 2189, 148, 2, 25, "Print",
 CellTags->"Info3347223942-3212477"],
Cell[102396, 2193, 275, 4, 63, "Print",
 CellTags->"Info3347223942-7052201"],
Cell[102674, 2199, 160, 2, 25, "Print",
 CellTags->"Info3347223942-1274397"],
Cell[102837, 2203, 1165, 15, 272, "Print",
 CellTags->"Info3347223942-6291660"],
Cell[104005, 2220, 171, 2, 25, "Print",
 CellTags->"Info3347223942-1780589"],
Cell[104179, 2224, 112, 1, 25, "Print",
 CellTags->"Info3347223942-7289647"],
Cell[104294, 2227, 246, 3, 44, "Print",
 CellTags->"Info3347223942-3206676"],
Cell[104543, 2232, 284, 4, 63, "Print",
 CellTags->"Info3347223942-9428676"],
Cell[104830, 2238, 295, 4, 63, "Print",
 CellTags->"Info3347223942-7629229"],
Cell[105128, 2244, 444, 6, 158, "Print",
 CellTags->"Info3347223942-1442542"],
Cell[105575, 2252, 508, 7, 101, "Print",
 CellTags->"Info3347223942-1702933"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[106144, 2266, 97, 2, 59, "Section"],
Cell[CellGroupData[{
Cell[106266, 2272, 102, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[106393, 2278, 254, 3, 63, "Print",
 CellTags->"Info3347223942-5078785"],
Cell[106650, 2283, 542, 7, 120, "Print",
 CellTags->"Info3347223942-1556017"],
Cell[107195, 2292, 126, 2, 25, "Print",
 CellTags->"Info3347223942-3937423"],
Cell[107324, 2296, 183, 2, 44, "Print",
 CellTags->"Info3347223942-1584120"],
Cell[107510, 2300, 495, 7, 120, "Print",
 CellTags->"Info3347223942-8122127"],
Cell[108008, 2309, 264, 3, 63, "Print",
 CellTags->"Info3347223942-6550982"],
Cell[108275, 2314, 122, 2, 25, "Print",
 CellTags->"Info3347223942-4006352"],
Cell[108400, 2318, 502, 6, 215, "Print",
 CellTags->"Info3347223943-7268328"],
Cell[108905, 2326, 421, 5, 177, "Print",
 CellTags->"Info3347223943-9145937"],
Cell[109329, 2333, 984, 13, 310, "Print",
 CellTags->"Info3347223943-9840448"],
Cell[110316, 2348, 318, 4, 63, "Print",
 CellTags->"Info3347223943-7986648"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[110683, 2358, 82, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[110790, 2364, 667, 9, 234, "Print",
 CellTags->"Info3347223943-7429312"],
Cell[111460, 2375, 160, 2, 44, "Print",
 CellTags->"Info3347223943-7412679"],
Cell[111623, 2379, 213, 3, 63, "Print",
 CellTags->"Info3347223943-4063720"],
Cell[111839, 2384, 216, 3, 63, "Print",
 CellTags->"Info3347223943-2445563"],
Cell[112058, 2389, 204, 3, 63, "Print",
 CellTags->"Info3347223943-6984034"],
Cell[112265, 2394, 209, 3, 63, "Print",
 CellTags->"Info3347223943-7106080"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[112523, 2403, 87, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[112635, 2409, 379, 5, 101, "Print",
 CellTags->"Info3347223943-3775443"],
Cell[113017, 2416, 135, 2, 25, "Print",
 CellTags->"Info3347223943-8151160"],
Cell[113155, 2420, 593, 8, 158, "Print",
 CellTags->"Info3347223943-8563191"],
Cell[113751, 2430, 135, 2, 25, "Print",
 CellTags->"Info3347223943-7693835"],
Cell[113889, 2434, 309, 4, 63, "Print",
 CellTags->"Info3347223943-2142348"],
Cell[114201, 2440, 108, 1, 25, "Print",
 CellTags->"Info3347223943-4698659"],
Cell[114312, 2443, 153, 2, 25, "Print",
 CellTags->"Info3347223943-1610739"],
Cell[114468, 2447, 101, 1, 25, "Print",
 CellTags->"Info3347223943-4515092"],
Cell[114572, 2450, 154, 2, 25, "Print",
 CellTags->"Info3347223943-2547445"],
Cell[114729, 2454, 147, 2, 25, "Print",
 CellTags->"Info3347223943-5690018"],
Cell[114879, 2458, 182, 2, 44, "Print",
 CellTags->"Info3347223943-2070076"],
Cell[115064, 2462, 148, 2, 25, "Print",
 CellTags->"Info3347223943-5398885"],
Cell[115215, 2466, 165, 2, 44, "Print",
 CellTags->"Info3347223943-3534432"],
Cell[115383, 2470, 228, 3, 44, "Print",
 CellTags->"Info3347223943-2811507"],
Cell[115614, 2475, 230, 3, 44, "Print",
 CellTags->"Info3347223943-3089526"],
Cell[115847, 2480, 107, 1, 25, "Print",
 CellTags->"Info3347223943-4050909"],
Cell[115957, 2483, 109, 1, 25, "Print",
 CellTags->"Info3347223943-2256146"],
Cell[116069, 2486, 296, 4, 82, "Print",
 CellTags->"Info3347223943-2578274"],
Cell[116368, 2492, 112, 1, 25, "Print",
 CellTags->"Info3347223943-1967258"],
Cell[116483, 2495, 143, 2, 25, "Print",
 CellTags->"Info3347223943-3803042"],
Cell[116629, 2499, 112, 1, 25, "Print",
 CellTags->"Info3347223943-8980657"],
Cell[116744, 2502, 112, 1, 25, "Print",
 CellTags->"Info3347223943-4021916"],
Cell[116859, 2505, 240, 3, 44, "Print",
 CellTags->"Info3347223943-4519082"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[117148, 2514, 83, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[117256, 2520, 134, 2, 25, "Print",
 CellTags->"Info3347223943-1421647"],
Cell[117393, 2524, 242, 3, 44, "Print",
 CellTags->"Info3347223943-4876034"],
Cell[117638, 2529, 131, 2, 25, "Print",
 CellTags->"Info3347223943-4053978"],
Cell[117772, 2533, 284, 4, 63, "Print",
 CellTags->"Info3347223943-8562188"],
Cell[118059, 2539, 295, 4, 63, "Print",
 CellTags->"Info3347223943-7158326"],
Cell[118357, 2545, 247, 3, 44, "Print",
 CellTags->"Info3347223943-1889904"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[118665, 2555, 92, 2, 59, "Section"],
Cell[CellGroupData[{
Cell[118782, 2561, 102, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[118909, 2567, 254, 3, 63, "Print",
 CellTags->"Info3347223943-5722087"],
Cell[119166, 2572, 542, 7, 120, "Print",
 CellTags->"Info3347223943-6066732"],
Cell[119711, 2581, 126, 2, 25, "Print",
 CellTags->"Info3347223943-7540695"],
Cell[119840, 2585, 183, 2, 44, "Print",
 CellTags->"Info3347223943-8356363"],
Cell[120026, 2589, 495, 7, 120, "Print",
 CellTags->"Info3347223943-2610039"],
Cell[120524, 2598, 264, 3, 63, "Print",
 CellTags->"Info3347223943-9333251"],
Cell[120791, 2603, 122, 2, 25, "Print",
 CellTags->"Info3347223943-5741528"],
Cell[120916, 2607, 435, 6, 177, "Print",
 CellTags->"Info3347223943-2058617"],
Cell[121354, 2615, 418, 5, 158, "Print",
 CellTags->"Info3347223943-6061612"],
Cell[121775, 2622, 1013, 13, 310, "Print",
 CellTags->"Info3347223943-5839947"],
Cell[122791, 2637, 325, 4, 63, "Print",
 CellTags->"Info3347223943-6964670"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[123165, 2647, 82, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[123272, 2653, 649, 9, 215, "Print",
 CellTags->"Info3347223943-7045062"],
Cell[123924, 2664, 164, 2, 44, "Print",
 CellTags->"Info3347223943-3156769"],
Cell[124091, 2668, 211, 3, 63, "Print",
 CellTags->"Info3347223943-6001645"],
Cell[124305, 2673, 209, 3, 63, "Print",
 CellTags->"Info3347223943-4852106"],
Cell[124517, 2678, 212, 3, 63, "Print",
 CellTags->"Info3347223943-2532118"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124778, 2687, 87, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[124890, 2693, 379, 5, 101, "Print",
 CellTags->"Info3347223943-7067293"],
Cell[125272, 2700, 135, 2, 25, "Print",
 CellTags->"Info3347223943-9641375"],
Cell[125410, 2704, 597, 8, 158, "Print",
 CellTags->"Info3347223943-7839447"],
Cell[126010, 2714, 135, 2, 25, "Print",
 CellTags->"Info3347223943-3277276"],
Cell[126148, 2718, 309, 4, 63, "Print",
 CellTags->"Info3347223943-1779400"],
Cell[126460, 2724, 108, 1, 25, "Print",
 CellTags->"Info3347223943-8626447"],
Cell[126571, 2727, 148, 2, 25, "Print",
 CellTags->"Info3347223943-1614004"],
Cell[126722, 2731, 101, 1, 25, "Print",
 CellTags->"Info3347223943-1756910"],
Cell[126826, 2734, 149, 2, 25, "Print",
 CellTags->"Info3347223943-7953603"],
Cell[126978, 2738, 147, 2, 25, "Print",
 CellTags->"Info3347223943-7285242"],
Cell[127128, 2742, 177, 2, 44, "Print",
 CellTags->"Info3347223943-3710641"],
Cell[127308, 2746, 148, 2, 25, "Print",
 CellTags->"Info3347223943-6496722"],
Cell[127459, 2750, 160, 2, 25, "Print",
 CellTags->"Info3347223943-4583684"],
Cell[127622, 2754, 228, 3, 44, "Print",
 CellTags->"Info3347223943-5150566"],
Cell[127853, 2759, 230, 3, 44, "Print",
 CellTags->"Info3347223943-5115022"],
Cell[128086, 2764, 107, 1, 25, "Print",
 CellTags->"Info3347223943-6296956"],
Cell[128196, 2767, 109, 1, 25, "Print",
 CellTags->"Info3347223943-1006138"],
Cell[128308, 2770, 296, 4, 82, "Print",
 CellTags->"Info3347223943-3228834"],
Cell[128607, 2776, 112, 1, 25, "Print",
 CellTags->"Info3347223943-1888747"],
Cell[128722, 2779, 143, 2, 25, "Print",
 CellTags->"Info3347223943-7381528"],
Cell[128868, 2783, 112, 1, 25, "Print",
 CellTags->"Info3347223943-8122874"],
Cell[128983, 2786, 112, 1, 25, "Print",
 CellTags->"Info3347223943-6416613"],
Cell[129098, 2789, 235, 3, 44, "Print",
 CellTags->"Info3347223943-1079780"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[129382, 2798, 83, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[129490, 2804, 134, 2, 25, "Print",
 CellTags->"Info3347223943-5972664"],
Cell[129627, 2808, 242, 3, 44, "Print",
 CellTags->"Info3347223943-4112961"],
Cell[129872, 2813, 126, 2, 25, "Print",
 CellTags->"Info3347223943-2709084"],
Cell[130001, 2817, 284, 4, 63, "Print",
 CellTags->"Info3347223943-8970379"],
Cell[130288, 2823, 295, 4, 63, "Print",
 CellTags->"Info3347223943-7602098"],
Cell[130586, 2829, 247, 3, 44, "Print",
 CellTags->"Info3347223943-2781622"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[130894, 2839, 95, 2, 59, "Section"],
Cell[CellGroupData[{
Cell[131014, 2845, 102, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[131141, 2851, 254, 3, 63, "Print",
 CellTags->"Info3347223943-1412650"],
Cell[131398, 2856, 542, 7, 120, "Print",
 CellTags->"Info3347223943-9876552"],
Cell[131943, 2865, 126, 2, 25, "Print",
 CellTags->"Info3347223943-9911280"],
Cell[132072, 2869, 183, 2, 44, "Print",
 CellTags->"Info3347223943-6335135"],
Cell[132258, 2873, 495, 7, 120, "Print",
 CellTags->"Info3347223943-9595876"],
Cell[132756, 2882, 264, 3, 63, "Print",
 CellTags->"Info3347223943-5396991"],
Cell[133023, 2887, 122, 2, 25, "Print",
 CellTags->"Info3347223943-6581954"],
Cell[133148, 2891, 937, 12, 310, "Print",
 CellTags->"Info3347223943-8464511"],
Cell[134088, 2905, 437, 6, 196, "Print",
 CellTags->"Info3347223943-4874601"],
Cell[134528, 2913, 1332, 17, 424, "Print",
 CellTags->"Info3347223943-5629661"],
Cell[135863, 2932, 319, 4, 63, "Print",
 CellTags->"Info3347223943-4925532"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136231, 2942, 82, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[136338, 2948, 1161, 15, 367, "Print",
 CellTags->"Info3347223943-5246270"],
Cell[137502, 2965, 160, 2, 44, "Print",
 CellTags->"Info3347223943-1445452"],
Cell[137665, 2969, 207, 3, 63, "Print",
 CellTags->"Info3347223943-4450436"],
Cell[137875, 2974, 207, 3, 63, "Print",
 CellTags->"Info3347223943-3881981"],
Cell[138085, 2979, 216, 3, 63, "Print",
 CellTags->"Info3347223943-7228078"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[138350, 2988, 87, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[138462, 2994, 379, 5, 101, "Print",
 CellTags->"Info3347223943-4602624"],
Cell[138844, 3001, 135, 2, 25, "Print",
 CellTags->"Info3347223943-8450963"],
Cell[138982, 3005, 670, 9, 310, "Print",
 CellTags->"Info3347223943-6220742"],
Cell[139655, 3016, 135, 2, 25, "Print",
 CellTags->"Info3347223943-7000860"],
Cell[139793, 3020, 309, 4, 63, "Print",
 CellTags->"Info3347223943-5567665"],
Cell[140105, 3026, 108, 1, 25, "Print",
 CellTags->"Info3347223943-5586590"],
Cell[140216, 3029, 146, 2, 25, "Print",
 CellTags->"Info3347223943-2736516"],
Cell[140365, 3033, 101, 1, 25, "Print",
 CellTags->"Info3347223943-4561819"],
Cell[140469, 3036, 147, 2, 25, "Print",
 CellTags->"Info3347223943-9200808"],
Cell[140619, 3040, 147, 2, 25, "Print",
 CellTags->"Info3347223943-4835101"],
Cell[140769, 3044, 175, 2, 44, "Print",
 CellTags->"Info3347223943-7355272"],
Cell[140947, 3048, 148, 2, 25, "Print",
 CellTags->"Info3347223943-1181112"],
Cell[141098, 3052, 158, 2, 25, "Print",
 CellTags->"Info3347223943-2215272"],
Cell[141259, 3056, 228, 3, 44, "Print",
 CellTags->"Info3347223943-1923535"],
Cell[141490, 3061, 230, 3, 44, "Print",
 CellTags->"Info3347223943-8093696"],
Cell[141723, 3066, 107, 1, 25, "Print",
 CellTags->"Info3347223943-6910008"],
Cell[141833, 3069, 109, 1, 25, "Print",
 CellTags->"Info3347223943-1493678"],
Cell[141945, 3072, 296, 4, 82, "Print",
 CellTags->"Info3347223943-3117515"],
Cell[142244, 3078, 112, 1, 25, "Print",
 CellTags->"Info3347223943-4832411"],
Cell[142359, 3081, 143, 2, 25, "Print",
 CellTags->"Info3347223943-8404433"],
Cell[142505, 3085, 112, 1, 25, "Print",
 CellTags->"Info3347223943-7328827"],
Cell[142620, 3088, 112, 1, 25, "Print",
 CellTags->"Info3347223943-4746551"],
Cell[142735, 3091, 225, 3, 44, "Print",
 CellTags->"Info3347223943-8409741"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[143009, 3100, 83, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[143117, 3106, 134, 2, 25, "Print",
 CellTags->"Info3347223943-8817053"],
Cell[143254, 3110, 242, 3, 44, "Print",
 CellTags->"Info3347223943-3716282"],
Cell[143499, 3115, 114, 1, 25, "Print",
 CellTags->"Info3347223943-8999170"],
Cell[143616, 3118, 284, 4, 63, "Print",
 CellTags->"Info3347223943-5709094"],
Cell[143903, 3124, 295, 4, 63, "Print",
 CellTags->"Info3347223943-3657880"],
Cell[144201, 3130, 247, 3, 44, "Print",
 CellTags->"Info3347223943-6348310"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[144509, 3140, 92, 2, 59, "Section"],
Cell[CellGroupData[{
Cell[144626, 3146, 102, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[144753, 3152, 261, 3, 63, "Print",
 CellTags->"Info3347223943-5622619"],
Cell[145017, 3157, 547, 7, 120, "Print",
 CellTags->"Info3347223943-3212639"],
Cell[145567, 3166, 126, 2, 25, "Print",
 CellTags->"Info3347223944-7593278"],
Cell[145696, 3170, 183, 2, 44, "Print",
 CellTags->"Info3347223944-1223543"],
Cell[145882, 3174, 495, 7, 120, "Print",
 CellTags->"Info3347223944-6433330"],
Cell[146380, 3183, 264, 3, 63, "Print",
 CellTags->"Info3347223944-8548286"],
Cell[146647, 3188, 122, 2, 25, "Print",
 CellTags->"Info3347223944-5636726"],
Cell[146772, 3192, 1282, 17, 519, "Print",
 CellTags->"Info3347223944-6212195"],
Cell[148057, 3211, 669, 9, 196, "Print",
 CellTags->"Info3347223944-2446185"],
Cell[148729, 3222, 897, 12, 348, "Print",
 CellTags->"Info3347223944-4819550"],
Cell[149629, 3236, 600, 8, 158, "Print",
 CellTags->"Info3347223944-6414604"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[150278, 3250, 82, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[150385, 3256, 794, 10, 310, "Print",
 CellTags->"Info3347223944-6619072"],
Cell[151182, 3268, 288, 4, 82, "Print",
 CellTags->"Info3347223944-4082389"],
Cell[151473, 3274, 213, 3, 63, "Print",
 CellTags->"Info3347223944-3243349"],
Cell[151689, 3279, 216, 3, 63, "Print",
 CellTags->"Info3347223944-9833440"],
Cell[151908, 3284, 177, 2, 63, "Print",
 CellTags->"Info3347223944-9033299"],
Cell[152088, 3288, 215, 3, 63, "Print",
 CellTags->"Info3347223944-7106424"],
Cell[152306, 3293, 186, 2, 63, "Print",
 CellTags->"Info3347223944-2091162"],
Cell[152495, 3297, 210, 3, 63, "Print",
 CellTags->"Info3347223944-1590385"],
Cell[152708, 3302, 200, 3, 63, "Print",
 CellTags->"Info3347223944-5449929"],
Cell[152911, 3307, 215, 3, 63, "Print",
 CellTags->"Info3347223944-5484391"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[153175, 3316, 87, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[153287, 3322, 541, 7, 158, "Print",
 CellTags->"Info3347223944-8026549"],
Cell[153831, 3331, 135, 2, 25, "Print",
 CellTags->"Info3347223944-6509291"],
Cell[153969, 3335, 922, 12, 234, "Print",
 CellTags->"Info3347223944-9854803"],
Cell[154894, 3349, 135, 2, 25, "Print",
 CellTags->"Info3347223944-4587203"],
Cell[155032, 3353, 309, 4, 63, "Print",
 CellTags->"Info3347223944-6627152"],
Cell[155344, 3359, 108, 1, 25, "Print",
 CellTags->"Info3347223944-9677027"],
Cell[155455, 3362, 153, 2, 25, "Print",
 CellTags->"Info3347223944-7882672"],
Cell[155611, 3366, 101, 1, 25, "Print",
 CellTags->"Info3347223944-5172316"],
Cell[155715, 3369, 154, 2, 25, "Print",
 CellTags->"Info3347223944-1205732"],
Cell[155872, 3373, 147, 2, 25, "Print",
 CellTags->"Info3347223944-8443384"],
Cell[156022, 3377, 182, 2, 44, "Print",
 CellTags->"Info3347223944-8424884"],
Cell[156207, 3381, 148, 2, 25, "Print",
 CellTags->"Info3347223944-9112071"],
Cell[156358, 3385, 165, 2, 44, "Print",
 CellTags->"Info3347223944-5725100"],
Cell[156526, 3389, 228, 3, 44, "Print",
 CellTags->"Info3347223944-3763668"],
Cell[156757, 3394, 230, 3, 44, "Print",
 CellTags->"Info3347223944-5023528"],
Cell[156990, 3399, 107, 1, 25, "Print",
 CellTags->"Info3347223944-6332496"],
Cell[157100, 3402, 109, 1, 25, "Print",
 CellTags->"Info3347223944-1601766"],
Cell[157212, 3405, 296, 4, 82, "Print",
 CellTags->"Info3347223944-9984544"],
Cell[157511, 3411, 112, 1, 25, "Print",
 CellTags->"Info3347223944-8912656"],
Cell[157626, 3414, 143, 2, 25, "Print",
 CellTags->"Info3347223944-6144805"],
Cell[157772, 3418, 112, 1, 25, "Print",
 CellTags->"Info3347223944-4339604"],
Cell[157887, 3421, 112, 1, 25, "Print",
 CellTags->"Info3347223944-7164196"],
Cell[158002, 3424, 240, 3, 44, "Print",
 CellTags->"Info3347223944-7748027"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[158291, 3433, 83, 2, 47, "Subsection"],
Cell[CellGroupData[{
Cell[158399, 3439, 134, 2, 25, "Print",
 CellTags->"Info3347223944-7495296"],
Cell[158536, 3443, 209, 3, 44, "Print",
 CellTags->"Info3347223944-8982714"],
Cell[158748, 3448, 131, 2, 25, "Print",
 CellTags->"Info3347223944-8993898"],
Cell[158882, 3452, 284, 4, 63, "Print",
 CellTags->"Info3347223944-1732994"],
Cell[159169, 3458, 295, 4, 63, "Print",
 CellTags->"Info3347223944-1385772"],
Cell[159467, 3464, 247, 3, 44, "Print",
 CellTags->"Info3347223944-8600115"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

